@@ -1,5 +1,5 @@
 # -*- coding: utf-8 -*-
-# Copyright 2022 Cohesity Inc.
+# Copyright 2023 Cohesity Inc.
 
 import logging
 from cohesity_management_sdk.api_helper import APIHelper
@@ -187,7 +187,8 @@ class PrincipalsController(BaseController):
                 are returned. 'kUser' specifies a user object class. 'kGroup'
                 specifies a group object class. 'kComputer' specifies a
                 computer object class. 'kWellKnownPrincipal' specifies a well
-                known principal.
+                known principal. 'kServiceAccount' specifies a service account
+                object class.
             search (string, optional): Optionally filter by matching a
                 substring. Only principals in the with a name or
                 sAMAccountName that matches part or all of the specified
@@ -1345,7 +1346,6 @@ class PrincipalsController(BaseController):
             self.logger.error(e, exc_info=True)
             raise
 
-    
     def verify_otp_code(self, body):
         """Does a POST request to /public/verify-otp.
 
@@ -1369,21 +1369,18 @@ class PrincipalsController(BaseController):
 
             # Validate required parameters
             self.logger.info(
-                'Validating required parameters for verify_otp_code.'
-            )
+                'Validating required parameters for verify_otp_code.')
             self.validate_parameters(body=body)
 
             # Prepare query URL
-            self.logger.info(
-                'Preparing query URL for verify_otp_code.')
+            self.logger.info('Preparing query URL for verify_otp_code.')
             _url_path = '/public/verify-otp'
             _query_builder = self.config.get_base_uri()
             _query_builder += _url_path
             _query_url = APIHelper.clean_url(_query_builder)
 
             # Prepare headers
-            self.logger.info(
-                'Preparing headers for verify_otp_code.')
+            self.logger.info('Preparing headers for verify_otp_code.')
             _headers = {
                 'accept': 'application/json',
                 'content-type': 'application/json; charset=utf-8'
@@ -1391,28 +1388,26 @@ class PrincipalsController(BaseController):
 
             # Prepare and execute request
             self.logger.info(
-                'Preparing and executing request for verify_otp_code.'
-            )
+                'Preparing and executing request for verify_otp_code.')
             _request = self.http_client.post(
                 _query_url,
                 headers=_headers,
                 parameters=APIHelper.json_serialize(body))
             AuthManager.apply(_request, self.config)
-            _context = self.execute_request(
-                _request, name='verify_otp_code')
+            _context = self.execute_request(_request,
+                                            name='verify_otp_code')
 
             # Endpoint and global error handling using HTTP status codes.
-            self.logger.info(
-                'Validating response for verify_otp_code.')
+            self.logger.info('Validating response for verify_otp_code.')
             if _context.response.status_code == 0:
                 raise RequestErrorErrorException('Error', _context)
             self.validate_response(_context)
 
             # Return appropriate type
-            return APIHelper.json_deserialize(_context.response.raw_body,
-                                              SessionUser.from_dictionary)
+            return APIHelper.json_deserialize(
+                _context.response.raw_body,
+                SessionUser.from_dictionary)
 
         except Exception as e:
             self.logger.error(e, exc_info=True)
             raise
-
