@@ -11,9 +11,13 @@ __all__ = [
     'acl_mode_enum',
     'acl_proto',
     'acl_proto_grant',
+    'acropolis_backup_job_params',
+    'acropolis_backup_source_params',
+    'acropolis_disk_filter_proto',
     'acropolis_protection_source',
     'acropolis_restore_parameters',
     'acropolis_type_enum',
+    'action_change_service_state_parameters_enum',
     'action_enum',
     'action_update_protection_jobs_state_params_enum',
     'action_update_protection_jobs_state_request_body_enum',
@@ -25,6 +29,7 @@ __all__ = [
     'active_operation_enum',
     'ad_attribute',
     'ad_attribute_flag_enum',
+    'ad_attribute_flags_enum',
     'ad_attribute_restore_param',
     'ad_domain',
     'ad_domain_controller',
@@ -34,6 +39,7 @@ __all__ = [
     'ad_object',
     'ad_object_attribute_parameters',
     'ad_object_flag_enum',
+    'ad_object_flags_enum',
     'ad_object_meta_data',
     'ad_object_restore_information',
     'ad_object_restore_param',
@@ -54,8 +60,10 @@ __all__ = [
     'address_family_enum',
     'agent_deployment_status_response',
     'agent_information',
+    'agent_status_enum',
     'agent_status_exchange_host_info_enum',
     'agent_type_enum',
+    'agent_upgrade_task_info',
     'aggregated_subtree_info',
     'alert',
     'alert_category_enum',
@@ -112,6 +120,7 @@ __all__ = [
     'application_restore_parameters',
     'application_server_info',
     'application_special_parameters',
+    'applications_enum',
     'applications_restore_task_request',
     'applications_wrapper',
     'apps_config',
@@ -124,6 +133,7 @@ __all__ = [
     'attribute_value',
     'audit_log_settings',
     'audit_logs_tile',
+    'aurora_cluster_info',
     'auth_method_enum',
     'auth_type_enum',
     'auth_type_mongodb_connect_params_enum',
@@ -158,6 +168,7 @@ __all__ = [
     'backup_job_proto_dr_to_cloud_params',
     'backup_job_proto_exclude_source',
     'backup_job_proto_exclusion_time_range',
+    'backup_job_proto_is_source_paused_map_entry',
     'backup_job_proto_remote_view_params',
     'backup_job_proto_remote_view_params_remote_view_map_entry',
     'backup_job_proto_remote_view_params_remote_view_params_per_view',
@@ -193,6 +204,8 @@ __all__ = [
     'bonding_mode_network_interface_enum',
     'bonding_mode_update_bond_parameters_enum',
     'bonding_opts',
+    'bucket_ownership_controls',
+    'bucket_policy',
     'bulk_install_app_task_info',
     'c2s_access_portal',
     'c2s_server_info',
@@ -210,9 +223,13 @@ __all__ = [
     'cassandra_protection_source',
     'cassandra_recover_job_params',
     'cassandra_security_info',
+    'categories_enum',
+    'category_alert_category_name_enum',
     'category_alert_metadata_enum',
     'category_enum',
     'category_notification_rule_enum',
+    'category_tenant_deletion_info_enum',
+    'cbt_info',
     'cdb_entity_info',
     'cdp_io_filter_state',
     'centrify_schema_enum',
@@ -222,6 +239,7 @@ __all__ = [
     'change_protection_job_state_param',
     'change_service_state_parameters',
     'change_service_state_result',
+    'changes_enum',
     'chassis_info',
     'check_type_enum',
     'cifs_share_info',
@@ -232,6 +250,7 @@ __all__ = [
     'clone_app_view_params',
     'clone_directory_params',
     'clone_refresh_request',
+    'clone_status_enum',
     'clone_task_info',
     'clone_task_request',
     'clone_view_request',
@@ -240,10 +259,13 @@ __all__ = [
     'cloud_archival_info',
     'cloud_archive_run',
     'cloud_archive_summary',
+    'cloud_chunk_repo_io_preferential_tier_enum',
     'cloud_deploy_info_proto',
     'cloud_deploy_info_proto_cloud_deploy_entity',
     'cloud_deploy_target',
     'cloud_deploy_target_details',
+    'cloud_domain_list',
+    'cloud_domain_migration_query_result',
     'cloud_network_configuration',
     'cloud_parameters',
     'cluster',
@@ -271,20 +293,29 @@ __all__ = [
     'cluster_networking_resource_information',
     'cluster_partition',
     'cluster_public_keys',
+    'cluster_size_enum',
     'cluster_stats',
     'cluster_status_result',
     'cluster_type_cluster_enum',
     'cluster_type_enum',
+    'cluster_update_ipmi_users_parameters',
+    'cluster_update_ipmi_users_result',
     'combine_method_enum',
     'common_acl_proto',
     'common_acl_proto_grantees',
+    'common_job_info',
     'compare_ad_objects_request',
     'compare_ad_objects_result_ad_attribute',
     'compare_ad_objects_result_ad_attribute_value',
     'compare_ad_objects_result_ad_object',
     'compared_ad_object',
+    'component_removal_progress',
+    'compression_enum',
     'compression_policy_enum',
     'compression_policy_vault_enum',
+    'condition',
+    'condition_condition_key_values_map_entry',
+    'condition_key_values',
     'connection_state_enum',
     'connector_parameters',
     'connector_params',
@@ -309,6 +340,7 @@ __all__ = [
     'create_bond_parameters',
     'create_bond_result',
     'create_cloud_cluster_parameters',
+    'create_cloud_domain_migration_parameters',
     'create_cluster_result',
     'create_idp_configuration_request',
     'create_ip_config_parameters',
@@ -328,6 +360,8 @@ __all__ = [
     'cryptsoft_kms_update_params',
     'current_operation_cluster_status_result_enum',
     'current_operation_enum',
+    'custom_tag',
+    'custom_tag_params',
     'custom_unix_id_attributes',
     'dag_application_server_info',
     'dag_info',
@@ -337,14 +371,19 @@ __all__ = [
     'dashboard',
     'dashboard_response',
     'data_disk_type_enum',
+    'data_governance_info',
     'data_lock_config',
     'data_lock_constraints',
     'data_migration_job_parameters',
     'data_migration_policy',
+    'data_protect_info',
     'data_protocol_enum',
+    'data_protocols_enum',
     'data_transfer_from_vault_per_task',
     'data_transfer_from_vault_summary',
     'data_transfer_from_vaults_summary_response',
+    'data_transfer_info',
+    'data_transfer_info_private_network_info',
     'data_transfer_to_vault_per_protection_job',
     'data_transfer_to_vault_summary',
     'data_transfer_to_vaults_summary_response',
@@ -352,10 +391,14 @@ __all__ = [
     'data_usage_stats',
     'database_state_enum',
     'datastore_info',
+    'date_time',
     'day_blackout_period_enum',
     'day_count_enum',
     'day_enum',
     'day_monthly_schedule_enum',
+    'day_time',
+    'day_time_window',
+    'days_enum',
     'db_file_info',
     'db_type_enum',
     'delete_infected_file_params',
@@ -370,12 +413,13 @@ __all__ = [
     'deploy_db_instances_to_rds_params_point_in_time_restore_params',
     'deploy_fleet_params',
     'deploy_task_request',
-    'deploy_v_ms_to_aws_params',
-    'deploy_v_ms_to_azure_params',
-    'deploy_v_ms_to_cloud_params',
-    'deploy_v_ms_to_cloud_task_state_proto',
-    'deploy_v_ms_to_gcp_params',
+    'deploy_vms_to_aws_params',
+    'deploy_vms_to_azure_params',
     'deploy_vms_to_cloud',
+    'deploy_vms_to_cloud_params',
+    'deploy_vms_to_cloud_task_state_proto',
+    'deploy_vms_to_gcp_params',
+    'deploy_vms_to_on_prem_params',
     'desired_wal_location_enum',
     'destroy_clone_app_task_info_proto',
     'destroy_cloned_entity_info_proto',
@@ -408,8 +452,12 @@ __all__ = [
     'download_package_parameters',
     'download_package_result',
     'dse_solar_info',
+    'dse_solr_info',
     'ebs_volume_exclusion_params',
+    'ebs_volume_exclusion_params_tag',
+    'ebs_volume_exclusion_params_tag_params',
     'ebs_volume_info',
+    'ebs_volume_tag',
     'edit_hosts_parameters',
     'elastifile_cluster',
     'elastifile_container',
@@ -417,6 +465,7 @@ __all__ = [
     'email_delivery_target',
     'email_meta_data',
     'encryption_configuration',
+    'encryption_level_enum',
     'encryption_policy_enum',
     'encryption_policy_vault_enum',
     'entity',
@@ -452,7 +501,9 @@ __all__ = [
     'environment_protected_objects_summary_by_env_enum',
     'environment_protection_job_enum',
     'environment_protection_job_request_body_enum',
+    'environment_protection_source_enum',
     'environment_protection_summary_by_env_enum',
+    'environment_protection_trend_enum',
     'environment_register_protection_source_parameters_enum',
     'environment_registered_app_info_enum',
     'environment_registered_source_info_enum',
@@ -467,7 +518,9 @@ __all__ = [
     'environment_snapshot_info_enum',
     'environment_type_job_parameters',
     'environment_vault_provider_stats_by_env_enum',
+    'environments_enum',
     'erasure_coding_info',
+    'error',
     'error_proto',
     'eula_config',
     'ews_to_pst_conversion_params',
@@ -485,13 +538,16 @@ __all__ = [
     'exclude_aws_types_enum',
     'exclude_kubernetes_types_enum',
     'exclude_office_365_type_enum',
+    'exclude_office_365_types_enum',
     'exclude_type_enum',
     'exclude_type_get_protected_objects_summary_enum',
     'expand_cloud_cluster_parameters',
     'expand_physical_cluster_parameters',
     'expiration_action',
+    'export_parameters',
     'extended_retention_policy',
     'extended_retention_policy_proto',
+    'extended_style_enum',
     'external_client_subnets',
     'external_network_info',
     'external_target_type_enum',
@@ -501,9 +557,11 @@ __all__ = [
     'externally_triggered_sbt_parameters',
     'extract_file_range_result',
     'fault_tolerance_level_enum',
+    'feature_flag',
     'feature_usage',
     'file_distribution_metrics',
     'file_distribution_stats',
+    'file_distribution_stats_list',
     'file_extension_filter',
     'file_fstat_result',
     'file_id',
@@ -526,6 +584,8 @@ __all__ = [
     'file_stubbing_params_target_view_data',
     'file_stubbing_params_target_view_map_entry',
     'file_type_enum',
+    'file_uptier_selection_policy_enum',
+    'file_uptier_size_policy_enum',
     'file_uptiering_params',
     'file_uptiering_params_source_view_data',
     'file_uptiering_params_source_view_map_entry',
@@ -539,6 +599,7 @@ __all__ = [
     'filtering_policy_proto',
     'fixed_unix_id_mapping',
     'flag_enum',
+    'flags_enum',
     'flash_blade_file_system',
     'flash_blade_network_interface',
     'flash_blade_nfs_info',
@@ -562,6 +623,8 @@ __all__ = [
     'get_all_job_runs_result',
     'get_consumer_stats_result',
     'get_job_run_info_result',
+    'get_kms_status_response',
+    'get_linux_support_user2fa_result',
     'get_linux_support_user_2fa_result',
     'get_map_reduce_app_runs_params',
     'get_mr_jar_upload_path_result',
@@ -582,6 +645,7 @@ __all__ = [
     'grantee_proto',
     'granular_restore_info',
     'granularity_bucket',
+    'granularity_bucket_exact_dates_info',
     'groot_io_preferential_tier_enum',
     'group',
     'group_backup_env_params',
@@ -594,7 +658,10 @@ __all__ = [
     'h_base_recover_job_params',
     'hadoop_distribution_enum',
     'hardware_info',
+    'hbase_backup_job_params',
     'hbase_connect_params',
+    'hbase_protection_source',
+    'hbase_recover_job_params',
     'hbase_table',
     'hdfs_backup_job_params',
     'hdfs_connect_params',
@@ -624,6 +691,7 @@ __all__ = [
     'hydra_io_preferential_tier_enum',
     'hyper_flex_protection_source',
     'hyperv_backup_env_params',
+    'hyperv_backup_source_params',
     'hyperv_clone_parameters',
     'hyperv_datastore',
     'hyperv_env_job_parameters',
@@ -637,6 +705,7 @@ __all__ = [
     'idp_reachability_test_result',
     'idp_service_configuration',
     'idp_user_info',
+    'import_configurations',
     'index_and_snapshots',
     'indexing_policy',
     'indexing_policy_proto',
@@ -677,8 +746,9 @@ __all__ = [
     'job_policy_proto',
     'job_runs_tile',
     'job_type_enum',
-    'k_8_s_filter_params',
-    'k_8_s_filter_params_label_vec',
+    'k8_s_filter_params',
+    'k8_s_filter_params_label_vec',
+    'k_ms_status_response',
     'key_value_pair',
     'keystone_acl_proto',
     'keystone_acl_proto_grantees',
@@ -706,6 +776,8 @@ __all__ = [
     'last_protection_run_stats',
     'last_protection_run_stats_by_env',
     'last_protection_run_summary',
+    'last_run_status_enum',
+    'last_run_type_enum',
     'last_upgrade_status_enum',
     'latency_thresholds',
     'latest_protection_job_run_info',
@@ -715,6 +787,7 @@ __all__ = [
     'ldap_provider_response',
     'ldap_provider_status',
     'legal_holdings',
+    'librarian_i_o_preferential_tier_enum',
     'librarian_io_preferential_tier_enum',
     'license_account_usage_rsp',
     'license_state',
@@ -738,12 +811,15 @@ __all__ = [
     'lock_file_params',
     'lock_range',
     'locking_protocol_enum',
+    'lockout_reason_enum',
     'lockout_reason_user_enum',
     'logical_stats',
     'logical_volume',
     'logical_volume_type_enum',
+    'm365_teams_channel_info',
     'magneto_instance_id',
     'magneto_object_id',
+    'mailbox_type_enum',
     'map_reduce_aux_data',
     'map_reduce_file_formats',
     'map_reduce_info',
@@ -771,10 +847,14 @@ __all__ = [
     'mode_smb_permission_enum',
     'mongoDB_additional_params',
     'mongoDB_backup_job_params',
+    'mongo_db_additional_params',
+    'mongo_db_backup_job_params',
     'mongo_db_cluster',
     'mongo_db_collection',
     'mongo_db_connect_params',
     'mongo_db_database',
+    'mongo_db_protection_source',
+    'mongo_db_recover_job_params',
     'mongodb_protection_source',
     'mongodb_recover_job_params',
     'monthly_entitlement',
@@ -790,6 +870,9 @@ __all__ = [
     'mount_volumes_task_state_proto',
     'mount_volumes_vmware_params',
     'ms_exchange_params',
+    'multi_stage_restore_action_enum',
+    'multi_stage_restore_finalize_action_params',
+    'multi_stage_restore_task_state_proto',
     'nas_analysis_job_params',
     'nas_analysis_job_params_access_time_bucket',
     'nas_analysis_job_params_file_size_bucket',
@@ -809,6 +892,7 @@ __all__ = [
     'netapp_cluster_info',
     'netapp_protection_source',
     'netapp_type_enum',
+    'netapp_version_tuple',
     'netapp_volume_info',
     'netapp_vserver_info',
     'network_configuration',
@@ -819,18 +903,23 @@ __all__ = [
     'network_pool',
     'network_pool_config',
     'network_pool_range',
+    'network_realm_info',
     'networking_information',
+    'new_s3_secret_access_key',
     'new_s_3_secret_access_key',
     'nfs_access_enum',
     'nfs_connection',
     'nfs_root_permissions',
+    'nfs_security_type_enum',
     'nfs_squash',
+    'nfs_version_number_enum',
     'nfs_version_preference_enum',
     'nimble_protection_source',
     'nimble_type_enum',
     'nis_netgroup',
     'nlm_lock',
     'no_sql_backup_job_params',
+    'no_sql_backup_job_params_immediate_ancestor_map_entry',
     'no_sql_connect_params',
     'no_sql_log_data',
     'no_sql_recover_job_params',
@@ -841,6 +930,7 @@ __all__ = [
     'node',
     'node_hardware_info',
     'node_interface_pair',
+    'node_ipmi_user',
     'node_network_interfaces',
     'node_port',
     'node_stats',
@@ -852,6 +942,8 @@ __all__ = [
     'notification_rule',
     'notifications',
     'ntp_settings_config',
+    'o365_backup_env_params',
+    'o365_connect_params',
     'o365_region_proto',
     'o_365_backup_env_params',
     'object_class_active_directory_principals_add_parameters_enum',
@@ -862,16 +954,27 @@ __all__ = [
     'object_class_search_active_directory_principals_enum',
     'object_class_search_principals_enum',
     'object_information',
+    'object_level_params',
     'object_meta',
     'object_meta_annotations_entry',
     'object_meta_labels_entry',
+    'object_protection_info',
     'object_reference',
     'object_search_results',
     'object_snapshot_info',
     'object_snapshot_type',
     'object_status_enum',
+    'object_type_enum',
     'objects_by_env',
+    'objects_discovery_params',
     'objects_protected_by_policy',
+    'office365_credentials',
+    'office365_env_job_parameters',
+    'office365_protection_source',
+    'office365_site_info',
+    'office365_team_info',
+    'office365_type_enum',
+    'office365_user_info',
     'office_365_credentials',
     'office_365_env_job_parameters',
     'office_365_protection_source',
@@ -881,6 +984,7 @@ __all__ = [
     'office_365_type_enum',
     'office_365_user_info',
     'old_syslog_server',
+    'on_prem_deploy_target',
     'one_drive_backup_env_params',
     'one_drive_document_metadata',
     'one_drive_env_job_parameters',
@@ -890,6 +994,9 @@ __all__ = [
     'one_drive_restore_parameters',
     'open_mode_enum',
     'oracle_app_params',
+    'oracle_archive_log_info',
+    'oracle_archive_log_info_oracle_archive_log_range',
+    'oracle_archive_log_info_oracle_archive_log_range_range_attributes',
     'oracle_backup_job_params',
     'oracle_cloud_credentials',
     'oracle_container_database_info',
@@ -905,6 +1012,7 @@ __all__ = [
     'oracle_host',
     'oracle_pluggable_database_info',
     'oracle_protection_source',
+    'oracle_recovery_validation_info',
     'oracle_sbt_host_params',
     'oracle_session',
     'oracle_source_params',
@@ -923,13 +1031,17 @@ __all__ = [
     'outlook_restore_parameters',
     'output_spec',
     'overusage',
+    'overwrite_policy_enum',
     'overwrite_view_param',
     'owner_info',
+    'ownership_context_enum',
+    'ownership_controls_rule',
     'package_details',
     'pagination_parameters',
     'partition_table_format_enum',
     'pattern',
     'pattern_request_body',
+    'pattern_type_enum',
     'pattern_type_supported_pattern_enum',
     'pdb_entity_info',
     'pdb_restore_param',
@@ -1008,7 +1120,9 @@ __all__ = [
     'privilege_id_enum',
     'privilege_id_user_enum',
     'privilege_id_user_parameters_enum',
+    'privilege_ids_enum',
     'privilege_info',
+    'privileges_type_enum',
     'privileges_type_view_privileges_enum',
     'product_model_interface_tuple',
     'project',
@@ -1017,6 +1131,7 @@ __all__ = [
     'protected_object',
     'protected_object_privileges',
     'protected_objects_by_env',
+    'protected_objects_privileges_type_enum',
     'protected_objects_summary',
     'protected_objects_summary_by_env',
     'protected_objects_tile',
@@ -1068,17 +1183,22 @@ __all__ = [
     'protocol_syslog_server_enum',
     'protocol_view_protocol_stats_enum',
     'protocol_view_stat_info_enum',
+    'protocol_view_stats_enum',
+    'protocols_enum',
     'pst_parameters',
     'public_folder',
     'public_folders_backup_env_params',
     'public_folders_restore_parameters',
     'public_status_cloud_archival_info_enum',
+    'public_status_enum',
     'pure_env_job_parameters',
     'pure_protection_source',
     'pure_storage_array',
     'pure_type_enum',
     'pure_volume',
-    'pvc_data',
+    'put_linux_support_user2fa_params_with_totp',
+    'put_linux_support_user2fa_result',
+    'put_linux_support_user_2fa_params_with_to_tp',
     'pvc_info',
     'pvc_info_pvc_spec',
     'pvc_info_pvc_spec_resources',
@@ -1087,12 +1207,15 @@ __all__ = [
     'qo_s',
     'qo_s_policy',
     'qos_tier_app_instance_settings_enum',
+    'qos_tier_enum',
     'qos_type_enum',
     'qos_type_rpo_policy_settings_enum',
     'quota_and_usage_in_view',
     'quota_policy',
     'random_io_preferential_tier_enum',
+    'ransomware_info',
     'rds_params',
+    'reboot_status_enum',
     'recover_disks_task_state_proto',
     'recover_task_request',
     'recover_virtual_disk_info_proto',
@@ -1113,6 +1236,7 @@ __all__ = [
     'register_remote_cluster',
     'registered_app_info',
     'registered_application_server',
+    'registered_entity_sfdc_params',
     'registered_protection_source_isilon_params',
     'registered_source_info',
     'registering_app_enum',
@@ -1135,7 +1259,9 @@ __all__ = [
     'remote_view_config',
     'removal_reason_enum',
     'removal_reason_node_enum',
+    'removal_state_cluster_status_result_enum',
     'removal_state_enum',
+    'removal_state_kms_configuration_response_enum',
     'removal_state_node_enum',
     'removal_state_vault_enum',
     'removal_state_view_box_enum',
@@ -1150,11 +1276,13 @@ __all__ = [
     'replication_target_settings',
     'request_error',
     'required_privileges_enum',
+    'reset_s3_secret_key_parameters',
     'reset_s_3_secret_key_parameters',
-    'restore_acropolis_v_ms_params',
     'restore_acropolis_vm_param',
     'restore_acropolis_vm_param_network_config_info',
+    'restore_acropolis_vm_param_network_config_info_n_i_c_spec',
     'restore_acropolis_vm_param_network_config_info_nic_spec',
+    'restore_acropolis_vms_params',
     'restore_ad_app_object_params',
     'restore_ad_guid_pair',
     'restore_app_object',
@@ -1179,7 +1307,18 @@ __all__ = [
     'restore_info_proto',
     'restore_info_proto_restore_entity',
     'restore_kubernetes_namespaces_params',
+    'restore_kvm_vms_params',
     'restore_kvmv_ms_params',
+    'restore_o365_groups_params',
+    'restore_o365_groups_params_group_granular_params',
+    'restore_o365_groups_params_ms_group_info',
+    'restore_o365_public_folders_params',
+    'restore_o365_public_folders_params_public_folder',
+    'restore_o365_public_folders_params_root_public_folder',
+    'restore_o365_teams_params',
+    'restore_o365_teams_params_ms_team_info',
+    'restore_o365_teams_params_source_channel',
+    'restore_o365_teams_params_target_channel',
     'restore_o_365_groups_params',
     'restore_o_365_groups_params_group_granular_params',
     'restore_o_365_groups_params_ms_group_info',
@@ -1209,6 +1348,7 @@ __all__ = [
     'restore_site_params_site_owner',
     'restore_site_params_site_owner_drive',
     'restore_source_summary_by_object_type_element',
+    'restore_spfile_or_pfile_info',
     'restore_sql_app_object_params',
     'restore_standby_task_state_proto',
     'restore_stats',
@@ -1216,6 +1356,7 @@ __all__ = [
     'restore_task_additional_params',
     'restore_task_state_base_proto',
     'restore_task_wrapper',
+    'restore_vapp_info',
     'restore_vlan_params',
     'restore_vmware_vm_params',
     'restore_wrapper_proto',
@@ -1233,6 +1374,7 @@ __all__ = [
     'role_create_ip_config_parameters_enum',
     'role_create_parameters',
     'role_delete_parameters',
+    'role_enum',
     'role_network_interface_enum',
     'role_oracle_data_guard_info_enum',
     'role_update_parameters',
@@ -1256,6 +1398,8 @@ __all__ = [
     's3_access_enum',
     's3_bucket_config_proto',
     's3_bucket_config_proto_tag_map_entry',
+    's3_bucket_info',
+    's3_key_mapping_config_enum',
     's3_view_backup_properties',
     's_3_key_mapping_config_create_view_request_enum',
     's_3_key_mapping_config_enum',
@@ -1264,6 +1408,7 @@ __all__ = [
     'san_env_job_parameters',
     'san_storage_array',
     'san_volume',
+    'schedule_type_enum',
     'scheduler_proto',
     'scheduler_proto_scheduler_job',
     'scheduler_proto_scheduler_job_schedule',
@@ -1271,12 +1416,18 @@ __all__ = [
     'scheduler_proto_scheduler_job_schedule__report',
     'scheduler_proto_scheduler_job_schedule__report_parameters',
     'scheduler_proto_scheduler_job_schedule_job_parameters',
+    'scheduler_proto_scheduler_job_schedule_job_parameters_report_job_parameter',
+    'scheduler_proto_scheduler_job_schedule_job_parameters_report_job_parameter_report',
+    'scheduler_proto_scheduler_job_schedule_job_parameters_report_job_parameter_report_parameters',
     'scheduling_policy',
     'scheduling_policy_proto',
     'scheduling_policy_proto_continuous_schedule',
     'scheduling_policy_proto_daily_schedule',
+    'scheduling_policy_proto_date_schedule',
     'scheduling_policy_proto_monthly_schedule',
     'scheduling_policy_proto_rpo_schedule',
+    'scheduling_policy_proto_rposchedule',
+    'scheduling_policy_proto_yearly_schedule',
     'schema_info',
     'scribe_io_preferential_tier_enum',
     'script_execution_status',
@@ -1285,6 +1436,7 @@ __all__ = [
     'search_job_status_remote_vault_search_job_results_enum',
     'search_production_ad_objects_request',
     'search_result_flag_enum',
+    'search_result_flags_enum',
     'security_mode_enum',
     'send_snmp_test_trap_result',
     'sequence_number',
@@ -1301,20 +1453,34 @@ __all__ = [
     'service_network_interface_enum',
     'service_process_entry',
     'service_service_state_result_enum',
+    'service_state_enum',
     'service_state_result',
+    'services_enum',
     'session_user',
     'setup_restore_disk_task_info_proto',
+    'severities_enum',
     'severity_enum',
     'severity_notification_rule_enum',
+    'sfdc_backup_job_params',
+    'sfdc_backup_source_params_proto',
+    'sfdc_object',
+    'sfdc_org',
+    'sfdc_protection_source',
+    'sfdc_recover_job_params',
+    'sfdc_recover_params',
+    'sfdc_restore_object',
+    'sfdc_restore_object_params',
     'share',
     'share_point_restore_parameters',
     'share_type_enum',
     'sharep_point_site_backup_env_params',
+    'sharepoint_backup_source_params',
     'sharepoint_document_metadata',
     'show_system_led_info_parameters',
     'show_system_led_info_result',
     'site_backup_file',
     'site_backup_status',
+    'site_continuity_info',
     'site_drive_info',
     'site_drive_item',
     'site_identity',
@@ -1370,13 +1536,18 @@ __all__ = [
     'state_bulk_install_app_task_info_enum',
     'state_enum',
     'state_license_state_enum',
+    'state_netapp_volume_info_enum',
     'state_service_state_result_enum',
+    'state_tenant_deletion_info_enum',
     'state_update_app_instance_state_parameters_enum',
+    'statement',
     'static_route',
     'stats_group',
+    'status_agent_information_enum',
     'status_app_entity_backup_status_info_enum',
     'status_backup_run_enum',
     'status_cloud_archival_info_enum',
+    'status_common_job_info_enum',
     'status_copy_run_enum',
     'status_copy_snapshot_task_status_enum',
     'status_dag_application_server_info_enum',
@@ -1384,12 +1555,18 @@ __all__ = [
     'status_exchange_host_info_enum',
     'status_get_protection_runs_stats_enum',
     'status_get_tenants_enum',
+    'status_protection_shell_info_enum',
     'status_restore_task_enum',
     'status_source_backup_status_enum',
     'status_task_enum',
     'status_task_notification_enum',
     'stop_remote_vault_search_job_parameters',
     'stopped_service_enum',
+    'stopped_services_enum',
+    'storage_array_snapshot_config_params',
+    'storage_array_snapshot_max_snapshot_config_params',
+    'storage_array_snapshot_max_space_config_params',
+    'storage_array_snapshot_throttling_policy',
     'storage_domain_stats',
     'storage_efficiency_tile',
     'storage_policy',
@@ -1400,6 +1577,7 @@ __all__ = [
     'stubbing_policy_proto',
     'style_enum',
     'subnet',
+    'subscription_info',
     'subscription_type_azure_credentials_enum',
     'subscription_type_azure_protection_source_enum',
     'subscription_type_enum',
@@ -1409,6 +1587,7 @@ __all__ = [
     'swift_params',
     'syslog_server',
     'system_app_status_result',
+    'table_type_enum',
     'tag_attribute',
     'tag_enum',
     'tags_operation_parameters',
@@ -1421,8 +1600,10 @@ __all__ = [
     'task_notification',
     'task_state_enum',
     'task_type_enum',
+    'teams_backup_env_params',
     'tear_down_status_enum',
     'tenant',
+    'tenant_access',
     'tenant_active_directory_update',
     'tenant_active_directory_update_parameters',
     'tenant_config',
@@ -1454,12 +1635,15 @@ __all__ = [
     'throttling_configuration',
     'throttling_policy_override',
     'throttling_policy_parameters',
+    'throttling_window',
     'throughput_tile',
+    'tier_type_amazon_cloud_credentials_enum',
     'tier_type_azure_cloud_credentials_enum',
     'tier_type_enum',
     'tier_type_google_cloud_credentials_enum',
     'tier_type_oracle_cloud_credentials_enum',
     'tiering_audit_log_configuration',
+    'tiering_info',
     'tiering_task_info',
     'tile_types_enum',
     'time',
@@ -1497,6 +1681,7 @@ __all__ = [
     'type_isilon_protection_source_enum',
     'type_kubernetes_protection_source_enum',
     'type_kvm_protection_source_enum',
+    'type_mongo_db_protection_source_enum',
     'type_mongodb_protection_source_enum',
     'type_nas_protection_source_enum',
     'type_netapp_protection_source_enum',
@@ -1504,6 +1689,7 @@ __all__ = [
     'type_netapp_vserver_info_enum',
     'type_network_interface_enum',
     'type_nimble_protection_source_enum',
+    'type_office365_protection_source_enum',
     'type_office_365_protection_source_enum',
     'type_oracle_data_guard_info_enum',
     'type_oracle_protection_source_enum',
@@ -1519,6 +1705,7 @@ __all__ = [
     'type_restore_task_enum',
     'type_run_job_snapshot_target_enum',
     'type_scheduler_proto_scheduler_job_enum',
+    'type_sfdc_protection_source_enum',
     'type_smb_permission_enum',
     'type_snapshot_target_settings_enum',
     'type_sql_protection_source_enum',
@@ -1530,12 +1717,16 @@ __all__ = [
     'type_vm_dir_entry_enum',
     'type_vmware_protection_source_enum',
     'uda_backup_job_params',
+    'uda_backup_job_params_backup_job_arguments_map_entry',
     'uda_cluster',
     'uda_connect_params',
+    'uda_custom_argument',
     'uda_object',
     'uda_objects',
     'uda_protection_source',
     'uda_recover_job_params',
+    'uda_recover_job_params_restore_job_arguments_map_entry',
+    'uda_recover_job_params_source_arguments_map_entry',
     'uda_recover_params',
     'uda_restore_object',
     'uda_restore_object_params',
@@ -1575,6 +1766,7 @@ __all__ = [
     'update_protection_object_parameters',
     'update_protection_source_parameters',
     'update_resolution_params',
+    'update_restore_task_options',
     'update_restore_task_params',
     'update_sources_for_principals_params',
     'update_trusted_domain_enable_params',
@@ -1612,7 +1804,10 @@ __all__ = [
     'user_quota_summary_for_user',
     'user_quota_summary_for_view',
     'user_ssh_key',
+    'users_discovery_params',
     'uuid_config_proto',
+    'v_mware_tools_running_status_enum',
+    'v_mware_type_enum',
     'value',
     'value_data',
     'value_type_enum',
@@ -1631,6 +1826,8 @@ __all__ = [
     'vault_run_stats_summary',
     'vault_stats',
     'vault_stats_info',
+    'vault_type_archival_external_target_enum',
+    'vault_type_cloud_archival_info_enum',
     'vault_type_data_transfer_to_vault_summary_enum',
     'vault_type_enum',
     'vault_type_vault_provider_stats_info_enum',
@@ -1645,17 +1842,23 @@ __all__ = [
     'view_box_stats',
     'view_id_mapping_proto_file_level_data_lock_config',
     'view_id_mapping_proto_protocol_access_info',
+    'view_intent',
     'view_params',
     'view_privileges',
     'view_protection',
     'view_protection_source',
     'view_protocol_stats',
+    'view_protocol_stats_list',
     'view_stat_info',
     'view_stats',
+    'view_stats_in_last_hours',
+    'view_stats_info',
     'view_stats_snapshot',
     'view_time_series_stats',
+    'view_time_series_stats_list',
     'view_user_quota_parameters',
     'view_user_quotas',
+    'virtual_disk_config',
     'virtual_disk_id',
     'virtual_disk_id_information',
     'virtual_disk_info',
@@ -1680,6 +1883,7 @@ __all__ = [
     'vm_num_replicas',
     'vm_volumes_information',
     'vmware_backup_env_params',
+    'vmware_backup_env_params_vapp_child_vms_list',
     'vmware_backup_source_params',
     'vmware_cdp_protection_source_info',
     'vmware_clone_parameters',
@@ -1691,6 +1895,7 @@ __all__ = [
     'vmware_restore_parameters',
     'vmware_special_parameters',
     'vmware_standby_resource',
+    'vmware_tools_running_status_enum',
     'vmware_type_enum',
     'volume_info',
     'volume_info_disk_info',
