@@ -1,30 +1,33 @@
 # -*- coding: utf-8 -*-
-# Copyright 2022 Cohesity Inc.
+# Copyright 2023 Cohesity Inc.
 
 import cohesity_management_sdk.models.ad_domain_controller
 
+
 class AdProtectionSource(object):
 
     """Implementation of the 'AdProtectionSource' model.
 
     Specifies an object representing an AD entity.
 
+
     Attributes:
-        domain_controller (AdDomainController): Specifies information about an
-            AD domain controller.
+
+        domain_controller (AdDomainController): Specifies the domain controller
+            residing in this physical machine.
         domain_name (string): Specifies the domain name corresponding to the
             domain controller.
         name (string): Specifies the domain name of the AD entity.
         owner_id (long|int): Specifies the entity id of the owner entity.
         mtype (TypeAdProtectionSourceEnum): Specifies the type of the managed
-            object in AD Protection Source. Specifies the kind of AD
-            protection source. 'kRootContainer' indicates the entity is a root
-            container to an AD domain controller. 'kDomainController'
-            indicates the domain controller hosted in this physical server.
+            object in AD Protection Source. Specifies the kind of AD protection
+            source. 'kRootContainer' indicates the entity is a root container
+            to an AD domain controller. 'kDomainController' indicates the
+            domain controller hosted in this physical server.
         uuid (string): Specifies the UUID for the AD entity.
-
     """
 
+
     # Create a mapping from Model property names to API property names
     _names = {
         "domain_controller":'domainController',
@@ -32,16 +35,17 @@ class AdProtectionSource(object):
         "name":'name',
         "owner_id":'ownerId',
         "mtype":'type',
-        "uuid":'uuid'
+        "uuid":'uuid',
     }
-
     def __init__(self,
                  domain_controller=None,
                  domain_name=None,
                  name=None,
                  owner_id=None,
                  mtype=None,
-                 uuid=None):
+                 uuid=None,
+            ):
+
         """Constructor for the AdProtectionSource class"""
 
         # Initialize members of the class
@@ -52,7 +56,6 @@ class AdProtectionSource(object):
         self.mtype = mtype
         self.uuid = uuid
 
-
     @classmethod
     def from_dictionary(cls,
                         dictionary):
@@ -79,11 +82,11 @@ class AdProtectionSource(object):
         uuid = dictionary.get('uuid')
 
         # Return an object of this model
-        return cls(domain_controller,
-                   domain_name,
-                   name,
-                   owner_id,
-                   mtype,
-                   uuid)
-
-
+        return cls(
+            domain_controller,
+            domain_name,
+            name,
+            owner_id,
+            mtype,
+            uuid
+)
\ No newline at end of file
