@@ -1,14 +1,13 @@
 # -*- coding: utf-8 -*-
-# Copyright 2022 Cohesity Inc.
+# Copyright 2023 Cohesity Inc.
 
 class AddressFamilyEnum(object):
 
     """Implementation of the 'AddressFamily' enum.
+    Specifies the enum for the IP address families. 'kUnknown' indicates IP
+    address families are unknown. 'kIPv4' indicates IP addresses used are from
+    IPv4 family. 'kIPv6' indicates IP addresses used are from IPv6 family.
 
-    Specifies the enum for the IP address families.
-    'kUnknown' indicates IP address families are unknown.
-    'kIPv4' indicates IP addresses used are from IPv4 family.
-    'kIPv6' indicates IP addresses used are from IPv6 family.
 
     Attributes:
         KUNKNOWN: TODO: type description here.
@@ -16,9 +15,9 @@ class AddressFamilyEnum(object):
         KIPV6: TODO: type description here.
 
     """
+
     KUNKNOWN = 'kUnknown'
 
     KIPV4 = 'kIPv4'
 
     KIPV6 = 'kIPv6'
-
