@@ -1,46 +1,39 @@
 # -*- coding: utf-8 -*-
-# Copyright 2022 Cohesity Inc.
+# Copyright 2023 Cohesity Inc.
 
 class AlertCategoryEnum(object):
 
     """Implementation of the 'AlertCategory' enum.
-
-    Specifies the category of an Alert.
-    kDisk - Alert associated with the disk.
-    kNode - Alert associated with general hardware on a specific node.
-    kCluster - Alert associated with general hardware in cluster level.
-    kChassis - Alert associated with the Chassis.
-    kPowerSupply - Alert associated with the power supply.
-    kCPU - Alert associated with the CPU usage.
-    kMemory - Alert associated with the RAM/Memory.
-    kTemperature - Alert associated with the temperature.
-    kFan - Alert associated with the fan.
-    kNIC - Alert associated with network chips and interfaces.
-    kFirmware - Alert associated with the firmware.
-    kNodeHealth - Alert associated with node health status.
-    kOperatingSystem - Alert associated with operating systems.
-    kDataPath - Alert associated with data management in the cluster.
-    kMetadata - Alert associated with metadata management.
-    kIndexing - Alert associated with indexing services.
-    kHelios - Alert associated with Helios.
-    kAppMarketPlace - Alert associated with App MarketPlace.
-    kLicense - Alert associated with licensing.
-    kSecurity - Alert associated with security.
-    kUpgrade - Alert associated with upgrade activities.
-    kClusterManagement - Alert associated with cluster management activities.
-    kAuditLog - Alert associated with audit log events.
-    kNetworking - Alert associated with networking issue.
+    Specifies the category of an Alert. kDisk - Alert associated with the disk.
+    kNode - Alert associated with general hardware on a specific node. kCluster
+    - Alert associated with general hardware in cluster level. kChassis - Alert
+    associated with the Chassis. kPowerSupply - Alert associated with the power
+    supply. kCPU - Alert associated with the CPU usage. kMemory - Alert
+    associated with the RAM/Memory. kTemperature - Alert associated with the
+    temperature. kFan - Alert associated with the fan. kNIC - Alert associated
+    with network chips and interfaces. kFirmware - Alert associated with the
+    firmware. kNodeHealth - Alert associated with node health status.
+    kOperatingSystem - Alert associated with operating systems. kDataPath -
+    Alert associated with data management in the cluster. kMetadata - Alert
+    associated with metadata management. kIndexing - Alert associated with
+    indexing services. kHelios - Alert associated with Helios. kAppMarketPlace
+    - Alert associated with App MarketPlace. kLicense - Alert associated with
+    licensing. kSecurity - Alert associated with security. kUpgrade - Alert
+    associated with upgrade activities. kClusterManagement - Alert associated
+    with cluster management activities. kAuditLog - Alert associated with audit
+    log events. kNetworking - Alert associated with networking issue.
     kConfiguration - Alert associated with cluster or system configurations.
-    kStorageUsage - Alert associated with the disk/domain/cluster storage usage.
-    kFaultTolerance - Alert associated with the fault tolerance in different levels.
-    kBackupRestore - Alert associated with Backup-Restore job.
-    kArchivalRestore - Alert associated with Archival-Restore job.
-    kRemoteReplication - Alert associated with Replication job.
-    kQuota - Alert associated with Quotas.
-    kCDP - Alert associated with Continuous Data Protection.
+    kStorageUsage - Alert associated with the disk/domain/cluster storage
+    usage. kFaultTolerance - Alert associated with the fault tolerance in
+    different levels. kBackupRestore - Alert associated with Backup-Restore
+    job. kArchivalRestore - Alert associated with Archival-Restore job.
+    kRemoteReplication - Alert associated with Replication job. kQuota - Alert
+    associated with Quotas. kCDP - Alert associated with Continuous Data
+    Protection. kViewFailover - Alert associated with view Failover.
+    kDisasterRecovery - Alert associated with Disaster Recovery.
+
 
     Attributes:
-
         KDISK: TODO: type description here.
         KNODE: TODO: type description here.
         KCLUSTER: TODO: type description here.
@@ -73,7 +66,11 @@ class AlertCategoryEnum(object):
         KREMOTEREPLICATION: TODO: type description here.
         KQUOTA: TODO: type description here.
         KCDP: TODO: type description here.
+        KVIEWFAILOVER: TODO: type description here.
+        KDISASTERRECOVERY: TODO: type description here.
+
     """
+
     KDISK = 'kDisk'
 
     KNODE = 'kNode'
@@ -137,3 +134,7 @@ class AlertCategoryEnum(object):
     KQUOTA = 'kQuota'
 
     KCDP = 'kCDP'
+
+    KVIEWFAILOVER = 'kViewFailover'
+
+    KDISASTERRECOVERY = 'kDisasterRecovery'
