@@ -1,5 +1,5 @@
 # -*- coding: utf-8 -*-
-# Copyright 2021 Cohesity Inc.
+# Copyright 2023 Cohesity Inc.
 
 class AlertCategoryListEnum(object):
 
@@ -38,6 +38,10 @@ class AlertCategoryListEnum(object):
     kArchivalRestore - Alert associated with Archival-Restore job.
     kRemoteReplication - Alert associated with Replication job.
     kQuota - Alert associated with Quotas.
+    kCDP - Alert associated with Continuous Data Protection.
+    kViewFailover - Alert associated with view Failover.
+    kDisasterRecovery - Alert associated with Disaster Recovery.
+
 
     Attributes:
     KDISK: TODO: type description here.
@@ -71,6 +75,10 @@ class AlertCategoryListEnum(object):
     KARCHIVALRESTORE: TODO: type description here.
     KREMOTEREPLICATION: TODO: type description here.
     KQUOTA: TODO: type description here.
+    KCDP: TODO: type description here.
+    KVIEWFAILOVER: TODO: type description here.
+    KDISASTERRECOVERY: TODO: type description here.
+
 
     """
 
@@ -134,4 +142,11 @@ class AlertCategoryListEnum(object):
 
     KREMOTEREPLICATION = 'kRemoteReplication'
 
-    KQUOTA = 'kQuota'
\ No newline at end of file
+    KQUOTA = 'kQuota'
+
+    KCDP = 'kCDP'
+
+    KVIEWFAILOVER = 'kViewFailover'
+
+    KDISASTERRECOVERY = 'kDisasterRecovery'
+
