@@ -1,35 +1,37 @@
 # -*- coding: utf-8 -*-
-# Copyright 2022 Cohesity Inc.
-
+# Copyright 2023 Cohesity Inc.
 
 class AnalysisTaskInfo(object):
 
     """Implementation of the 'AnalysisTaskInfo' model.
 
-    Parameters for a analysis op.
+    TODO: type description here.
+
 
     Attributes:
+
         instance_id (string): Id of that particular instance.
         name (string): Name of the recovery task.
-        start_time_usecs (string): Denotes the start time of the
-            tieringtask, needed for deeplinking.
+        start_time_usecs (string): Denotes the start time of the tieringtask,
+            needed for deeplinking.
         task_id (string): Id of the recovery task.
-
     """
 
+
     # Create a mapping from Model property names to API property names
     _names = {
         "instance_id":'instanceId',
         "name":'name',
         "start_time_usecs":'startTimeUsecs',
-        "task_id":'taskId'
+        "task_id":'taskId',
     }
-
     def __init__(self,
                  instance_id=None,
                  name=None,
                  start_time_usecs=None,
-                 task_id=None):
+                 task_id=None,
+            ):
+
         """Constructor for the AnalysisTaskInfo class"""
 
         # Initialize members of the class
@@ -38,7 +40,6 @@ class AnalysisTaskInfo(object):
         self.start_time_usecs = start_time_usecs
         self.task_id = task_id
 
-
     @classmethod
     def from_dictionary(cls,
                         dictionary):
@@ -63,9 +64,9 @@ class AnalysisTaskInfo(object):
         task_id = dictionary.get('taskId')
 
         # Return an object of this model
-        return cls(instance_id,
-                   name,
-                   start_time_usecs,
-                   task_id)
-
-
+        return cls(
+            instance_id,
+            name,
+            start_time_usecs,
+            task_id
+)
\ No newline at end of file
