@@ -1,21 +1,23 @@
 # -*- coding: utf-8 -*-
-# Copyright 2021 Cohesity Inc.
+# Copyright 2023 Cohesity Inc.
 
+import cohesity_management_sdk.models.external_network_info
 import cohesity_management_sdk.models.protected_object_privileges
 import cohesity_management_sdk.models.view_privileges
-import cohesity_management_sdk.models.external_network_info
 import cohesity_management_sdk.models.vm_num_replicas
 
+
 class AppInstanceSettings(object):
 
     """Implementation of the 'AppInstanceSettings' model.
 
-    AppInstanceSettings provides settings used while launching an app
-    instance.
+    AppInstanceSettings provides settings used while launching an app instance.
     Current settings include QoSTier to be used for the instance and views
     allowed to be accessed by the instance.
 
+
     Attributes:
+
         external_network_info (ExternalNetworkInfo): External network
             information of the app instance.
         instance_size (string): Instance size specification (e.g.
@@ -23,24 +25,20 @@ class AppInstanceSettings(object):
         protected_object_privileges (ProtectedObjectPrivileges): Specifies
             which protected objects are allowed to be accessed by an app
             instance.
-        qos_tier (QosTierAppInstanceSettingsEnum):  Specifies QoSTier of the
-            app instance.
-            Specifies QoS Tier for an app instance. App instances are
-            allocated resources such as memory, CPU and IO based on their QoS
-            Tier.
-            kLow - Low QoS Tier.
-            kMedium - Medium QoS Tier.
-            kHigh - High QoS Tier.
+        qos_tier (QosTierEnum): Specifies QoSTier of the app instance.
+            Specifies QoS Tier for an app instance. App instances are allocated
+            resources such as memory, CPU and IO based on their QoS Tier. kLow
+            - Low QoS Tier. kMedium - Medium QoS Tier. kHigh - High QoS Tier.
             kMax - Max QoS Tier.
         read_view_privileges (ViewPrivileges): Specifies views allowed to be
             accessed in read only mode by the app instance.
-        read_write_view_privileges (ViewPrivileges): Specifies views allowed
-            to be accessed in read/write mode by the app instance.
-        vm_num_replicas_list(list of VmNumReplicas): List of vm-name,
-            replica count pairs to be used at the time of app instance launch.
-
+        read_write_view_privileges (ViewPrivileges): Specifies views allowed to
+            be accessed in read/write mode by the app instance.
+        vm_num_replicas_list (list of VmNumReplicas): List of vm-name, replica
+            count pairs to be used at the time of app instance launch.
     """
 
+
     # Create a mapping from Model property names to API property names
     _names = {
         "external_network_info":'externalNetworkInfo',
@@ -49,9 +47,8 @@ class AppInstanceSettings(object):
         "qos_tier":'qosTier',
         "read_view_privileges":'readViewPrivileges',
         "read_write_view_privileges":'readWriteViewPrivileges',
-        "vm_num_replicas_list":'vmNumReplicasList'
+        "vm_num_replicas_list":'vmNumReplicasList',
     }
-
     def __init__(self,
                  external_network_info=None,
                  instance_size=None,
@@ -59,7 +56,9 @@ class AppInstanceSettings(object):
                  qos_tier=None,
                  read_view_privileges=None,
                  read_write_view_privileges=None,
-                 vm_num_replicas_list=None):
+                 vm_num_replicas_list=None,
+            ):
+
         """Constructor for the AppInstanceSettings class"""
 
         # Initialize members of the class
@@ -71,7 +70,6 @@ class AppInstanceSettings(object):
         self.read_write_view_privileges = read_write_view_privileges
         self.vm_num_replicas_list = vm_num_replicas_list
 
-
     @classmethod
     def from_dictionary(cls,
                         dictionary):
@@ -103,12 +101,12 @@ class AppInstanceSettings(object):
                 vm_num_replicas_list.append(cohesity_management_sdk.models.vm_num_replicas.VmNumReplicas.from_dictionary(structure))
 
         # Return an object of this model
-        return cls(external_network_info,
-                   instance_size,
-                   protected_object_privileges,
-                   qos_tier,
-                   read_view_privileges,
-                   read_write_view_privileges,
-                   vm_num_replicas_list)
-
-
+        return cls(
+            external_network_info,
+            instance_size,
+            protected_object_privileges,
+            qos_tier,
+            read_view_privileges,
+            read_write_view_privileges,
+            vm_num_replicas_list
+)
\ No newline at end of file
