@@ -1,12 +1,12 @@
 # -*- coding: utf-8 -*-
-# Copyright 2022 Cohesity Inc.
+# Copyright 2023 Cohesity Inc.
 
-class AthenaIOPreferentialTierEnum(object):
-
-    """Implementation of the 'AthenaIOPreferentialTier' enum.
+class AthenaIoPreferentialTierEnum(object):
 
+    """Implementation of the 'AthenaIoPreferentialTier' enum.
     Specifies the list of perferred storage tiers used by Athena.
 
+
     Attributes:
         KPCIESSD: TODO: type description here.
         KSATASSD: TODO: type description here.
@@ -22,4 +22,3 @@ class AthenaIOPreferentialTierEnum(object):
     KSATAHDD = 'kSataHdd'
 
     KCLOUD = 'kCloud'
-
