@@ -1,36 +1,40 @@
 # -*- coding: utf-8 -*-
-# Copyright 2022 Cohesity Inc.
+# Copyright 2023 Cohesity Inc.
 
 import cohesity_management_sdk.models.backup_job_proto_remote_view_params_remote_view_params_per_view
 
+
 class BackupJobProto_RemoteViewParams_RemoteViewMapEntry(object):
 
     """Implementation of the 'BackupJobProto_RemoteViewParams_RemoteViewMapEntry' model.
 
+    TODO: type description here.
+
 
     Attributes:
-        key (long|int): TODO:Type description here.
-        value (BackupJobProto_RemoteViewParams_RemoteViewParamsPerView):
-            TODO:Type description here.
 
+        key (long|int): TODO: Type description here.
+        value (BackupJobProto_RemoteViewParams_RemoteViewParamsPerView): TODO:
+            Type description here.
     """
 
+
     # Create a mapping from Model property names to API property names
     _names = {
-        "key": 'key',
-        "value": 'value'
+        "key":'key',
+        "value":'value',
     }
-
     def __init__(self,
                  key=None,
-                 value=None):
+                 value=None,
+            ):
+
         """Constructor for the BackupJobProto_RemoteViewParams_RemoteViewMapEntry class"""
 
         # Initialize members of the class
         self.key = key
         self.value = value
 
-
     @classmethod
     def from_dictionary(cls,
                         dictionary):
@@ -53,7 +57,7 @@ class BackupJobProto_RemoteViewParams_RemoteViewMapEntry(object):
         value = cohesity_management_sdk.models.backup_job_proto_remote_view_params_remote_view_params_per_view.BackupJobProto_RemoteViewParams_RemoteViewParamsPerView.from_dictionary(dictionary.get('value')) if dictionary.get('value') else None
 
         # Return an object of this model
-        return cls(key,
-                   value)
-
-
+        return cls(
+            key,
+            value
+)
\ No newline at end of file
