@@ -1,47 +1,44 @@
 # -*- coding: utf-8 -*-
-# Copyright 2022 Cohesity Inc.
+# Copyright 2023 Cohesity Inc.
 
 import cohesity_management_sdk.models.time
 
-class BackupPolicyProtoExclusionTimeRange(object):
+
+class BackupPolicyProto_ExclusionTimeRange(object):
 
     """Implementation of the 'BackupPolicyProto_ExclusionTimeRange' model.
 
     A proto to specify a time range within a single day when backups are not
     permitted to run.
 
-    Attributes:
-        day (int): If the day is not set, the time range applies to all days.
-        end_time (Time): A message to encapusulate time of a day. Users of
-            this proto will have to store the timezone information separately.
-            For example, when this proto is part of a backup job, timezone of
-            the backup job is applied to get the absolute time.
-        start_time (Time): A message to encapusulate time of a day. Users of
-            this proto will have to store the timezone information separately.
-            For example, when this proto is part of a backup job, timezone of
-            the backup job is applied to get the absolute time.
 
+    Attributes:
+
+        day (int): If the day is not set, the time range applies to all days.
+        end_time (Time): End time of the time range.
+        start_time (Time): Start time of the time range.
     """
 
+
     # Create a mapping from Model property names to API property names
     _names = {
         "day":'day',
         "end_time":'endTime',
-        "start_time":'startTime'
+        "start_time":'startTime',
     }
-
     def __init__(self,
                  day=None,
                  end_time=None,
-                 start_time=None):
-        """Constructor for the BackupPolicyProtoExclusionTimeRange class"""
+                 start_time=None,
+            ):
+
+        """Constructor for the BackupPolicyProto_ExclusionTimeRange class"""
 
         # Initialize members of the class
         self.day = day
         self.end_time = end_time
         self.start_time = start_time
 
-
     @classmethod
     def from_dictionary(cls,
                         dictionary):
@@ -65,8 +62,8 @@ class BackupPolicyProtoExclusionTimeRange(object):
         start_time = cohesity_management_sdk.models.time.Time.from_dictionary(dictionary.get('startTime')) if dictionary.get('startTime') else None
 
         # Return an object of this model
-        return cls(day,
-                   end_time,
-                   start_time)
-
-
+        return cls(
+            day,
+            end_time,
+            start_time
+)
\ No newline at end of file
