@@ -1,41 +1,50 @@
 # -*- coding: utf-8 -*-
-# Copyright 2021 Cohesity Inc.
+# Copyright 2023 Cohesity Inc.
+
+import cohesity_management_sdk.models.interface_stats
 import cohesity_management_sdk.models.uplink_switch_info
 
+
 class BondSlaveInfo(object):
 
     """Implementation of the 'BondSlaveInfo' model.
 
-    Specifies the AMQP target config.
+    TODO: type description here.
+
 
     Attributes:
-        link_state (string): Bond slave link state.
-        mac_addr (string): Mac address of the bond slave interface.
-        name (string): Bond slave name.
-        slot (string): Bond slaves slot info.
-        speed (string): Bond slave Speed.
-        uplink_switch_info (UplinkSwitchInfo): Bond slave uplink switch info.
 
+        link_state (string): Bond seocondary link state.
+        mac_addr (string): Mac address of the bond secondary interface.
+        name (string): Bond secondary name.
+        slot (string): Bond seocondarys slot info.
+        speed (string): Bond seocondary Speed.
+        stats (InterfaceStats): Interface Stats.
+        uplink_switch_info (UplinkSwitchInfo): Bond secondary uplink switch
+            info.
     """
 
+
     # Create a mapping from Model property names to API property names
     _names = {
-        "link_state": 'linkState',
-        "mac_addr": 'macAddr',
+        "link_state":'linkState',
+        "mac_addr":'macAddr',
         "name":'name',
         "slot":'slot',
         "speed":'speed',
-        "uplink_switch_info":'uplinkSwitchInfo'
+        "stats":'stats',
+        "uplink_switch_info":'uplinkSwitchInfo',
     }
-
     def __init__(self,
                  link_state=None,
                  mac_addr=None,
                  name=None,
                  slot=None,
                  speed=None,
-                 uplink_switch_info=None
-                 ):
+                 stats=None,
+                 uplink_switch_info=None,
+            ):
+
         """Constructor for the BondSlaveInfo class"""
 
         # Initialize members of the class
@@ -44,6 +53,7 @@ class BondSlaveInfo(object):
         self.name = name
         self.slot = slot
         self.speed = speed
+        self.stats = stats
         self.uplink_switch_info = uplink_switch_info
 
     @classmethod
@@ -69,14 +79,16 @@ class BondSlaveInfo(object):
         name = dictionary.get('name')
         slot = dictionary.get('slot')
         speed = dictionary.get('speed')
+        stats = cohesity_management_sdk.models.interface_stats.InterfaceStats.from_dictionary(dictionary.get('stats')) if dictionary.get('stats') else None
         uplink_switch_info = cohesity_management_sdk.models.uplink_switch_info.UplinkSwitchInfo.from_dictionary(dictionary.get('uplinkSwitchInfo')) if dictionary.get('uplinkSwitchInfo') else None
 
         # Return an object of this model
-        return cls(link_state,
-                   mac_addr,
-                   name,
-                   slot,
-                   speed,
-                   uplink_switch_info)
-
-
+        return cls(
+            link_state,
+            mac_addr,
+            name,
+            slot,
+            speed,
+            stats,
+            uplink_switch_info
+)
\ No newline at end of file
