@@ -1,9 +1,10 @@
 # -*- coding: utf-8 -*-
-# Copyright 2022 Cohesity Inc.
+# Copyright 2023 Cohesity Inc.
 
-import cohesity_management_sdk.models.dse_solar_info
+import cohesity_management_sdk.models.dse_solr_info
 import cohesity_management_sdk.models.node_to_tiered_storage_directories_map
 
+
 class CassandraAdditionalParams(object):
 
     """Implementation of the 'CassandraAdditionalParams' model.
@@ -11,35 +12,35 @@ class CassandraAdditionalParams(object):
     Contains additional parameters required by the agents to backup data from
     Cassandra.
 
+
     Attributes:
+
         cassandra_classpath_suffix (string): Cassandra classpath suffix.
         cassandra_partitioner (string): Required in compaction.
-        cassandra_version (string): Cassandra and DSE Versions.
-            Discovery code will attempt to discover the versions.
+        cassandra_version (string): Cassandra and DSE Versions. Discovery code
+            will attempt to discover the versions.
         commit_log_backup_location (string): Commit Log Backup location used
-            for PITR feature.
+            for PITR feature
         data_center_vec (list of string): Data center information is required
             for backup and recovery.
-        dse_solr_info (DSESolrInfo): Message to hold information about DSE
-            Solr node.
-        dse_version (string): TODO: type description here.
+        dse_solr_info (DSESolrInfo): In case this Cassandra has a Solr node.
+        dse_version (string): TODO: Type description here.
         tiered_storage_dirs_map (list of NodeToTieredStorageDirectoriesMap):
             Map of nodes to tiered storage directories
-
     """
 
+
     # Create a mapping from Model property names to API property names
     _names = {
-        "cassandra_classpath_suffix": 'cassandraClasspathSuffix',
-        "cassandra_partitioner": 'cassandraPartitioner',
-        "cassandra_version": 'cassandraVersion',
+        "cassandra_classpath_suffix":'cassandraClasspathSuffix',
+        "cassandra_partitioner":'cassandraPartitioner',
+        "cassandra_version":'cassandraVersion',
         "commit_log_backup_location":'commitLogBackupLocation',
         "data_center_vec":'dataCenterVec',
         "dse_solr_info":'dseSolrInfo',
         "dse_version":'dseVersion',
-        "tiered_storage_dirs_map":'tieredStorageDirsMap'
+        "tiered_storage_dirs_map":'tieredStorageDirsMap',
     }
-
     def __init__(self,
                  cassandra_classpath_suffix=None,
                  cassandra_partitioner=None,
@@ -48,8 +49,9 @@ class CassandraAdditionalParams(object):
                  data_center_vec=None,
                  dse_solr_info=None,
                  dse_version=None,
-                 tiered_storage_dirs_map=None
-                 ):
+                 tiered_storage_dirs_map=None,
+            ):
+
         """Constructor for the CassandraAdditionalParams class"""
 
         # Initialize members of the class
@@ -84,8 +86,8 @@ class CassandraAdditionalParams(object):
         cassandra_partitioner = dictionary.get('cassandraPartitioner')
         cassandra_version = dictionary.get('cassandraVersion')
         commit_log_backup_location = dictionary.get('commitLogBackupLocation')
-        data_center_vec = dictionary.get('dataCenterVec')
-        dse_solr_info = cohesity_management_sdk.models.dse_solar_info.DSESolrInfo.from_dictionary(dictionary.get('dseSolrInfo')) if dictionary.get('dseSolrInfo') else None
+        data_center_vec = dictionary.get("dataCenterVec")
+        dse_solr_info = cohesity_management_sdk.models.dse_solr_info.DSESolrInfo.from_dictionary(dictionary.get('dseSolrInfo')) if dictionary.get('dseSolrInfo') else None
         dse_version = dictionary.get('dseVersion')
         tiered_storage_dirs_map = None
         if dictionary.get('tieredStorageDirsMap') != None:
@@ -94,13 +96,13 @@ class CassandraAdditionalParams(object):
                 tiered_storage_dirs_map.append(cohesity_management_sdk.models.node_to_tiered_storage_directories_map.NodeToTieredStorageDirectoriesMap.from_dictionary(structure))
 
         # Return an object of this model
-        return cls(cassandra_classpath_suffix,
-                   cassandra_partitioner,
-                   cassandra_version,
-                   commit_log_backup_location,
-                   data_center_vec,
-                   dse_solr_info,
-                   dse_version,
-                   tiered_storage_dirs_map)
-
-
+        return cls(
+            cassandra_classpath_suffix,
+            cassandra_partitioner,
+            cassandra_version,
+            commit_log_backup_location,
+            data_center_vec,
+            dse_solr_info,
+            dse_version,
+            tiered_storage_dirs_map
+)
\ No newline at end of file
