@@ -1,29 +1,32 @@
 # -*- coding: utf-8 -*-
-# Copyright 2022 Cohesity Inc.
-
+# Copyright 2023 Cohesity Inc.
 
 class ClusterConfigProto_Vault_CloudProperties_GoogleProperties(object):
 
     """Implementation of the 'ClusterConfigProto_Vault_CloudProperties_GoogleProperties' model.
 
-    Attributes:
-        tier_type (int): TODO: Type description here.
+    TODO: type description here.
 
+
+    Attributes:
+
+        tier_type (int): TODO: Type description here.
     """
 
+
     # Create a mapping from Model property names to API property names
     _names = {
-        "tier_type": 'tierType'
+        "tier_type":'tierType',
     }
-
     def __init__(self,
-                 tier_type=None):
+                 tier_type=None,
+            ):
+
         """Constructor for the ClusterConfigProto_Vault_CloudProperties_GoogleProperties class"""
 
         # Initialize members of the class
         self.tier_type = tier_type
 
-
     @classmethod
     def from_dictionary(cls,
                         dictionary):
@@ -42,9 +45,9 @@ class ClusterConfigProto_Vault_CloudProperties_GoogleProperties(object):
             return None
 
         # Extract variables from the dictionary
-        tier_type = dictionary.get('tierType', None)
+        tier_type = dictionary.get('tierType')
 
         # Return an object of this model
-        return cls(tier_type)
-
-
+        return cls(
+            tier_type
+)
\ No newline at end of file
