@@ -1,12 +1,15 @@
 # -*- coding: utf-8 -*-
-# Copyright 2021 Cohesity Inc.
-
+# Copyright 2023 Cohesity Inc.
 
 class CommonACLProto_Grantees(object):
 
     """Implementation of the 'CommonACLProto_Grantees' model.
 
+    TODO: type description here.
+
+
     Attributes:
+
         all_users (bool): This field indicates if all users are granted ACL
             permission.
         denied_referrer_vec (list of string): This field holds a list of
@@ -16,22 +19,23 @@ class CommonACLProto_Grantees(object):
         rlistings (bool): This fields indicates if container GET and HEAD
             operations are permitted provided that read access is granted
             (using referer ACL) on objects.
-
     """
 
+
     # Create a mapping from Model property names to API property names
     _names = {
         "all_users":'allUsers',
         "denied_referrer_vec":'deniedReferrerVec',
         "granted_referrer_vec":'grantedReferrerVec',
-        "rlistings":'rlistings'
+        "rlistings":'rlistings',
     }
-
     def __init__(self,
                  all_users=None,
                  denied_referrer_vec=None,
                  granted_referrer_vec=None,
-                 rlistings=None):
+                 rlistings=None,
+            ):
+
         """Constructor for the CommonACLProto_Grantees class"""
 
         # Initialize members of the class
@@ -40,7 +44,6 @@ class CommonACLProto_Grantees(object):
         self.granted_referrer_vec = granted_referrer_vec
         self.rlistings = rlistings
 
-
     @classmethod
     def from_dictionary(cls,
                         dictionary):
@@ -60,14 +63,14 @@ class CommonACLProto_Grantees(object):
 
         # Extract variables from the dictionary
         all_users = dictionary.get('allUsers')
-        denied_referrer_vec = dictionary.get('deniedReferrerVec')
-        granted_referrer_vec = dictionary.get('grantedReferrerVec')
+        denied_referrer_vec = dictionary.get("deniedReferrerVec")
+        granted_referrer_vec = dictionary.get("grantedReferrerVec")
         rlistings = dictionary.get('rlistings')
 
         # Return an object of this model
-        return cls(all_users,
-                   denied_referrer_vec,
-                   granted_referrer_vec,
-                   rlistings)
-
-
+        return cls(
+            all_users,
+            denied_referrer_vec,
+            granted_referrer_vec,
+            rlistings
+)
\ No newline at end of file
