@@ -1,6 +1,5 @@
 # -*- coding: utf-8 -*-
-# Copyright 2022 Cohesity Inc.
-
+# Copyright 2023 Cohesity Inc.
 
 class CreateApiKeyParams(object):
 
@@ -8,26 +7,29 @@ class CreateApiKeyParams(object):
 
     Specifies the parameters to create an API key.
 
+
     Attributes:
-        expiring_time_msecs (int|long): Specifies a time stamp when the API
-            key will expire in milli seconds.
+
+        expiring_time_msecs (long|int): Specifies a time stamp when the API key
+            will expire in milli seconds.
         is_active (bool): Specifies if the API key is active. Only an active
             and not expired API key can be used for authentication.
-        name (string, required): Specifies the name of API key.
-
+        name (string): Specifies the name of API key.
     """
 
+
     # Create a mapping from Model property names to API property names
     _names = {
         "expiring_time_msecs":'expiringTimeMsecs',
         "is_active":'isActive',
-        "name":'name'
+        "name":'name',
     }
-
     def __init__(self,
                  expiring_time_msecs=None,
                  is_active=None,
-                 name=None):
+                 name=None,
+            ):
+
         """Constructor for the CreateApiKeyParams class"""
 
         # Initialize members of the class
@@ -35,7 +37,6 @@ class CreateApiKeyParams(object):
         self.is_active = is_active
         self.name = name
 
-
     @classmethod
     def from_dictionary(cls,
                         dictionary):
@@ -59,8 +60,8 @@ class CreateApiKeyParams(object):
         name = dictionary.get('name')
 
         # Return an object of this model
-        return cls(expiring_time_msecs,
-                   is_active,
-                   name)
-
-
+        return cls(
+            expiring_time_msecs,
+            is_active,
+            name
+)
\ No newline at end of file
