@@ -1,30 +1,32 @@
 # -*- coding: utf-8 -*-
-# Copyright 2022 Cohesity Inc.
+# Copyright 2023 Cohesity Inc.
 
 import cohesity_management_sdk.models.smb_permission
 import cohesity_management_sdk.models.subnet
 
+
 class CreateViewAliasResponseBody(object):
 
     """Implementation of the 'CreateViewAliasResponseBody' model.
 
-    Specifies the response body of creating view alias.
+    TODO: type description here.
+
 
     Attributes:
-        alias_name (string): Name of the alias to be updated.
+
+        alias_name (string): Alias name.
         enable_filer_audit_log (bool): Specifies whether to enable filer audit
             log on this view alias.
-        enable_smb_encryption (bool): Specifies the SMB encryption for the
-            View Alias. If set, it enables the SMB encryption for the View
-            Alias. Encryption is supported only by SMB 3.x dialects. Dialects
-            that do not support would still access data in unencrypted
-            format.
+        enable_smb_encryption (bool): Specifies the SMB encryption for the View
+            Alias. If set, it enables the SMB encryption for the View Alias.
+            Encryption is supported only by SMB 3.x dialects. Dialects that do
+            not support would still access data in unencrypted format.
         enable_smb_view_discovery (bool): If set, it enables discovery of view
             alias for SMB.
-        enforce_smb_encryption (bool): Specifies the SMB encryption for all
-            the sessions for the View Alias. If set, encryption is enforced
-            for all the sessions for the View Alias. When enabled all future
-            and existing unencrypted sessions are disallowed.
+        enforce_smb_encryption (bool): Specifies the SMB encryption for all the
+            sessions for the View Alias. If set, encryption is enforced for all
+            the sessions for the View Alias. When enabled all future and
+            existing unencrypted sessions are disallowed.
         message (string): Specifies the creating view alias message.
         share_permissions (list of SmbPermission): Specifies a list of share
             level permissions.
@@ -34,11 +36,11 @@ class CreateViewAliasResponseBody(object):
             level and View level.)
         super_user_sids (list of string): Specifies a list of user sids who
             have Superuser access to this alias.
-        view_name (string): View Name.
+        view_name (string): View name.
         view_path (string): View path for the alias.
-
     """
 
+
     # Create a mapping from Model property names to API property names
     _names = {
         "alias_name":'aliasName',
@@ -51,9 +53,8 @@ class CreateViewAliasResponseBody(object):
         "subnet_whitelist":'subnetWhitelist',
         "super_user_sids":'superUserSids',
         "view_name":'viewName',
-        "view_path":'viewPath'
+        "view_path":'viewPath',
     }
-
     def __init__(self,
                  alias_name=None,
                  enable_filer_audit_log=None,
@@ -65,7 +66,9 @@ class CreateViewAliasResponseBody(object):
                  subnet_whitelist=None,
                  super_user_sids=None,
                  view_name=None,
-                 view_path=None):
+                 view_path=None,
+            ):
+
         """Constructor for the CreateViewAliasResponseBody class"""
 
         # Initialize members of the class
@@ -81,7 +84,6 @@ class CreateViewAliasResponseBody(object):
         self.view_name = view_name
         self.view_path = view_path
 
-
     @classmethod
     def from_dictionary(cls,
                         dictionary):
@@ -116,21 +118,21 @@ class CreateViewAliasResponseBody(object):
             subnet_whitelist = list()
             for structure in dictionary.get('subnetWhitelist'):
                 subnet_whitelist.append(cohesity_management_sdk.models.subnet.Subnet.from_dictionary(structure))
-        super_user_sids = dictionary.get('superUserSids')
+        super_user_sids = dictionary.get("superUserSids")
         view_name = dictionary.get('viewName')
         view_path = dictionary.get('viewPath')
 
         # Return an object of this model
-        return cls(alias_name,
-                   enable_filer_audit_log,
-                   enable_smb_encryption,
-                   enable_smb_view_discovery,
-                   enforce_smb_encryption,
-                   message,
-                   share_permissions,
-                   subnet_whitelist,
-                   super_user_sids,
-                   view_name,
-                   view_path)
-
-
+        return cls(
+            alias_name,
+            enable_filer_audit_log,
+            enable_smb_encryption,
+            enable_smb_view_discovery,
+            enforce_smb_encryption,
+            message,
+            share_permissions,
+            subnet_whitelist,
+            super_user_sids,
+            view_name,
+            view_path
+)
\ No newline at end of file
