@@ -1,48 +1,54 @@
 # -*- coding: utf-8 -*-
-# Copyright 2022 Cohesity Inc.
+# Copyright 2023 Cohesity Inc.
 
 import cohesity_management_sdk.models.encryption_configuration
 import cohesity_management_sdk.models.network_configuration
 import cohesity_management_sdk.models.virtual_node_configuration
 
+
 class CreateVirtualClusterParameters(object):
 
     """Implementation of the 'CreateVirtualClusterParameters' model.
 
     Specifies the parameters needed for creation of a new Cluster.
 
+
     Attributes:
+
         cluster_name (string): Specifies the name of the new Cluster.
-        encryption_config (EncryptionConfiguration): Specifies the parameters
-            the user wants to use when configuring encryption for the new
-            Cluster.
+        encryption_config (EncryptionConfiguration): Specifies the encryption
+            configuration parameters.
         ip_preference (int): Specifies IP preference.
-        metadata_fault_tolerance (int): Specifies the metadata fault
-            tolerance.
-        network_config (NetworkConfiguration): Specifies all of the parameters
-            needed for network configuration of the new Cluster.
+        metadata_fault_tolerance (int): Specifies the metadata fault tolerance.
+        network_config (NetworkConfiguration): Specifies the network
+            configuration parameters.
         node_configs (list of VirtualNodeConfiguration): Specifies the
             configuration for the nodes in the new cluster.
-
+        trust_domain (string): Specifies Trust Domain used for Service
+            Identity.
     """
 
+
     # Create a mapping from Model property names to API property names
     _names = {
         "cluster_name":'clusterName',
+        "encryption_config":'encryptionConfig',
+        "ip_preference":'ipPreference',
+        "metadata_fault_tolerance":'metadataFaultTolerance',
         "network_config":'networkConfig',
         "node_configs":'nodeConfigs',
-        "encryption_config":'encryptionConfig',
-        "metadata_fault_tolerance":'metadataFaultTolerance',
-        "ip_preference":'ipPreference'
+        "trust_domain":'trustDomain',
     }
-
     def __init__(self,
                  cluster_name=None,
+                 encryption_config=None,
+                 ip_preference=None,
+                 metadata_fault_tolerance=None,
                  network_config=None,
                  node_configs=None,
-                 encryption_config=None,
-                 metadata_fault_tolerance=None,
-                 ip_preference=None):
+                 trust_domain=None,
+            ):
+
         """Constructor for the CreateVirtualClusterParameters class"""
 
         # Initialize members of the class
@@ -52,7 +58,7 @@ class CreateVirtualClusterParameters(object):
         self.metadata_fault_tolerance = metadata_fault_tolerance
         self.network_config = network_config
         self.node_configs = node_configs
-
+        self.trust_domain = trust_domain
 
     @classmethod
     def from_dictionary(cls,
@@ -73,22 +79,24 @@ class CreateVirtualClusterParameters(object):
 
         # Extract variables from the dictionary
         cluster_name = dictionary.get('clusterName')
+        encryption_config = cohesity_management_sdk.models.encryption_configuration.EncryptionConfiguration.from_dictionary(dictionary.get('encryptionConfig')) if dictionary.get('encryptionConfig') else None
+        ip_preference = dictionary.get('ipPreference')
+        metadata_fault_tolerance = dictionary.get('metadataFaultTolerance')
         network_config = cohesity_management_sdk.models.network_configuration.NetworkConfiguration.from_dictionary(dictionary.get('networkConfig')) if dictionary.get('networkConfig') else None
         node_configs = None
         if dictionary.get('nodeConfigs') != None:
             node_configs = list()
             for structure in dictionary.get('nodeConfigs'):
                 node_configs.append(cohesity_management_sdk.models.virtual_node_configuration.VirtualNodeConfiguration.from_dictionary(structure))
-        encryption_config = cohesity_management_sdk.models.encryption_configuration.EncryptionConfiguration.from_dictionary(dictionary.get('encryptionConfig')) if dictionary.get('encryptionConfig') else None
-        metadata_fault_tolerance = dictionary.get('metadataFaultTolerance')
-        ip_preference = dictionary.get('ipPreference')
+        trust_domain = dictionary.get('trustDomain')
 
         # Return an object of this model
-        return cls(cluster_name,
-                   network_config,
-                   node_configs,
-                   encryption_config,
-                   metadata_fault_tolerance,
-                   ip_preference)
-
-
+        return cls(
+            cluster_name,
+            encryption_config,
+            ip_preference,
+            metadata_fault_tolerance,
+            network_config,
+            node_configs,
+            trust_domain
+)
\ No newline at end of file
