@@ -1,6 +1,5 @@
 # -*- coding: utf-8 -*-
-# Copyright 2021 Cohesity Inc.
-
+# Copyright 2023 Cohesity Inc.
 
 class CreatedApiKey(object):
 
@@ -8,15 +7,17 @@ class CreatedApiKey(object):
 
     Specifies a created API key.
 
+
     Attributes:
-        created_time_msecs (int|long): Specifies the API key created time in
+
+        created_time_msecs (long|int): Specifies the API key created time in
             milli seconds.
         created_user_sid (string): Specifies the user sid who created this API
             key.
         created_username (string): Specifies the username who created this API
             key.
-        expiring_time_msecs (long|int): Specifies a time stamp when the API
-            key will expire in milli seconds.
+        expiring_time_msecs (long|int): Specifies a time stamp when the API key
+            will expire in milli seconds.
         id (string): Specifies the API key id.
         is_active (bool): Specifies if the API key is active. Only an active
             and not expired API key can be used for authentication.
@@ -26,9 +27,9 @@ class CreatedApiKey(object):
         name (string): Specifies the API key name.
         owner_user_sid (string): Specifies the user sid who owns this API key.
         owner_username (string): Specifies the username who owns this API key.
-
     """
 
+
     # Create a mapping from Model property names to API property names
     _names = {
         "created_time_msecs":'createdTimeMsecs',
@@ -41,9 +42,8 @@ class CreatedApiKey(object):
         "key":'key',
         "name":'name',
         "owner_user_sid":'ownerUserSid',
-        "owner_username":'ownerUsername'
+        "owner_username":'ownerUsername',
     }
-
     def __init__(self,
                  created_time_msecs=None,
                  created_user_sid=None,
@@ -55,7 +55,9 @@ class CreatedApiKey(object):
                  key=None,
                  name=None,
                  owner_user_sid=None,
-                 owner_username=None):
+                 owner_username=None,
+            ):
+
         """Constructor for the CreatedApiKey class"""
 
         # Initialize members of the class
@@ -66,12 +68,11 @@ class CreatedApiKey(object):
         self.id = id
         self.is_active = is_active
         self.is_expired = is_expired
-        self.key =  key
+        self.key = key
         self.name = name
         self.owner_user_sid = owner_user_sid
         self.owner_username = owner_username
 
-
     @classmethod
     def from_dictionary(cls,
                         dictionary):
@@ -103,16 +104,16 @@ class CreatedApiKey(object):
         owner_username = dictionary.get('ownerUsername')
 
         # Return an object of this model
-        return cls(created_time_msecs,
-                   created_user_sid,
-                   created_username,
-                   expiring_time_msecs,
-                   id,
-                   is_active,
-                   is_expired,
-                   key,
-                   name,
-                   owner_user_sid,
-                   owner_username)
-
-
+        return cls(
+            created_time_msecs,
+            created_user_sid,
+            created_username,
+            expiring_time_msecs,
+            id,
+            is_active,
+            is_expired,
+            key,
+            name,
+            owner_user_sid,
+            owner_username
+)
\ No newline at end of file
