@@ -1,12 +1,12 @@
 # -*- coding: utf-8 -*-
-# Copyright 2022 Cohesity Inc.
+# Copyright 2023 Cohesity Inc.
 
 class DistributionEnum(object):
 
     """Implementation of the 'Distribution' enum.
+    Specifies the type of the entity in a Kubernetes environment. Determines
+    the K8s distribution.
 
-    Specifies the type of the entity in a Kubernetes environment.
-    Determines the K8s distribution.
 
     Attributes:
         KMAINLINE: TODO: type description here.
@@ -31,4 +31,4 @@ class DistributionEnum(object):
 
     KAKS = 'kAKS'
 
-    KVMWARETANZU = 'kVMwareTanzu'
\ No newline at end of file
+    KVMWARETANZU = 'kVMwareTanzu'
