@@ -1,6 +1,5 @@
 # -*- coding: utf-8 -*-
-# Copyright 2022 Cohesity Inc.
-
+# Copyright 2023 Cohesity Inc.
 
 class DownloadPackageParameters(object):
 
@@ -9,25 +8,27 @@ class DownloadPackageParameters(object):
     Specifies the parameters needed for a request to download a new software
     package to a Cluster.
 
+
     Attributes:
+
         url (string): Specifies a URL from which the package can be downloaded
             to the Cluster.
-
     """
 
+
     # Create a mapping from Model property names to API property names
     _names = {
-        "url":'url'
+        "url":'url',
     }
-
     def __init__(self,
-                 url=None):
+                 url=None,
+            ):
+
         """Constructor for the DownloadPackageParameters class"""
 
         # Initialize members of the class
         self.url = url
 
-
     @classmethod
     def from_dictionary(cls,
                         dictionary):
@@ -49,6 +50,6 @@ class DownloadPackageParameters(object):
         url = dictionary.get('url')
 
         # Return an object of this model
-        return cls(url)
-
-
+        return cls(
+            url
+)
\ No newline at end of file
