@@ -1,34 +1,36 @@
 # -*- coding: utf-8 -*-
-# Copyright 2022 Cohesity Inc.
-
+# Copyright 2023 Cohesity Inc.
 
 class EmailDeliveryTarget(object):
 
     """Implementation of the 'EmailDeliveryTarget' model.
 
-    EmailDeliveryTarget
-    Specifies the email address and the locale setting for it.
+    EmailDeliveryTarget Specifies the email address and the locale setting for
+    it.
+
 
     Attributes:
-        email_address (string): TODO: type description here.
-        locale (string): Specifies the language in which the emails sent to
-            the above defined mail address should be in.
+
+        email_address (string): TODO: Type description here.
+        locale (string): Specifies the language in which the emails sent to the
+            above defined mail address should be in.
         recipient_type (int): Specifies the recipient type on how the emails
             are to received.
-
     """
 
+
     # Create a mapping from Model property names to API property names
     _names = {
         "email_address":'emailAddress',
         "locale":'locale',
-        "recipient_type":'recipientType'
+        "recipient_type":'recipientType',
     }
-
     def __init__(self,
                  email_address=None,
                  locale=None,
-                 recipient_type=None):
+                 recipient_type=None,
+            ):
+
         """Constructor for the EmailDeliveryTarget class"""
 
         # Initialize members of the class
@@ -36,7 +38,6 @@ class EmailDeliveryTarget(object):
         self.locale = locale
         self.recipient_type = recipient_type
 
-
     @classmethod
     def from_dictionary(cls,
                         dictionary):
@@ -60,8 +61,8 @@ class EmailDeliveryTarget(object):
         recipient_type = dictionary.get('recipientType')
 
         # Return an object of this model
-        return cls(email_address,
-                   locale,
-                   recipient_type)
-
-
+        return cls(
+            email_address,
+            locale,
+            recipient_type
+)
\ No newline at end of file
