@@ -1,5 +1,5 @@
 # -*- coding: utf-8 -*-
-# Copyright 2022 Cohesity Inc.
+# Copyright 2023 Cohesity Inc.
 
 class EnvironmentListProtectionSourcesEnum(object):
 
@@ -8,7 +8,7 @@ class EnvironmentListProtectionSourcesEnum(object):
     TODO: type enum description here.
 
     Attributes:
-        KVMWARE: TODO: type description here.
+        K_VMWARE: TODO: type description here.
         KSQL: TODO: type description here.
         KVIEW: TODO: type description here.
         KPUPPETEER: TODO: type description here.
@@ -16,10 +16,17 @@ class EnvironmentListProtectionSourcesEnum(object):
         KPURE: TODO: type description here.
         KNETAPP: TODO: type description here.
         KGENERICNAS: TODO: type description here.
-        KHYPERV: TODO: type description here.
+        K_HYPERV: TODO: type description here.
         KACROPOLIS: TODO: type description here.
         KAZURE: TODO: type description here.
         KKUBERNETES: TODO: type description here.
+        KCASSANDRA: TODO: type description here.
+        KMONGODB: TODO: type description here.
+        KCOUCHBASE: TODO: type description here.
+        KHDFS: TODO: type description here.
+        KHIVE: TODO: type description here.
+        KHBASE: TODO: type description here.
+        KUDA: TODO: type description here.
 
     """
 
@@ -47,3 +54,17 @@ class EnvironmentListProtectionSourcesEnum(object):
 
     KKUBERNETES = 'kKubernetes'
 
+    KCASSANDRA = 'kCassandra'
+
+    KMONGODB = 'kMongoDB'
+
+    KCOUCHBASE = 'kCouchbase'
+
+    KHDFS = 'kHdfs'
+
+    KHIVE = 'kHive'
+
+    KHBASE = 'kHBase'
+
+    KUDA = 'kUDA'
+
