@@ -1,35 +1,36 @@
 # -*- coding: utf-8 -*-
-# Copyright 2022 Cohesity Inc.
-
+# Copyright 2023 Cohesity Inc.
 
 class ErrorProto(object):
 
     """Implementation of the 'ErrorProto' model.
 
-    TODO: type model description here.
+    TODO: type description here.
+
 
     Attributes:
+
         error_msg (string): An optional detail.
         mtype (int): Error.
-
     """
 
+
     # Create a mapping from Model property names to API property names
     _names = {
         "error_msg":'errorMsg',
-        "mtype":'type'
+        "mtype":'type',
     }
-
     def __init__(self,
                  error_msg=None,
-                 mtype=None):
+                 mtype=None,
+            ):
+
         """Constructor for the ErrorProto class"""
 
         # Initialize members of the class
         self.error_msg = error_msg
         self.mtype = mtype
 
-
     @classmethod
     def from_dictionary(cls,
                         dictionary):
@@ -52,7 +53,7 @@ class ErrorProto(object):
         mtype = dictionary.get('type')
 
         # Return an object of this model
-        return cls(error_msg,
-                   mtype)
-
-
+        return cls(
+            error_msg,
+            mtype
+)
\ No newline at end of file
