@@ -1,33 +1,32 @@
 # -*- coding: utf-8 -*-
-# Copyright 2022 Cohesity Inc.
-
+# Copyright 2023 Cohesity Inc.
 
 class ExpandCloudClusterParameters(object):
 
     """Implementation of the 'ExpandCloudClusterParameters' model.
 
-    Specifies the parameters needed to expand a Cohesity Cloud Edition
-    Cluster.
+    Specifies the parameters needed to expand a Cohesity Cloud Edition Cluster.
+
 
     Attributes:
-        node_ips (list of string): Specifies the list of IPs of the new
-            Nodes.
 
+        node_ips (list of string): Specifies the list of IPs of the new Nodes.
     """
 
+
     # Create a mapping from Model property names to API property names
     _names = {
-        "node_ips":'nodeIps'
+        "node_ips":'nodeIps',
     }
-
     def __init__(self,
-                 node_ips=None):
+                 node_ips=None,
+            ):
+
         """Constructor for the ExpandCloudClusterParameters class"""
 
         # Initialize members of the class
         self.node_ips = node_ips
 
-
     @classmethod
     def from_dictionary(cls,
                         dictionary):
@@ -46,9 +45,9 @@ class ExpandCloudClusterParameters(object):
             return None
 
         # Extract variables from the dictionary
-        node_ips = dictionary.get('nodeIps')
+        node_ips = dictionary.get("nodeIps")
 
         # Return an object of this model
-        return cls(node_ips)
-
-
+        return cls(
+            node_ips
+)
\ No newline at end of file
