@@ -1,35 +1,38 @@
 # -*- coding: utf-8 -*-
-# Copyright 2022 Cohesity Inc.
+# Copyright 2023 Cohesity Inc.
 
 import cohesity_management_sdk.models.physical_node_configuration
 
+
 class ExpandPhysicalClusterParameters(object):
 
     """Implementation of the 'ExpandPhysicalClusterParameters' model.
 
-    Specifies the parameters needed to expand a Cohesity Physical
-    Edition Cluster.
+    Specifies the parameters needed to expand a Cohesity Physical Edition
+    Cluster.
+
 
     Attributes:
-        chassis_serial_to_rack_id_map (int|long): ChassisSerialToRackId Map.
+
+        chassis_serial_to_rack_id_map (object): ChassisSerialToRackId map.
         node_configs (list of PhysicalNodeConfiguration): Specifies the
             configuration details of the Nodes in the Cluster.
-        vips (list of string): Specifies the virtual IPs to add to the
-            Cluster.
-
+        vips (list of string): Specifies the virtual IPs to add to the Cluster.
     """
 
+
     # Create a mapping from Model property names to API property names
     _names = {
         "chassis_serial_to_rack_id_map":'chassisSerialToRackIdMap',
         "node_configs":'nodeConfigs',
-        "vips":'vips'
+        "vips":'vips',
     }
-
     def __init__(self,
                  chassis_serial_to_rack_id_map=None,
                  node_configs=None,
-                 vips=None):
+                 vips=None,
+            ):
+
         """Constructor for the ExpandPhysicalClusterParameters class"""
 
         # Initialize members of the class
@@ -37,7 +40,6 @@ class ExpandPhysicalClusterParameters(object):
         self.node_configs = node_configs
         self.vips = vips
 
-
     @classmethod
     def from_dictionary(cls,
                         dictionary):
@@ -62,11 +64,11 @@ class ExpandPhysicalClusterParameters(object):
             node_configs = list()
             for structure in dictionary.get('nodeConfigs'):
                 node_configs.append(cohesity_management_sdk.models.physical_node_configuration.PhysicalNodeConfiguration.from_dictionary(structure))
-        vips = dictionary.get('vips')
+        vips = dictionary.get("vips")
 
         # Return an object of this model
-        return cls(chassis_serial_to_rack_id_map,
-                   node_configs,
-                   vips)
-
-
+        return cls(
+            chassis_serial_to_rack_id_map,
+            node_configs,
+            vips
+)
\ No newline at end of file
