@@ -1,15 +1,15 @@
 # -*- coding: utf-8 -*-
-# Copyright 2021 Cohesity Inc.
+# Copyright 2023 Cohesity Inc.
 
 class FaultToleranceLevelEnum(object):
 
     """Implementation of the 'FaultToleranceLevel' enum.
-
     Specifies the level which 'MetadataFaultToleranceFactor' applies to.
     'kNode' indicates 'MetadataFaultToleranceFactor' applies to Node level.
     'kChassis' indicates 'MetadataFaultToleranceFactor' applies to Chassis
+    level. 'kRack' indicates 'MetadataFaultToleranceFactor' applies to Rack
     level.
-    'kRack' indicates 'MetadataFaultToleranceFactor' applies to Rack level.
+
 
     Attributes:
         KNODE: TODO: type description here.
@@ -23,4 +23,3 @@ class FaultToleranceLevelEnum(object):
     KCHASSIS = 'kChassis'
 
     KRACK = 'kRack'
-
