@@ -1,6 +1,5 @@
 # -*- coding: utf-8 -*-
-# Copyright 2021 Cohesity Inc.
-
+# Copyright 2023 Cohesity Inc.
 
 class GpfsFileset(object):
 
@@ -8,34 +7,37 @@ class GpfsFileset(object):
 
     Specifies information about a fileset in a GPFS file system.
 
+
     Attributes:
-        id (int): Specifies the id of the fileset.
+
+        id (long|int): Specifies the id of the fileset.
         is_independent_fileset (bool): If the given fileset is an Independent
             fileset or not.
         name (string): Name of the filesystem associated with the fileset
         path (string): Specifies the absolute path of the fileset.
-        protocols (list of ProtocolEnum): Specifies GPFS supported Protocol
+        protocols (list of ProtocolsEnum): Specifies GPFS supported Protocol
             information enabled on GPFS File System 'kNfs' indicates NFS
             exports in a GPFS fileset. 'kSmb' indicates CIFS/SMB Shares in a
             GPFS fileset.
-
     """
 
+
     # Create a mapping from Model property names to API property names
     _names = {
         "id":'id',
         "is_independent_fileset":'isIndependentFileset',
         "name":'name',
         "path":'path',
-        "protocols":'protocols'
+        "protocols":'protocols',
     }
-
     def __init__(self,
                  id=None,
                  is_independent_fileset=None,
                  name=None,
                  path=None,
-                 protocols=None):
+                 protocols=None,
+            ):
+
         """Constructor for the GpfsFileset class"""
 
         # Initialize members of the class
@@ -45,7 +47,6 @@ class GpfsFileset(object):
         self.path = path
         self.protocols = protocols
 
-
     @classmethod
     def from_dictionary(cls,
                         dictionary):
@@ -68,13 +69,13 @@ class GpfsFileset(object):
         is_independent_fileset = dictionary.get('isIndependentFileset')
         name = dictionary.get('name')
         path = dictionary.get('path')
-        protocols = dictionary.get('protocols')
+        protocols = dictionary.get("protocols")
 
         # Return an object of this model
-        return cls(id,
-                   is_independent_fileset,
-                   name,
-                   path,
-                   protocols)
-
-
+        return cls(
+            id,
+            is_independent_fileset,
+            name,
+            path,
+            protocols
+)
\ No newline at end of file
