@@ -1,6 +1,5 @@
 # -*- coding: utf-8 -*-
-# Copyright 2021 Cohesity Inc.
-
+# Copyright 2023 Cohesity Inc.
 
 class HostEntry(object):
 
@@ -9,25 +8,27 @@ class HostEntry(object):
     Specifies the parameters of a host entry that can be stored in the
     cluster's /etc/hosts file.
 
-    Attributes:
-        description (string): Description the host entry.
-        domain_names (list of string): Specifies the domain names of the
-            host.
-        ip (string): Specifies the IP address of the host.
 
+    Attributes:
+
+        description (string): Description the host entry.
+        domain_names (list of string): Specifies the domain names of the host.
+        ip (string): Specifies the IP address of the host.
     """
 
+
     # Create a mapping from Model property names to API property names
     _names = {
         "description":'description',
         "domain_names":'domainNames',
-        "ip":'ip'
+        "ip":'ip',
     }
-
     def __init__(self,
                  description=None,
                  domain_names=None,
-                 ip=None):
+                 ip=None,
+            ):
+
         """Constructor for the HostEntry class"""
 
         # Initialize members of the class
@@ -35,7 +36,6 @@ class HostEntry(object):
         self.domain_names = domain_names
         self.ip = ip
 
-
     @classmethod
     def from_dictionary(cls,
                         dictionary):
@@ -55,12 +55,12 @@ class HostEntry(object):
 
         # Extract variables from the dictionary
         description = dictionary.get('description')
-        domain_names = dictionary.get('domainNames')
+        domain_names = dictionary.get("domainNames")
         ip = dictionary.get('ip')
 
         # Return an object of this model
-        return cls(description,
-                   domain_names,
-                   ip)
-
-
+        return cls(
+            description,
+            domain_names,
+            ip
+)
\ No newline at end of file
