@@ -1,5 +1,5 @@
 # -*- coding: utf-8 -*-
-# Copyright 2022 Cohesity Inc.
+# Copyright 2023 Cohesity Inc.
 
 class HostTypeAgentInformationEnum(object):
 
@@ -12,6 +12,9 @@ class HostTypeAgentInformationEnum(object):
     'kAix' indicates the IBM AIX operating system.
     'kSolaris' indicates the Oracle Solaris operating system.
     'kSapHana' indicates the Sap Hana database system developed by SAP SE.
+    'kSapOracle' indicates the Sap Oracle database system developed by SAP SE.
+    'kCockroachDB' indicates the CockroachDB database system.
+    'kMySQL' indicates the MySQL database system.
     'kOther' indicates the other types of operating system.
 
     Attributes:
@@ -20,6 +23,9 @@ class HostTypeAgentInformationEnum(object):
         KAIX: TODO: type description here.
         KSOLARIS: TODO: type description here.
         KSAPHANA: TODO: type description here.
+        KSAPORACLE: TODO: type description here.
+        KCOCKROACHDB: TODO: type description here.
+        KMYSQL: TODO: type description here.
         KOTHER: TODO: type description here.
 
     """
@@ -34,5 +40,10 @@ class HostTypeAgentInformationEnum(object):
 
     KSAPHANA = 'kSapHana'
 
-    KOTHER = 'kOther'
+    KSAPORACLE = 'kSapOracle'
 
+    KCOCKROACHDB = 'kCockroachDB'
+
+    KMYSQL = 'kMySQL'
+
+    KOTHER = 'kOther'
