@@ -1,11 +1,11 @@
 # -*- coding: utf-8 -*-
-# Copyright 2022 Cohesity Inc.
+# Copyright 2023 Cohesity Inc.
 
-class HydraIOPreferentialTierEnum(object):
+class HydraIoPreferentialTierEnum(object):
 
-    """Implementation of the 'HydraIOPreferentialTier' enum.
+    """Implementation of the 'HydraIoPreferentialTier' enum.
+    Specifies the list of perferred storage tiers used by Hydra.
 
-    TODO: type enum description here.
 
     Attributes:
         KPCIESSD: TODO: type description here.
@@ -22,4 +22,3 @@ class HydraIOPreferentialTierEnum(object):
     KSATAHDD = 'kSataHdd'
 
     KCLOUD = 'kCloud'
-
