@@ -1,34 +1,40 @@
 # -*- coding: utf-8 -*-
-# Copyright 2022 Cohesity Inc.
+# Copyright 2023 Cohesity Inc.
 
 import cohesity_management_sdk.models.label_selector_match_labels_entry
 
+
 class LabelSelector(object):
 
     """Implementation of the 'LabelSelector' model.
 
-    Attributes:
-        match_labels (list of LabelSelector_MatchLabelsEntry): This field is
-            an object which consists of key-value pairs
-            of all labels that must be matched by the selector
-        name (string): Select all objects which have a label with
-            key : "name" and value specified by this field.
-        service_name (string): Select all objects which have a label with.
-            key: "serviceName" and value as specified by this field.
+    TODO: type description here.
 
+
+    Attributes:
+
+        match_labels (list of LabelSelector_MatchLabelsEntry): This field is an
+            object which consists of key-value pairs of all labels that must be
+            matched by the selector
+        name (string): Select all objects which have a label with key : "name"
+            and value specified by this field.
+        service_name (string): Select all objects which have a label with. key:
+            "serviceName" and value as specified by this field.
     """
 
+
     # Create a mapping from Model property names to API property names
     _names = {
         "match_labels":'matchLabels',
         "name":'name',
-        "service_name":'serviceName'
+        "service_name":'serviceName',
     }
-
     def __init__(self,
                  match_labels=None,
                  name=None,
-                 service_name=None):
+                 service_name=None,
+            ):
+
         """Constructor for the LabelSelector class"""
 
         # Initialize members of the class
@@ -36,7 +42,6 @@ class LabelSelector(object):
         self.name = name
         self.service_name = service_name
 
-
     @classmethod
     def from_dictionary(cls,
                         dictionary):
@@ -56,7 +61,7 @@ class LabelSelector(object):
 
         # Extract variables from the dictionary
         match_labels = None
-        if dictionary.get('matchLabels'):
+        if dictionary.get('matchLabels') != None:
             match_labels = list()
             for structure in dictionary.get('matchLabels'):
                 match_labels.append(cohesity_management_sdk.models.label_selector_match_labels_entry.LabelSelector_MatchLabelsEntry.from_dictionary(structure))
@@ -64,8 +69,8 @@ class LabelSelector(object):
         service_name = dictionary.get('serviceName')
 
         # Return an object of this model
-        return cls(match_labels,
-                   name,
-                   service_name)
-
-
+        return cls(
+            match_labels,
+            name,
+            service_name
+)
\ No newline at end of file
