@@ -1,6 +1,5 @@
 # -*- coding: utf-8 -*-
-# Copyright 2022 Cohesity Inc.
-
+# Copyright 2023 Cohesity Inc.
 
 class LdapProviderResponse(object):
 
@@ -8,7 +7,9 @@ class LdapProviderResponse(object):
 
     LDAP provider response struct.
 
+
     Attributes:
+
         ad_domain_name (string): Specifies the domain name of an Active
             Directory which is mapped to this LDAP provider
         attribute_common_name (string): Name of the LDAP attribute used for
@@ -19,37 +20,37 @@ class LdapProviderResponse(object):
             members of a group.
         attribute_uid (string): Name of the attribute used to lookup unix UID
             of an LDAP user.
-        attribute_user_name (string): Name of the LDAP attribute used to
-            lookup a user by user ID.
+        attribute_user_name (string): Name of the LDAP attribute used to lookup
+            a user by user ID.
         auth_type (AuthTypeEnum): Specifies the authentication type used while
             connecting to LDAP servers. Authentication level. 'kAnonymous'
             indicates LDAP authentication type 'Anonymous' 'kSimple' indicates
             LDAP authentication type 'Simple'
-        base_distinguished_name (string): Specifies the base distinguished
-            name used as the base for LDAP search requests.
+        base_distinguished_name (string): Specifies the base distinguished name
+            used as the base for LDAP search requests.
         domain_name (string): Specifies the name of the domain name to be used
             for querying LDAP servers from DNS. If PreferredLdapServerList is
             set, then DomainName field is ignored.
         id (long|int): Specifies the ID of the LDAP provider.
+        name (string): Specifies the name of the LDAP provider.
         object_class_group (string): Name of the LDAP group object class for
             user accounts.
         object_class_user (string): Name of the LDAP user object class for user
             accounts.
-        name (string): Specifies the name of the LDAP provider.
         port (int): Specifies LDAP server port.
         preferred_ldap_server_list (list of string): Specifies the preferred
             LDAP servers. Server names should be either in fully qualified
             domain name (FQDN) format or IP addresses.
         tenant_id (string): Specifies the unique id of the tenant.
         use_ssl (bool): Specifies whether to use SSL for LDAP connections.
-        user_distinguished_name (string): Specifies the user distinguished
-            name that is used for LDAP authentication. It should be provided
-            if the AuthType is set to either kSimple or kSasl.
+        user_distinguished_name (string): Specifies the user distinguished name
+            that is used for LDAP authentication. It should be provided if the
+            AuthType is set to either kSimple or kSasl.
         user_password (string): Specifies the user password that is used for
             LDAP authentication.
-
     """
 
+
     # Create a mapping from Model property names to API property names
     _names = {
         "ad_domain_name":'adDomainName',
@@ -70,9 +71,8 @@ class LdapProviderResponse(object):
         "tenant_id":'tenantId',
         "use_ssl":'useSsl',
         "user_distinguished_name":'userDistinguishedName',
-        "user_password":'userPassword'
+        "user_password":'userPassword',
     }
-
     def __init__(self,
                  ad_domain_name=None,
                  attribute_common_name=None,
@@ -92,7 +92,9 @@ class LdapProviderResponse(object):
                  tenant_id=None,
                  use_ssl=None,
                  user_distinguished_name=None,
-                 user_password=None):
+                 user_password=None,
+            ):
+
         """Constructor for the LdapProviderResponse class"""
 
         # Initialize members of the class
@@ -106,9 +108,9 @@ class LdapProviderResponse(object):
         self.base_distinguished_name = base_distinguished_name
         self.domain_name = domain_name
         self.id = id
+        self.name = name
         self.object_class_group = object_class_group
         self.object_class_user = object_class_user
-        self.name = name
         self.port = port
         self.preferred_ldap_server_list = preferred_ldap_server_list
         self.tenant_id = tenant_id
@@ -116,7 +118,6 @@ class LdapProviderResponse(object):
         self.user_distinguished_name = user_distinguished_name
         self.user_password = user_password
 
-
     @classmethod
     def from_dictionary(cls,
                         dictionary):
@@ -149,31 +150,31 @@ class LdapProviderResponse(object):
         object_class_group = dictionary.get('objectClassGroup')
         object_class_user = dictionary.get('objectClassUser')
         port = dictionary.get('port')
-        preferred_ldap_server_list = dictionary.get('preferredLdapServerList')
+        preferred_ldap_server_list = dictionary.get("preferredLdapServerList")
         tenant_id = dictionary.get('tenantId')
         use_ssl = dictionary.get('useSsl')
         user_distinguished_name = dictionary.get('userDistinguishedName')
         user_password = dictionary.get('userPassword')
 
         # Return an object of this model
-        return cls(ad_domain_name,
-                   attribute_common_name,
-                   attribute_gid,
-                   attribute_member_of,
-                   attribute_uid,
-                   attribute_user_name,
-                   auth_type,
-                   base_distinguished_name,
-                   domain_name,
-                   id,
-                   name,
-                   object_class_group,
-                   object_class_user,
-                   port,
-                   preferred_ldap_server_list,
-                   tenant_id,
-                   use_ssl,
-                   user_distinguished_name,
-                   user_password)
-
-
+        return cls(
+            ad_domain_name,
+            attribute_common_name,
+            attribute_gid,
+            attribute_member_of,
+            attribute_uid,
+            attribute_user_name,
+            auth_type,
+            base_distinguished_name,
+            domain_name,
+            id,
+            name,
+            object_class_group,
+            object_class_user,
+            port,
+            preferred_ldap_server_list,
+            tenant_id,
+            use_ssl,
+            user_distinguished_name,
+            user_password
+)
\ No newline at end of file
