@@ -1,36 +1,36 @@
 # -*- coding: utf-8 -*-
-# Copyright 2022 Cohesity Inc.
-
+# Copyright 2023 Cohesity Inc.
 
 class LicensedUsage(object):
 
     """Implementation of the 'LicensedUsage' model.
 
-    Structure to hold feature usage on cluster side.
+    TODO: type description here.
+
 
     Attributes:
-        capacity_gib (int|long): Feature usage by the cluster.
-        expiry_time (int|long): Expiry time(epoch) of each feature.
-            There could be multiple expiry time for the given SKU.
+
+        capacity_gib (long|int): Feature usage by the cluster.
+        expiry_time (long|int): Expiry time(epoch) of each feature. There could
+            be multiple expiry time for the given SKU.
         feature_name (string): Name of feature.
         license_type (string): Type of License
-        num_vm (int|long): Number of VM spinned.
+        num_vm (long|int): Number of VM spinned.
         product_description (string): Detail description of entitlement
         product_info (string): Short description of entitlement
-
     """
 
+
     # Create a mapping from Model property names to API property names
     _names = {
-        "capacity_gib": 'capacityGiB',
-        "expiry_time": 'expiryTime',
-        "feature_name": 'featureName',
-        "license_type": 'licenseType',
+        "capacity_gib":'capacityGiB',
+        "expiry_time":'expiryTime',
+        "feature_name":'featureName',
+        "license_type":'licenseType',
         "num_vm":'numVm',
         "product_description":'productDescription',
-        "product_info":'productInfo'
+        "product_info":'productInfo',
     }
-
     def __init__(self,
                  capacity_gib=None,
                  expiry_time=None,
@@ -38,7 +38,9 @@ class LicensedUsage(object):
                  license_type=None,
                  num_vm=None,
                  product_description=None,
-                 product_info=None):
+                 product_info=None,
+            ):
+
         """Constructor for the LicensedUsage class"""
 
         # Initialize members of the class
@@ -77,12 +79,12 @@ class LicensedUsage(object):
         product_info = dictionary.get('productInfo')
 
         # Return an object of this model
-        return cls(capacity_gib,
-                   expiry_time,
-                   feature_name,
-                   license_type,
-                   num_vm,
-                   product_description,
-                   product_info)
-
-
+        return cls(
+            capacity_gib,
+            expiry_time,
+            feature_name,
+            license_type,
+            num_vm,
+            product_description,
+            product_info
+)
\ No newline at end of file
