@@ -1,32 +1,36 @@
 # -*- coding: utf-8 -*-
-# Copyright 2022 Cohesity Inc.
+# Copyright 2023 Cohesity Inc.
 
 import cohesity_management_sdk.models.org_vdc_network
 
+
 class ListOrgVdcNetworksResponse(object):
 
     """Implementation of the 'ListOrgVdcNetworksResponse' model.
 
-    Specifies the response returned when fetching a list of Org VDC Networks.
+    TODO: type description here.
+
 
     Attributes:
-        org_vdc_networks (list of OrgVdcNetwork): Specifies a list of Org VDC Networks.
-            user.
+
+        org_vdc_networks (list of OrgVdcNetwork): Specifies a list of Org VDC
+            Networks.
     """
 
+
     # Create a mapping from Model property names to API property names
     _names = {
-        "org_vdc_networks":'orgVdcNetworks'
+        "org_vdc_networks":'orgVdcNetworks',
     }
-
     def __init__(self,
-                 org_vdc_networks=None):
+                 org_vdc_networks=None,
+            ):
+
         """Constructor for the ListOrgVdcNetworksResponse class"""
 
         # Initialize members of the class
         self.org_vdc_networks = org_vdc_networks
 
-
     @classmethod
     def from_dictionary(cls,
                         dictionary):
@@ -52,6 +56,6 @@ class ListOrgVdcNetworksResponse(object):
                 org_vdc_networks.append(cohesity_management_sdk.models.org_vdc_network.OrgVdcNetwork.from_dictionary(structure))
 
         # Return an object of this model
-        return cls(org_vdc_networks)
-
-
+        return cls(
+            org_vdc_networks
+)
\ No newline at end of file
