@@ -1,35 +1,37 @@
 # -*- coding: utf-8 -*-
-# Copyright 2021 Cohesity Inc.
-
+# Copyright 2023 Cohesity Inc.
 
 class LogicalStats(object):
 
     """Implementation of the 'LogicalStats' model.
 
-    Provides the combined data residing on protected objects. The size of data
-    before reduction by deduplication and compression.
+    Provides logical statistics for logical entities such as Clusters and
+    Domains (View Boxes). The logical size is the size of the data when it is
+    fully hydrated or expanded. The actual physical data stored on the Cohesity
+    Cluster is reduced by change-block tracking, compression and deduplication.
+
 
     Attributes:
-        total_logical_usage_bytes (long|int): Provides the logical usage as
-            computed by the Cohesity Cluster. The size of the data without
-            reduction by change-block tracking, compression and
-            deduplication.
 
+        total_logical_usage_bytes (long|int): Provides the combined data
+            residing on protected objects. The size of data before reduction by
+            deduplication and compression.
     """
 
+
     # Create a mapping from Model property names to API property names
     _names = {
-        "total_logical_usage_bytes":'totalLogicalUsageBytes'
+        "total_logical_usage_bytes":'totalLogicalUsageBytes',
     }
-
     def __init__(self,
-                 total_logical_usage_bytes=None):
+                 total_logical_usage_bytes=None,
+            ):
+
         """Constructor for the LogicalStats class"""
 
         # Initialize members of the class
         self.total_logical_usage_bytes = total_logical_usage_bytes
 
-
     @classmethod
     def from_dictionary(cls,
                         dictionary):
@@ -51,6 +53,6 @@ class LogicalStats(object):
         total_logical_usage_bytes = dictionary.get('totalLogicalUsageBytes')
 
         # Return an object of this model
-        return cls(total_logical_usage_bytes)
-
-
+        return cls(
+            total_logical_usage_bytes
+)
\ No newline at end of file
