@@ -1,14 +1,13 @@
 # -*- coding: utf-8 -*-
-# Copyright 2022 Cohesity Inc.
+# Copyright 2023 Cohesity Inc.
 
 class NasProtocolEnum(object):
 
     """Implementation of the 'NasProtocol' enum.
+    Specifies the protocol used by the NAS server. Specifies the protocol used
+    by a NAS server. 'kNfs3' indicates NFS v3 protocol. 'kCifs1' indicates CIFS
+    v1.0 protocol.
 
-    Specifies the protocol used by the NAS server.
-    Specifies the protocol used by a NAS server.
-    'kNfs3' indicates NFS v3 protocol.
-    'kCifs1' indicates CIFS v1.0 protocol.
 
     Attributes:
         KNFS3: TODO: type description here.
@@ -19,4 +18,3 @@ class NasProtocolEnum(object):
     KNFS3 = 'kNfs3'
 
     KCIFS1 = 'kCifs1'
-
