@@ -1,6 +1,5 @@
 # -*- coding: utf-8 -*-
-# Copyright 2022 Cohesity Inc.
-
+# Copyright 2023 Cohesity Inc.
 
 class NasSourceThrottlingParams(object):
 
@@ -9,33 +8,37 @@ class NasSourceThrottlingParams(object):
     Specifies the NAS specific source throttling parameters during source
     registration or during backup of the source.
 
+
     Attributes:
+
         max_parallel_metadata_fetch_full_percentage (int): Specifies the
             percentage value of maximum concurrent metadata to be fetched
             during full backup of the source.
-        max_parallel_metadata_fetch_incremental_percentage (int): Specifies
-            the IPMI IP of the node (if physical cluster).
-        max_parallel_read_write_full_percentage (int): Specifies the
-            percentage value of maximum concurrent IO during full backup
+        max_parallel_metadata_fetch_incremental_percentage (int): Specifies the
+            percentage value of maximum concurrent metadata to be fetched
+            during incremental backup of the source.
+        max_parallel_read_write_full_percentage (int): Specifies the percentage
+            value of maximum concurrent IO during full backup of the source.
         max_parallel_read_write_incremental_percentage (int): Specifies the
-            percentage value of maximum concurrent IO during incremental
-            backup of the source.
-
+            percentage value of maximum concurrent IO during incremental backup
+            of the source.
     """
 
+
     # Create a mapping from Model property names to API property names
     _names = {
         "max_parallel_metadata_fetch_full_percentage":'maxParallelMetadataFetchFullPercentage',
         "max_parallel_metadata_fetch_incremental_percentage":'maxParallelMetadataFetchIncrementalPercentage',
         "max_parallel_read_write_full_percentage":'maxParallelReadWriteFullPercentage',
-        "max_parallel_read_write_incremental_percentage":'maxParallelReadWriteIncrementalPercentage'
+        "max_parallel_read_write_incremental_percentage":'maxParallelReadWriteIncrementalPercentage',
     }
-
     def __init__(self,
                  max_parallel_metadata_fetch_full_percentage=None,
                  max_parallel_metadata_fetch_incremental_percentage=None,
                  max_parallel_read_write_full_percentage=None,
-                 max_parallel_read_write_incremental_percentage=None):
+                 max_parallel_read_write_incremental_percentage=None,
+            ):
+
         """Constructor for the NasSourceThrottlingParams class"""
 
         # Initialize members of the class
@@ -44,7 +47,6 @@ class NasSourceThrottlingParams(object):
         self.max_parallel_read_write_full_percentage = max_parallel_read_write_full_percentage
         self.max_parallel_read_write_incremental_percentage = max_parallel_read_write_incremental_percentage
 
-
     @classmethod
     def from_dictionary(cls,
                         dictionary):
@@ -69,9 +71,9 @@ class NasSourceThrottlingParams(object):
         max_parallel_read_write_incremental_percentage = dictionary.get('maxParallelReadWriteIncrementalPercentage')
 
         # Return an object of this model
-        return cls(max_parallel_metadata_fetch_full_percentage,
-                   max_parallel_metadata_fetch_incremental_percentage,
-                   max_parallel_read_write_full_percentage,
-                   max_parallel_read_write_incremental_percentage)
-
-
+        return cls(
+            max_parallel_metadata_fetch_full_percentage,
+            max_parallel_metadata_fetch_incremental_percentage,
+            max_parallel_read_write_full_percentage,
+            max_parallel_read_write_incremental_percentage
+)
\ No newline at end of file
