@@ -1,27 +1,27 @@
 # -*- coding: utf-8 -*-
-# Copyright 2021 Cohesity Inc.
+# Copyright 2023 Cohesity Inc.
 
 import cohesity_management_sdk.models.network_pool_range
 
+
 class NetworkPool(object):
 
     """Implementation of the 'NetworkPool' model.
 
-    Specifies the network pool config of an Isilon Access Zone.
+    TODO: type description here.
+
 
     Attributes:
+
         address_family (AddressFamilyEnum): Specifies the enum for the IP
-            address families.
-            'kUnknown' indicates IP address families are unknown.
-            'kIPv4' indicates IP addresses used are from IPv4 family.
+            address families. 'kUnknown' indicates IP address families are
+            unknown. 'kIPv4' indicates IP addresses used are from IPv4 family.
             'kIPv6' indicates IP addresses used are from IPv6 family.
         allocation_method (AllocationMethodEnum): Specifies the enum for IP
-            allocation method.
-            'kUnknownAllocMethod' indicates allocation method is unknown.
-            'kStaticAllocMethod' indicates static allocation method for IP
-                addresses.
-            'kDynamicAllocMethod' indicates dynamic allocation method for IP
-                addresses.
+            allocation method. 'kUnknownAllocMethod' indicates allocation
+            method is unknown. 'kStaticAllocMethod' indicates static allocation
+            method for IP addresses. 'kDynamicAllocMethod' indicates dynamic
+            allocation method for IP addresses.
         groupnet (string): Specifies the groupnet name of the network pool.
         id (string): Specifies the unique identifier of the network pool.
         name (string): Specifies the name of the network pool.
@@ -29,21 +29,20 @@ class NetworkPool(object):
         smart_connect_dns_zone (string): Specifies the SmartConnect zone name
             of the network pool.
         subnet (string): Specifies the subnet name of the network pool.
-
     """
 
+
     # Create a mapping from Model property names to API property names
     _names = {
-        "address_family": 'addressFamily',
-        "allocation_method": 'allocationMethod',
+        "address_family":'addressFamily',
+        "allocation_method":'allocationMethod',
         "groupnet":'groupnet',
         "id":'id',
         "name":'name',
         "ranges":'ranges',
         "smart_connect_dns_zone":'smartConnectDnsZone',
-        "subnet":'subnet'
+        "subnet":'subnet',
     }
-
     def __init__(self,
                  address_family=None,
                  allocation_method=None,
@@ -52,7 +51,9 @@ class NetworkPool(object):
                  name=None,
                  ranges=None,
                  smart_connect_dns_zone=None,
-                 subnet=None):
+                 subnet=None,
+            ):
+
         """Constructor for the NetworkPool class"""
 
         # Initialize members of the class
@@ -97,13 +98,13 @@ class NetworkPool(object):
         subnet = dictionary.get('subnet')
 
         # Return an object of this model
-        return cls(address_family,
-                   allocation_method,
-                   groupnet,
-                   id,
-                   name,
-                   ranges,
-                   smart_connect_dns_zone,
-                   subnet)
-
-
+        return cls(
+            address_family,
+            allocation_method,
+            groupnet,
+            id,
+            name,
+            ranges,
+            smart_connect_dns_zone,
+            subnet
+)
\ No newline at end of file
