@@ -1,38 +1,43 @@
 # -*- coding: utf-8 -*-
-# Copyright 2021 Cohesity Inc.
+# Copyright 2023 Cohesity Inc.
 
 import cohesity_management_sdk.models.entity_proto
 import cohesity_management_sdk.models.no_sql_log_data
 
-class IpRange(object):
 
-    """Implementation of the 'IpRange' model.
+class NoSqlRecoverParams_EntityLog(object):
+
+    """Implementation of the 'NoSqlRecoverParams_EntityLog' model.
+
+    TODO: type description here.
+
 
     Attributes:
+
         entity (EntityProto): Entity for a leaf level entity.
         log_data_vec (list of NoSqlLogData): List of log file and time range to
             applied for hydrated backup or for recovery. Each data event has a
-            path of log file and the valid sequencer range within that log file.
-
-
+            path of log file and the valid sequencer range within that log
+            file.
     """
 
+
     # Create a mapping from Model property names to API property names
     _names = {
-        "entity": 'entity',
-        "log_data_vec": 'logDataVec'
+        "entity":'entity',
+        "log_data_vec":'logDataVec',
     }
-
     def __init__(self,
                  entity=None,
-                 log_data_vec=None):
-        """Constructor for the IpRange class"""
+                 log_data_vec=None,
+            ):
+
+        """Constructor for the NoSqlRecoverParams_EntityLog class"""
 
         # Initialize members of the class
         self.entity = entity
         self.log_data_vec = log_data_vec
 
-
     @classmethod
     def from_dictionary(cls,
                         dictionary):
@@ -51,7 +56,7 @@ class IpRange(object):
             return None
 
         # Extract variables from the dictionary
-        entity = cohesity_management_sdk.models.entity_proto.EntityProto.from_dictionary(dictionary.get('entity')) if dictionary.get('entity') else None 
+        entity = cohesity_management_sdk.models.entity_proto.EntityProto.from_dictionary(dictionary.get('entity')) if dictionary.get('entity') else None
         log_data_vec = None
         if dictionary.get('logDataVec') != None:
             log_data_vec = list()
@@ -59,7 +64,7 @@ class IpRange(object):
                 log_data_vec.append(cohesity_management_sdk.models.no_sql_log_data.NoSqlLogData.from_dictionary(structure))
 
         # Return an object of this model
-        return cls(entity,
-                   log_data_vec)
-
-
+        return cls(
+            entity,
+            log_data_vec
+)
\ No newline at end of file
