@@ -1,34 +1,38 @@
 # -*- coding: utf-8 -*-
-# Copyright 2022 Cohesity Inc.
+# Copyright 2023 Cohesity Inc.
 
 import cohesity_management_sdk.models.migrate_oracle_clone_params
 
+
 class OracleUpdateRestoreTaskOptions(object):
 
     """Implementation of the 'OracleUpdateRestoreTaskOptions' model.
 
-    OracleUpdateRestoreTaskOptions holds the information needed for updating
-    an Oracle restore task. Currently this contains Oracle clone specific
-    details, which would be needed in the migration workflow.
+    OracleUpdateRestoreTaskOptions holds the information needed for updating an
+    Oracle restore task. Currently this contains Oracle clone specific details,
+    which would be needed in the migration workflow.
+
 
     Attributes:
+
         migrate_clone_params (MigrateOracleCloneParams): Details needed for
             Oracle Clone migrations.
     """
 
+
     # Create a mapping from Model property names to API property names
     _names = {
-        "migrate_clone_params":'MigrateCloneParams'
+        "migrate_clone_params":'migrateCloneParams',
     }
-
     def __init__(self,
-                 migrate_clone_params=None):
+                 migrate_clone_params=None,
+            ):
+
         """Constructor for the OracleUpdateRestoreTaskOptions class"""
 
         # Initialize members of the class
         self.migrate_clone_params = migrate_clone_params
 
-
     @classmethod
     def from_dictionary(cls,
                         dictionary):
@@ -47,9 +51,9 @@ class OracleUpdateRestoreTaskOptions(object):
             return None
 
         # Extract variables from the dictionary
-        migrate_clone_params = cohesity_management_sdk.models.migrate_oracle_clone_params.MigrateOracleCloneParams.from_dictionary(dictionary.get('MigrateCloneParams')) if dictionary.get('MigrateCloneParams') else None
+        migrate_clone_params = cohesity_management_sdk.models.migrate_oracle_clone_params.MigrateOracleCloneParams.from_dictionary(dictionary.get('migrateCloneParams')) if dictionary.get('migrateCloneParams') else None
 
         # Return an object of this model
-        return cls(migrate_clone_params)
-
-
+        return cls(
+            migrate_clone_params
+)
\ No newline at end of file
