@@ -1,38 +1,47 @@
 # -*- coding: utf-8 -*-
-# Copyright 2021 Cohesity Inc.
+# Copyright 2023 Cohesity Inc.
 
 class OrgVDCNetwork(object):
 
     """Implementation of the 'OrgVDCNetwork' model.
 
-    Attributes:
-        name (string): This is the name of the  Org VDC network.
-        vcd_uuid (string): This is the uuid of Org VDC network as identified
-            by VCD.
-        vcenter_moref_uuid (string): This is the uuid of the corresponding
-            network on VCenter.
+    TODO: type description here.
 
+
+    Attributes:
+
+        name (string): This is the name of the  Org VDC network.
+        network_type (string): This is the type of the corresponding network on
+            VCenter.
+        vcd_uuid (string): This is the uuid of Org VDC network as identified by
+            VCD.
+        vcenter_moref_uuid (string): This is the moref of the corresponding
+            network on VCenter.
     """
 
+
     # Create a mapping from Model property names to API property names
     _names = {
         "name":'name',
+        "network_type":'networkType',
         "vcd_uuid":'vcdUuid',
-        "vcenter_moref_uuid":'vcenterMorefUuid'
+        "vcenter_moref_uuid":'vcenterMorefUuid',
     }
-
     def __init__(self,
                  name=None,
+                 network_type=None,
                  vcd_uuid=None,
-                 vcenter_moref_uuid=None):
+                 vcenter_moref_uuid=None,
+            ):
+
         """Constructor for the OrgVDCNetwork class"""
 
         # Initialize members of the class
         self.name = name
+        self.network_type = network_type
         self.vcd_uuid = vcd_uuid
         self.vcenter_moref_uuid = vcenter_moref_uuid
 
-
     @classmethod
     def from_dictionary(cls,
                         dictionary):
@@ -52,12 +61,14 @@ class OrgVDCNetwork(object):
 
         # Extract variables from the dictionary
         name = dictionary.get('name')
+        network_type = dictionary.get('networkType')
         vcd_uuid = dictionary.get('vcdUuid')
         vcenter_moref_uuid = dictionary.get('vcenterMorefUuid')
 
         # Return an object of this model
-        return cls(name,
-                   vcd_uuid,
-                   vcenter_moref_uuid)
-
-
+        return cls(
+            name,
+            network_type,
+            vcd_uuid,
+            vcenter_moref_uuid
+)
\ No newline at end of file
