@@ -1,33 +1,34 @@
 # -*- coding: utf-8 -*-
-# Copyright 2022 Cohesity Inc.
-
+# Copyright 2023 Cohesity Inc.
 
 class Preferences(object):
 
     """Implementation of the 'Preferences' model.
 
-    TODO: type model description here.
+    TODO: type description here.
+
 
     Attributes:
+
         locale (string): Locale reflects the language settings of the user.
             Populate using the user preferences stored in Scribe for the user
             wherever needed.
-
     """
 
+
     # Create a mapping from Model property names to API property names
     _names = {
-        "locale":'locale'
+        "locale":'locale',
     }
-
     def __init__(self,
-                 locale=None):
+                 locale=None,
+            ):
+
         """Constructor for the Preferences class"""
 
         # Initialize members of the class
         self.locale = locale
 
-
     @classmethod
     def from_dictionary(cls,
                         dictionary):
@@ -49,6 +50,6 @@ class Preferences(object):
         locale = dictionary.get('locale')
 
         # Return an object of this model
-        return cls(locale)
-
-
+        return cls(
+            locale
+)
\ No newline at end of file
