@@ -1,68 +1,68 @@
 # -*- coding: utf-8 -*-
-# Copyright 2021 Cohesity Inc.
+# Copyright 2023 Cohesity Inc.
 
 import cohesity_management_sdk.models.protection_source
 import cohesity_management_sdk.models.tenant_info
 
+
 class ProtectionSourcesSummaryStats(object):
 
     """Implementation of the 'ProtectionSourcesSummaryStats' model.
 
-    Specifies Job Run (Snapshot) summary statistics about the specified
-    leaf Protection Source Object (such as a VM).
+    Specifies Job Run (Snapshot) summary statistics about the specified leaf
+    Protection Source Object (such as a VM).
+
 
     Attributes:
-        first_failed_run_time_usecs (int|long): Specifies the start time of
-            the first failed Job Run protecting this Protection Source Object.
-            The time is specified as a Unix epoch Timestamp (in microseconds).
-        first_successful_run_time_usecs (long|int): Specifies the start time
-            of the first successful Job Run protecting this Protection Source
-            Object.
-            The time is specified as a Unix epoch Timestamp (in microseconds).
-        last_failed_run_time_usecs (int|long): Specifies the start time of the
-            last failed Job Run protecting this Protection Source Object.
-            The time is specified as a Unix epoch Timestamp (in microseconds).
+
+        first_failed_run_time_usecs (long|int): Specifies the start time of the
+            first failed Job Run protecting this Protection Source Object. The
+            time is specified as a Unix epoch Timestamp (in microseconds).
+        first_successful_run_time_usecs (long|int): Specifies the start time of
+            the first successful Job Run protecting this Protection Source
+            Object. The time is specified as a Unix epoch Timestamp (in
+            microseconds).
+        last_failed_run_time_usecs (long|int): Specifies the start time of the
+            last failed Job Run protecting this Protection Source Object. The
+            time is specified as a Unix epoch Timestamp (in microseconds).
         last_run_end_time_usecs (long|int): Specifies the end time of the last
-            Job Run protecting this Protection Source Object.
-            The time is specified as a Unix epoch Timestamp (in microseconds).
+            Job Run protecting this Protection Source Object. The time is
+            specified as a Unix epoch Timestamp (in microseconds).
         last_run_error_msg (string): Specifies the error message associated
             with last run, if the last run has failed.
         last_run_start_time_usecs (long|int): Specifies the start time of the
-            last Run of this object's snapshot.
-            The time is specified in Unix epoch Timestamp (in microseconds).
-        last_run_status (RunStatusEnum): Specifies the Job Run status of the
-            last Job Run protecting this Protection Source Object.
-            'kSuccess' indicates that the Job Run was successful.
-            'kRunning' indicates that the Job Run is currently running.
-            'kWarning' indicates that the Job Run was successful but warnings
-            were issued.
-            'kCancelled' indicates that the Job Run was canceled.
-            'kError' indicates the Job Run encountered an error and did not
-            run to completion.
-        last_run_type (RunTypeEnum): Specifies the status of the Job Run.
-            'kRegular' indicates an incremental (CBT) backup. Incremental
-            backups utilizing CBT (if supported) are captured of the target
-            protection objects.
-            The first run of a kRegular schedule captures all the blocks.
-            'kFull' indicates a full (no CBT) backup. A complete backup
+            last Job Run protecting this Protection Source Object. The time is
+            specified as a Unix epoch Timestamp (in microseconds).
+        last_run_status (LastRunStatusEnum): Specifies the Job Run status of
+            the last Job Run protecting this Protection Source Object.
+            'kSuccess' indicates that the Job Run was successful. 'kRunning'
+            indicates that the Job Run is currently running. 'kWarning'
+            indicates that the Job Run was successful but warnings were issued.
+            'kCancelled' indicates that the Job Run was canceled. 'kError'
+            indicates the Job Run encountered an error and did not run to
+            completion.
+        last_run_type (LastRunTypeEnum): Specifies the Job Run type of the last
+            Job Run protecting this Protection Source Object. 'kRegular'
+            indicates an incremental (CBT) backup. Incremental backups
+            utilizing CBT (if supported) are captured of the target protection
+            objects. The first run of a kRegular schedule captures all the
+            blocks. 'kFull' indicates a full (no CBT) backup. A complete backup
             (all blocks) of the target protection objects are always captured
-            and Change Block Tracking (CBT) is not utilized.
-            'kLog' indicates a Database Log backup. Capture the database
-            transaction logs to allow rolling back to a specific point in
-            time.
-            'kSystem' indicates system volume backup. It produces an image
-            for bare metal recovery.
-        last_successful_run_time_usecs (int|long): Specifies the start time of
+            and Change Block Tracking (CBT) is not utilized. 'kLog' indicates a
+            Database Log backup. Capture the database transaction logs to allow
+            rolling back to a specific point in time. 'kSystem' indicates
+            system volume backup. It produces an image for bare metal recovery.
+        last_successful_run_time_usecs (long|int): Specifies the start time of
             the last successful Job Run protecting this Protection Source
-            Object.
-            The time is specified as a Unix epoch Timestamp (in microseconds).
+            Object. The time is specified as a Unix epoch Timestamp (in
+            microseconds).
         num_data_read_bytes (long|int): Specifies the total number of bytes
             read while protecting this Protection Source Object.
         num_errors (int): Specifies the total number of errors reported during
             Job Runs of this Protection Source Object.
-        num_logical_bytes_protected (int|long): Specifies the total logical
-            bytes protected for this Protection Source Object.
-            The logical size is when the data is fully hydrated or expanded.
+        num_logical_bytes_protected (long|int): Specifies the total logical
+            bytes protected for this Protection Source Object. The logical size
+            is when the data is fully hydrated or expanded.
         num_snapshots (int): Specifies the total number of Snapshots that are
             backing up this Protection Source Object.
         num_success_runs (int): Specifies the total number of successful Job
@@ -71,14 +71,15 @@ class ProtectionSourcesSummaryStats(object):
             during Job Runs of this Protection Source Object.
         protection_source (ProtectionSource): Specifies the leaf Protection
             Source Object (such as VM). Snapshot summary statistics are
-            reported for this Protection Source Object
-        registered_source (string): Specifies the name of the Registered
-            Source that is the top level parent of the specified Protection
-            Source Object.
-        tenants (list of TenantInfo): Specifies basic information about
-            tenants having access to the protection job.
+            reported for this Protection Source Object.
+        registered_source (string): Specifies the name of the Registered Source
+            that is the top level parent of the specified Protection Source
+            Object.
+        tenants (list of TenantInfo): Specifies basic information about tenants
+            having access to the protection job.
     """
 
+
     # Create a mapping from Model property names to API property names
     _names = {
         "first_failed_run_time_usecs":'firstFailedRunTimeUsecs',
@@ -88,7 +89,7 @@ class ProtectionSourcesSummaryStats(object):
         "last_run_error_msg":'lastRunErrorMsg',
         "last_run_start_time_usecs":'lastRunStartTimeUsecs',
         "last_run_status":'lastRunStatus',
-        "last_run_type":'last_run_type',
+        "last_run_type":'lastRunType',
         "last_successful_run_time_usecs":'lastSuccessfulRunTimeUsecs',
         "num_data_read_bytes":'numDataReadBytes',
         "num_errors":'numErrors',
@@ -98,9 +99,8 @@ class ProtectionSourcesSummaryStats(object):
         "num_warnings":'numWarnings',
         "protection_source":'protectionSource',
         "registered_source":'registeredSource',
-        "tenants":'tenants'
+        "tenants":'tenants',
     }
-
     def __init__(self,
                  first_failed_run_time_usecs=None,
                  first_successful_run_time_usecs=None,
@@ -119,7 +119,9 @@ class ProtectionSourcesSummaryStats(object):
                  num_warnings=None,
                  protection_source=None,
                  registered_source=None,
-                 tenants=None):
+                 tenants=None,
+            ):
+
         """Constructor for the ProtectionSourcesSummaryStats class"""
 
         # Initialize members of the class
@@ -142,7 +144,6 @@ class ProtectionSourcesSummaryStats(object):
         self.registered_source = registered_source
         self.tenants = tenants
 
-
     @classmethod
     def from_dictionary(cls,
                         dictionary):
@@ -168,10 +169,10 @@ class ProtectionSourcesSummaryStats(object):
         last_run_error_msg = dictionary.get('lastRunErrorMsg')
         last_run_start_time_usecs = dictionary.get('lastRunStartTimeUsecs')
         last_run_status = dictionary.get('lastRunStatus')
-        last_run_type = dictionary.get('last_run_type')
+        last_run_type = dictionary.get('lastRunType')
         last_successful_run_time_usecs = dictionary.get('lastSuccessfulRunTimeUsecs')
         num_data_read_bytes = dictionary.get('numDataReadBytes')
-        num_errors = dictionary.get('num_errors')
+        num_errors = dictionary.get('numErrors')
         num_logical_bytes_protected = dictionary.get('numLogicalBytesProtected')
         num_snapshots = dictionary.get('numSnapshots')
         num_success_runs = dictionary.get('numSuccessRuns')
@@ -185,24 +186,23 @@ class ProtectionSourcesSummaryStats(object):
                 tenants.append(cohesity_management_sdk.models.tenant_info.TenantInfo.from_dictionary(structure))
 
         # Return an object of this model
-        return cls(first_failed_run_time_usecs,
-                   first_successful_run_time_usecs,
-                   last_failed_run_time_usecs,
-                   last_run_end_time_usecs,
-                   last_run_error_msg,
-                   last_run_start_time_usecs,
-                   last_run_status,
-                   last_run_type,
-                   last_successful_run_time_usecs,
-                   num_data_read_bytes,
-                   num_errors,
-                   num_logical_bytes_protected,
-                   num_snapshots,
-                   num_success_runs,
-                   num_warnings,
-                   protection_source,
-                   registered_source,
-                   tenants)
-
-
-
+        return cls(
+            first_failed_run_time_usecs,
+            first_successful_run_time_usecs,
+            last_failed_run_time_usecs,
+            last_run_end_time_usecs,
+            last_run_error_msg,
+            last_run_start_time_usecs,
+            last_run_status,
+            last_run_type,
+            last_successful_run_time_usecs,
+            num_data_read_bytes,
+            num_errors,
+            num_logical_bytes_protected,
+            num_snapshots,
+            num_success_runs,
+            num_warnings,
+            protection_source,
+            registered_source,
+            tenants
+)
\ No newline at end of file
