@@ -1,9 +1,10 @@
 # -*- coding: utf-8 -*-
-# Copyright 2022 Cohesity Inc.
+# Copyright 2023 Cohesity Inc.
 
 import cohesity_management_sdk.models.object_meta
 import cohesity_management_sdk.models.pvc_info_pvc_spec
 
+
 class PVCInfo(object):
 
     """Implementation of the 'PVCInfo' model.
@@ -11,32 +12,35 @@ class PVCInfo(object):
     Message that encapsulates information about a PVC. We only extract relevant
     information from a larger response sent by Kubernetes.
 
+
     Attributes:
+
         api_version (string): APIVersion defines the versioned schema of this
-            representation of anobject. Servers should convert recognized
+            representation of an object. Servers should convert recognized
             schemas to the latest internal value, and may reject unrecognized
             values.
         kind (string): Kind is a string value representing the REST resource
             this object represents. Servers may infer this from the endpoint
             the client submits requests to.
         metadata (ObjectMeta): Metadata if any.
-        spec (PVCInfo_PVCSpec): Specifies the IPMI Username.
-
+        spec (PVCInfo_PVCSpec): TODO: Type description here.
     """
 
+
     # Create a mapping from Model property names to API property names
     _names = {
         "api_version":'apiVersion',
         "kind":'kind',
         "metadata":'metadata',
-        "spec":'spec'
+        "spec":'spec',
     }
-
     def __init__(self,
                  api_version=None,
                  kind=None,
                  metadata=None,
-                 spec=None):
+                 spec=None,
+            ):
+
         """Constructor for the PVCInfo class"""
 
         # Initialize members of the class
@@ -45,7 +49,6 @@ class PVCInfo(object):
         self.metadata = metadata
         self.spec = spec
 
-
     @classmethod
     def from_dictionary(cls,
                         dictionary):
@@ -70,9 +73,9 @@ class PVCInfo(object):
         spec = cohesity_management_sdk.models.pvc_info_pvc_spec.PVCInfo_PVCSpec.from_dictionary(dictionary.get('spec')) if dictionary.get('spec') else None
 
         # Return an object of this model
-        return cls(api_version,
-                   kind,
-                   metadata,
-                   spec)
-
-
+        return cls(
+            api_version,
+            kind,
+            metadata,
+            spec
+)
\ No newline at end of file
