@@ -1,6 +1,5 @@
 # -*- coding: utf-8 -*-
-# Copyright 2022 Cohesity Inc.
-
+# Copyright 2023 Cohesity Inc.
 
 class QoS(object):
 
@@ -8,7 +7,9 @@ class QoS(object):
 
     Specifies the Quality of Service (QoS) Policy for the View.
 
+
     Attributes:
+
         principal_id (long|int): Specifies the name of the QoS Policy used for
             the View.
         principal_name (string): Specifies the name of the QoS Policy used for
@@ -17,25 +18,25 @@ class QoS(object):
             complete list and descriptions, see the 'Create or Edit Views'
             topic in the documentation. If not specified, the default is
             'Backup Target Low'.
-
     """
 
+
     # Create a mapping from Model property names to API property names
     _names = {
         "principal_id":'principalId',
-        "principal_name":'principalName'
+        "principal_name":'principalName',
     }
-
     def __init__(self,
                  principal_id=None,
-                 principal_name=None):
+                 principal_name=None,
+            ):
+
         """Constructor for the QoS class"""
 
         # Initialize members of the class
         self.principal_id = principal_id
         self.principal_name = principal_name
 
-
     @classmethod
     def from_dictionary(cls,
                         dictionary):
@@ -58,7 +59,7 @@ class QoS(object):
         principal_name = dictionary.get('principalName')
 
         # Return an object of this model
-        return cls(principal_id,
-                   principal_name)
-
-
+        return cls(
+            principal_id,
+            principal_name
+)
\ No newline at end of file
