@@ -1,28 +1,30 @@
 # -*- coding: utf-8 -*-
-# Copyright 2022 Cohesity Inc.
+# Copyright 2023 Cohesity Inc.
 
 import cohesity_management_sdk.models.host_settings_check_result
 
+
 class RegisteredAppInfo(object):
 
     """Implementation of the 'RegisteredAppInfo' model.
 
-    TODO: type model description here.
+    TODO: type description here.
+
 
     Attributes:
+
         authentication_error_message (string): Specifies an authentication
             error message. This indicates the given credentials are rejected
             and the registration of the application is not successful.
-        authentication_status (AuthenticationStatusRegisteredAppInfoEnum):
-            Specifies the status of authenticating to the Protection Source
-            when registering this application with Cohesity Cluster. If the
-            status is 'kFinished' and there is no error, registration is
-            successful. Specifies the status of the authentication during the
-            registration of a Protection Source. 'kPending' indicates the
-            authentication is in progress. 'kScheduled' indicates the
-            authentication is scheduled. 'kFinished' indicates the
-            authentication is completed. 'kRefreshInProgress' indicates the
-            refresh is in progress.
+        authentication_status (AuthenticationStatusEnum): Specifies the status
+            of authenticating to the Protection Source when registering this
+            application with Cohesity Cluster. If the status is 'kFinished' and
+            there is no error, registration is successful. Specifies the status
+            of the authentication during the registration of a Protection
+            Source. 'kPending' indicates the authentication is in progress.
+            'kScheduled' indicates the authentication is scheduled. 'kFinished'
+            indicates the authentication is completed. 'kRefreshInProgress'
+            indicates the refresh is in progress.
         environment (EnvironmentRegisteredAppInfoEnum): Specifies the
             application environment. Supported environment types such as
             'kView', 'kSQL', 'kVMware', etc. NOTE: 'kPuppeteer' refers to
@@ -33,13 +35,13 @@ class RegisteredAppInfo(object):
             environment. 'kPuppeteer' indicates the Cohesity's Remote Adapter.
             'kPhysical' indicates the physical Protection Source environment.
             'kPure' indicates the Pure Storage Protection Source environment.
-            'Nimble' indicates the Nimble Storage Protection Source
+            'kNimble' indicates the Nimble Storage Protection Source
             environment. 'kAzure' indicates the Microsoft's Azure Protection
             Source environment. 'kNetapp' indicates the Netapp Protection
             Source environment. 'kAgent' indicates the Agent Protection Source
             environment. 'kGenericNas' indicates the Generic Network Attached
             Storage Protection Source environment. 'kAcropolis' indicates the
-            Acropolis Protection Source environment. 'kPhsicalFiles' indicates
+            Acropolis Protection Source environment. 'kPhysicalFiles' indicates
             the Physical Files Protection Source environment. 'kIsilon'
             indicates the Dell EMC's Isilon Protection Source environment.
             'kGPFS' indicates IBM's GPFS Protection Source environment. 'kKVM'
@@ -52,48 +54,56 @@ class RegisteredAppInfo(object):
             indicates the Flash Blade Protection Source environment.
             'kAWSNative' indicates the AWS Native Protection Source
             environment. 'kO365' indicates the Office 365 Protection Source
-            environment. 'kO365Outlook' indicates Office 365 outlook
-            Protection Source environment. 'kHyperFlex' indicates the Hyper
-            Flex Protection Source environment. 'kGCPNative' indicates the GCP
+            environment. 'kO365Outlook' indicates Office 365 outlook Protection
+            Source environment. 'kHyperFlex' indicates the Hyper Flex
+            Protection Source environment. 'kGCPNative' indicates the GCP
             Native Protection Source environment. 'kAzureNative' indicates the
-            Azure Native Protection Source environment.'kKubernetes' indicates
-            a Kubernetes Protection Source environment. 'kElastifile'
-            indicates Elastifile Protection Source environment. 'kAD'
-            indicates Active Directory Protection Source environment.
-            'kRDSSnapshotManager' indicates AWS RDS Protection Source
-            environment. 'kCassandra' indicates Cassandra Protection Source
-            environment. 'kMongoDB' indicates MongoDB Protection Source
-            environment. 'kCouchbase' indicates Couchbase Protection Source
-            environment. 'kHdfs' indicates Hdfs Protection Source environment.
-            'kHive' indicates Hive Protection Source environment. 'kHBase'
-            indicates HBase Protection Source environment.
-            'kUDA' indicates Universal Data Adapter Protection Source environment.
+            Azure Native Protection Source environment. 'kKubernetes' indicates
+            a Kubernetes Protection Source environment. 'kElastifile' indicates
+            Elastifile Protection Source environment. 'kAD' indicates Active
+            Directory Protection Source environment. 'kRDSSnapshotManager'
+            indicates AWS RDS Protection Source environment. 'kCassandra'
+            indicates Cassandra Protection Source environment. 'kMongoDB'
+            indicates MongoDB Protection Source environment. 'kCouchbase'
+            indicates Couchbase Protection Source environment. 'kHdfs'
+            indicates Hdfs Protection Source environment. 'kHive' indicates
+            Hive Protection Source environment. 'kHBase' indicates HBase
+            Protection Source environment. 'kUDA' indicates Universal Data
+            Adapter Protection Source environment. 'kO365Teams' indicates the
+            Office365 Teams Protection Source environment. 'kO365Group'
+            indicates the Office365 Groups Protection Source environment.
+            'kO365Exchange' indicates the Office365 Mailbox Protection Source
+            environment. 'kO365OneDrive' indicates the Office365 OneDrive
+            Protection Source environment. 'kO365Sharepoint' indicates the
+            Office365 SharePoint Protection Source environment.
+            'kO365PublicFolders' indicates the Office365 PublicFolders
+            Protection Source environment.
         host_settings_check_results (list of HostSettingsCheckResult):
             Specifies the list of check results internally performed to verify
             status of various services such as 'AgnetRunning',
             'SQLWriterRunning' etc.
         refresh_error_message (string): Specifies a message if there was any
             error encountered during the last rebuild of the application tree.
-            If there was no error during the last rebuild, this field is
-            reset.
-
+            If there was no error during the last rebuild, this field is reset.
     """
 
+
     # Create a mapping from Model property names to API property names
     _names = {
         "authentication_error_message":'authenticationErrorMessage',
         "authentication_status":'authenticationStatus',
         "environment":'environment',
         "host_settings_check_results":'hostSettingsCheckResults',
-        "refresh_error_message":'refreshErrorMessage'
+        "refresh_error_message":'refreshErrorMessage',
     }
-
     def __init__(self,
                  authentication_error_message=None,
                  authentication_status=None,
                  environment=None,
                  host_settings_check_results=None,
-                 refresh_error_message=None):
+                 refresh_error_message=None,
+            ):
+
         """Constructor for the RegisteredAppInfo class"""
 
         # Initialize members of the class
@@ -103,7 +113,6 @@ class RegisteredAppInfo(object):
         self.host_settings_check_results = host_settings_check_results
         self.refresh_error_message = refresh_error_message
 
-
     @classmethod
     def from_dictionary(cls,
                         dictionary):
@@ -133,10 +142,10 @@ class RegisteredAppInfo(object):
         refresh_error_message = dictionary.get('refreshErrorMessage')
 
         # Return an object of this model
-        return cls(authentication_error_message,
-                   authentication_status,
-                   environment,
-                   host_settings_check_results,
-                   refresh_error_message)
-
-
+        return cls(
+            authentication_error_message,
+            authentication_status,
+            environment,
+            host_settings_check_results,
+            refresh_error_message
+)
\ No newline at end of file
