@@ -1,16 +1,15 @@
 # -*- coding: utf-8 -*-
-# Copyright 2022 Cohesity Inc.
+# Copyright 2023 Cohesity Inc.
 
 class RegisteringAppEnum(object):
 
     """Implementation of the 'RegisteringApp' enum.
-
-    Application being registered.
-    This param is used to indicate the app for which the job is created.
-    'oracle' indicates that the job was created for oracle app.
-    'msSql' indicates that the job was created for msSql app.
+    Application being registered. This param is used to indicate the app for
+    which the job is created. 'oracle' indicates that the job was created for
+    oracle app. 'msSql' indicates that the job was created for msSql app.
     'physical' indicates that the job was created for physical machine.
 
+
     Attributes:
         ORACLE: TODO: type description here.
         MSSQL: TODO: type description here.
@@ -23,4 +22,3 @@ class RegisteringAppEnum(object):
     MSSQL = 'msSql'
 
     PHYSICAL = 'physical'
-
