@@ -1,6 +1,5 @@
 # -*- coding: utf-8 -*-
-# Copyright 2022 Cohesity Inc.
-
+# Copyright 2023 Cohesity Inc.
 
 class RenameViewParam(object):
 
@@ -8,24 +7,26 @@ class RenameViewParam(object):
 
     Specifies the rename parameters for the view.
 
-    Attributes:
-        new_view_name (string): Specifies the new name of the View.
 
+    Attributes:
+
+        new_view_name (string): Specifies the new name of the View.
     """
 
+
     # Create a mapping from Model property names to API property names
     _names = {
-        "new_view_name":'newViewName'
+        "new_view_name":'newViewName',
     }
-
     def __init__(self,
-                 new_view_name=None):
+                 new_view_name=None,
+            ):
+
         """Constructor for the RenameViewParam class"""
 
         # Initialize members of the class
         self.new_view_name = new_view_name
 
-
     @classmethod
     def from_dictionary(cls,
                         dictionary):
@@ -47,6 +48,6 @@ class RenameViewParam(object):
         new_view_name = dictionary.get('newViewName')
 
         # Return an object of this model
-        return cls(new_view_name)
-
-
+        return cls(
+            new_view_name
+)
\ No newline at end of file
