@@ -1,25 +1,28 @@
 # -*- coding: utf-8 -*-
-# Copyright 2021 Cohesity Inc.
+# Copyright 2023 Cohesity Inc.
 
-import cohesity_management_sdk.models.sql_update_restore_task_options
 import cohesity_management_sdk.models.files_to_directory_mapping
+import cohesity_management_sdk.models.sql_update_restore_task_options
+
 
 class RestoreSqlAppObjectParams(object):
 
     """Implementation of the 'RestoreSqlAppObjectParams' model.
 
-    TODO: type model description here.
+    TODO: type description here.
+
 
     Attributes:
+
         capture_tail_logs (bool): Set to true if tail logs are to be captured
             before the restore operation. This is only applicable if we are
-            restoring the SQL database to its original source, and the
-            database is not being renamed.
+            restoring the SQL database to its original source, and the database
+            is not being renamed.
         continue_after_error (bool): Whether restore should continue after
             encountering a page checksum error.
         data_file_destination (string): Which directory to put the database
-            data files. Missing directory will be automatically created.
-            Cannot be empty if not restoring to the original SQL instance.
+            data files. Missing directory will be automatically created. Cannot
+            be empty if not restoring to the original SQL instance.
         db_restore_overwrite_policy (int): Policy to overwrite an existing DB
             during a restore operation.
         enable_checksum (bool): Whether restore checksums are enabled.
@@ -30,26 +33,27 @@ class RestoreSqlAppObjectParams(object):
             for multi-stage SQL restore task is enabled. This field is valid
             only if is_multi_state_restore is set to true.
         is_multi_stage_restore (bool): The following field is set if we are
-            creating a multi-stage SQL restore task needed for features such
-            as Hot-Standby.
+            creating a multi-stage SQL restore task needed for features such as
+            Hot-Standby.
         keep_cdc (bool): Set to true to keep cdc on restored database.
         log_file_destination (string): Which directory to put the database log
             files. Missing directory will be automatically created. Cannot be
             empty if not restoring to the original SQL instance.
-        multi_stage_restore_options (SqlUpdateRestoreTaskOptions): TODO: type
-            description here.
+        multi_stage_restore_options (SqlUpdateRestoreTaskOptions): Note that
+            this field is set internally by Magneto, and should not be set by
+            Iris.
         new_database_name (string): The new name of the database, if it is
             going to be renamed. app_entity in RestoreAppObject has to be
             non-empty for the renaming, otherwise it does not make sense to
             rename all databases in the owner.
         restore_time_secs (long|int): The time to which the SQL database needs
-            to be restored. This allows for granular recovery of SQL
-            databases. If this is not set, the SQL database will be recovered
-            to the full/incremental snapshot (specified in the owner's restore
-            object in AppOwnerRestoreInfo).
-        resume_restore (bool): Resume restore if sql instance/database exist
-            in restore/recovering state. The database might be in
-            restore/recovering state if previous restore failed or previous
+            to be restored. This allows for granular recovery of SQL databases.
+            If this is not set, the SQL database will be recovered to the
+            full/incremental snapshot (specified in the owner's restore object
+            in AppOwnerRestoreInfo).
+        resume_restore (bool): Resume restore if sql instance/database exist in
+            restore/recovering state. The database might be in
+            restore/recovering state if previous restore failed or previous 
             restore was attempted  with norecovery option.
         secondary_data_file_destination (string): Which directory to put the
             secondary data files of the database. Secondary data files are
@@ -58,22 +62,21 @@ class RestoreSqlAppObjectParams(object):
             will be automatically created if its missing.
         secondary_data_file_destination_vec (list of FilesToDirectoryMapping):
             Specify the secondary data files and corresponding direcories of
-            the DB. Secondary data files are optional and are user defined.
-            The recommended file extension for secondary files is ".ndf".  If
-            this option is specified and the destination folders do not exist
-            they will be automatically created.
+            the DB. Secondary data files are optional and are user defined. The
+            recommended file extension for secondary files is ".ndf".  If this
+            option is specified and the destination folders do not exist they
+            will be automatically created.
         with_clause (string): 'with_clause' contains 'with clause' to be used
             in native sql restore command. This is only applicable for db
             restore of native sql backup. Here user can specify multiple
             restore options. Example: "WITH BUFFERCOUNT = 575, MAXTRANSFERSIZE
-            = 2097152". If this is not specified, we use the value specified
-            in magneto_sql_native_restore_with_clause gflag.
-        with_no_recovery (bool): Set to true if we want to recover the
-            database in "NO_RECOVERY" mode which does not bring it online
-            after restore.
-
+            = 2097152". If this is not specified, we use the value specified in
+            magneto_sql_native_restore_with_clause gflag.
+        with_no_recovery (bool): Set to true if we want to recover the database
+            in "NO_RECOVERY" mode which does not bring it online after restore.
     """
 
+
     # Create a mapping from Model property names to API property names
     _names = {
         "capture_tail_logs":'captureTailLogs',
@@ -93,9 +96,8 @@ class RestoreSqlAppObjectParams(object):
         "secondary_data_file_destination":'secondaryDataFileDestination',
         "secondary_data_file_destination_vec":'secondaryDataFileDestinationVec',
         "with_clause":'withClause',
-        "with_no_recovery":'withNoRecovery'
+        "with_no_recovery":'withNoRecovery',
     }
-
     def __init__(self,
                  capture_tail_logs=None,
                  continue_after_error=None,
@@ -114,7 +116,9 @@ class RestoreSqlAppObjectParams(object):
                  secondary_data_file_destination=None,
                  secondary_data_file_destination_vec=None,
                  with_clause=None,
-                 with_no_recovery=None):
+                 with_no_recovery=None,
+            ):
+
         """Constructor for the RestoreSqlAppObjectParams class"""
 
         # Initialize members of the class
@@ -137,7 +141,6 @@ class RestoreSqlAppObjectParams(object):
         self.with_clause = with_clause
         self.with_no_recovery = with_no_recovery
 
-
     @classmethod
     def from_dictionary(cls,
                         dictionary):
@@ -180,23 +183,23 @@ class RestoreSqlAppObjectParams(object):
         with_no_recovery = dictionary.get('withNoRecovery')
 
         # Return an object of this model
-        return cls(capture_tail_logs,
-                   continue_after_error,
-                   data_file_destination,
-                   db_restore_overwrite_policy,
-                   enable_checksum,
-                   instance_name,
-                   is_auto_sync_enabled,
-                   is_multi_stage_restore,
-                   keep_cdc,
-                   log_file_destination,
-                   multi_stage_restore_options,
-                   new_database_name,
-                   restore_time_secs,
-                   resume_restore,
-                   secondary_data_file_destination,
-                   secondary_data_file_destination_vec,
-                   with_clause,
-                   with_no_recovery)
-
-
+        return cls(
+            capture_tail_logs,
+            continue_after_error,
+            data_file_destination,
+            db_restore_overwrite_policy,
+            enable_checksum,
+            instance_name,
+            is_auto_sync_enabled,
+            is_multi_stage_restore,
+            keep_cdc,
+            log_file_destination,
+            multi_stage_restore_options,
+            new_database_name,
+            restore_time_secs,
+            resume_restore,
+            secondary_data_file_destination,
+            secondary_data_file_destination_vec,
+            with_clause,
+            with_no_recovery
+)
\ No newline at end of file
