@@ -1,6 +1,5 @@
 # -*- coding: utf-8 -*-
-# Copyright 2022 Cohesity Inc.
-
+# Copyright 2023 Cohesity Inc.
 
 class RoleDeleteParameters(object):
 
@@ -8,25 +7,27 @@ class RoleDeleteParameters(object):
 
     Specifies the parameters required for deleting one or more roles.
 
+
     Attributes:
+
         names (list of string): Array of Role Names.  Specifies the list of
             roles to delete which are specified by role names.
-
     """
 
+
     # Create a mapping from Model property names to API property names
     _names = {
-        "names":'names'
+        "names":'names',
     }
-
     def __init__(self,
-                 names=None):
+                 names=None,
+            ):
+
         """Constructor for the RoleDeleteParameters class"""
 
         # Initialize members of the class
         self.names = names
 
-
     @classmethod
     def from_dictionary(cls,
                         dictionary):
@@ -45,9 +46,9 @@ class RoleDeleteParameters(object):
             return None
 
         # Extract variables from the dictionary
-        names = dictionary.get('names')
+        names = dictionary.get("names")
 
         # Return an object of this model
-        return cls(names)
-
-
+        return cls(
+            names
+)
\ No newline at end of file
