@@ -1,16 +1,15 @@
 # -*- coding: utf-8 -*-
-# Copyright 2021 Cohesity Inc.
+# Copyright 2023 Cohesity Inc.
 
 class S3AccessEnum(object):
 
     """Implementation of the 'S3Access' enum.
-
     Specifies whether clients from this subnet can access using S3 protocol.
-    Protocol access level.
-    'kDisabled' indicates Protocol access level 'Disabled'
-    'kReadOnly' indicates Protocol access level 'ReadOnly'
+    Protocol access level. 'kDisabled' indicates Protocol access level
+    'Disabled' 'kReadOnly' indicates Protocol access level 'ReadOnly'
     'kReadWrite' indicates Protocol access level 'ReadWrite'
 
+
     Attributes:
         KDISABLED: TODO: type description here.
         KREADONLY: TODO: type description here.
@@ -23,4 +22,3 @@ class S3AccessEnum(object):
     KREADONLY = 'kReadOnly'
 
     KREADWRITE = 'kReadWrite'
-
