@@ -1,43 +1,52 @@
 # -*- coding: utf-8 -*-
-# Copyright 2022 Cohesity Inc.
+# Copyright 2023 Cohesity Inc.
 
 import cohesity_management_sdk.models.site_backup_file
+import cohesity_management_sdk.models.site_info
+
 
 class SiteBackupStatus(object):
 
     """Implementation of the 'SiteBackupStatus' model.
 
+    TODO: type description here.
+
+
     Attributes:
+
         backup_file_vec (list of SiteBackupFile): List of backuped files. Its
             PnP package and any other files required to recover the site.
-        ipmi_password (string): Specifies the IPMI Password.
-        ipmi_subnet_mask (string): Specifies the subnet mask for the IPMI
-            network.
-        ipmi_username (string): Specifies the IPMI Username.
-
+        option_flags (int): Actual options with which this site was backed up
+            (BackupSiteArg.BackupSiteOptionFlags).
+        site_info (SiteInfo): This site info is used during recovery to recover
+            a full site.
+        warning_vec (list of string): Backup succeeded, but there were some
+            warnings for user. For example we could not backup term store due
+            to lack of permissions.
     """
 
+
     # Create a mapping from Model property names to API property names
     _names = {
         "backup_file_vec":'backupFileVec',
-        "ipmi_password":'ipmiPassword',
-        "ipmi_subnet_mask":'ipmiSubnetMask',
-        "ipmi_username":'ipmiUsername'
+        "option_flags":'optionFlags',
+        "site_info":'siteInfo',
+        "warning_vec":'warningVec',
     }
-
     def __init__(self,
                  backup_file_vec=None,
-                 ipmi_password=None,
-                 ipmi_subnet_mask=None,
-                 ipmi_username=None):
+                 option_flags=None,
+                 site_info=None,
+                 warning_vec=None,
+            ):
+
         """Constructor for the SiteBackupStatus class"""
 
         # Initialize members of the class
         self.backup_file_vec = backup_file_vec
-        self.ipmi_password = ipmi_password
-        self.ipmi_subnet_mask = ipmi_subnet_mask
-        self.ipmi_username = ipmi_username
-
+        self.option_flags = option_flags
+        self.site_info = site_info
+        self.warning_vec = warning_vec
 
     @classmethod
     def from_dictionary(cls,
@@ -62,14 +71,14 @@ class SiteBackupStatus(object):
             backup_file_vec = list()
             for structure in dictionary.get('backupFileVec'):
                 backup_file_vec.append(cohesity_management_sdk.models.site_backup_file.SiteBackupFile.from_dictionary(structure))
-        ipmi_password = dictionary.get('ipmiPassword')
-        ipmi_subnet_mask = dictionary.get('ipmiSubnetMask')
-        ipmi_username = dictionary.get('ipmiUsername')
+        option_flags = dictionary.get('optionFlags')
+        site_info = cohesity_management_sdk.models.site_info.SiteInfo.from_dictionary(dictionary.get('siteInfo')) if dictionary.get('siteInfo') else None
+        warning_vec = dictionary.get("warningVec")
 
         # Return an object of this model
-        return cls(backup_file_vec,
-                   ipmi_password,
-                   ipmi_subnet_mask,
-                   ipmi_username)
-
-
+        return cls(
+            backup_file_vec,
+            option_flags,
+            site_info,
+            warning_vec
+)
\ No newline at end of file
