@@ -1,26 +1,34 @@
 # -*- coding: utf-8 -*-
-# Copyright 2021 Cohesity Inc.
+# Copyright 2023 Cohesity Inc.
 
 import cohesity_management_sdk.models.archival_external_target
 import cohesity_management_sdk.models.cloud_deploy_target_details
 import cohesity_management_sdk.models.replication_target_settings
 
+
 class SnapshotTargetSettings(object):
 
     """Implementation of the 'SnapshotTargetSettings' model.
 
-    Specifies settings about a target where a copied Snapshot is stored.
-    A target can be a Remote Cluster or an Archival External Target such as
-    AWS or Tape.
+    Specifies settings about a target where a copied Snapshot is stored. A
+    target can be a Remote Cluster or an Archival External Target such as AWS
+    or Tape.
+
 
     Attributes:
-        archival_target (ArchivalExternalTarget): Specifies settings about the
-            Archival External Target (such as Tape or AWS).
-        cloud_replication_target (CloudDeployTargetDetails): Message that
-            specifies the details about CloudDeploy target where backup
-            snapshots may be converted and stored.
-        replication_target (ReplicationTargetSettings): Specifies settings
-            about the Remote Cohesity Cluster where Snapshots are copied to.
+
+        archival_target (ArchivalExternalTarget): Specifies the Archival
+            External Target for storing a copied Snapshot. If the type is not
+            'kLocal', either a replicationTarget, archivalExternalTarget or
+            cloudReplicationTarget must be specified.
+        cloud_replication_target (CloudDeployTargetDetails): Specifies the
+            cloud replication target for storing a copied Snapshot. If the type
+            is not 'kLocal', either a replicationTarget, archivalExternalTarget
+            or cloudReplicationTarget must be specified.
+        replication_target (ReplicationTargetSettings): Specifies the
+            replication target (Remote Cluster) for storing a copied Snapshot.
+            If the type is not 'kLocal', either a replicationTarget,
+            archivalExternalTarget or cloudReplicationTarget must be specified.
         mtype (TypeSnapshotTargetSettingsEnum): Specifies the type of a
             Snapshot target such as 'kLocal', 'kRemote' or 'kArchival'.
             'kLocal' means the Snapshot is stored on a local Cohesity Cluster.
@@ -29,22 +37,23 @@ class SnapshotTargetSettings(object):
             replication.) 'kArchival' means the Snapshot is stored on a
             Archival External Target (such as Tape or AWS). 'kCloudDeploy'
             means the Snapshot is stored on a Cloud platform.
-
     """
 
+
     # Create a mapping from Model property names to API property names
     _names = {
         "archival_target":'archivalTarget',
         "cloud_replication_target":'cloudReplicationTarget',
         "replication_target":'replicationTarget',
-        "mtype":'type'
+        "mtype":'type',
     }
-
     def __init__(self,
                  archival_target=None,
                  cloud_replication_target=None,
                  replication_target=None,
-                 mtype=None):
+                 mtype=None,
+            ):
+
         """Constructor for the SnapshotTargetSettings class"""
 
         # Initialize members of the class
@@ -53,7 +62,6 @@ class SnapshotTargetSettings(object):
         self.replication_target = replication_target
         self.mtype = mtype
 
-
     @classmethod
     def from_dictionary(cls,
                         dictionary):
@@ -78,9 +86,9 @@ class SnapshotTargetSettings(object):
         mtype = dictionary.get('type')
 
         # Return an object of this model
-        return cls(archival_target,
-                   cloud_replication_target,
-                   replication_target,
-                   mtype)
-
-
+        return cls(
+            archival_target,
+            cloud_replication_target,
+            replication_target,
+            mtype
+)
\ No newline at end of file
