@@ -1,6 +1,5 @@
 # -*- coding: utf-8 -*-
-# Copyright 2021 Cohesity Inc.
-
+# Copyright 2023 Cohesity Inc.
 
 class SystemAppStatusResult(object):
 
@@ -8,40 +7,42 @@ class SystemAppStatusResult(object):
 
     Specifies the result of getting the status of System Apps.
 
+
     Attributes:
+
         available_replicas (int): Required field.
-        name (string): Required field.
         configured_replicas (int): Required field.
+        name (string): Required field.
         ready_replicas (int): Required field.
         service_endpoint (string): Required field.
-
     """
 
+
     # Create a mapping from Model property names to API property names
     _names = {
         "available_replicas":'availableReplicas',
-        "name":'name',
         "configured_replicas":'configuredReplicas',
+        "name":'name',
         "ready_replicas":'readyReplicas',
-        "service_endpoint":'serviceEndpoint'
+        "service_endpoint":'serviceEndpoint',
     }
-
     def __init__(self,
                  available_replicas=None,
-                 name=None,
                  configured_replicas=None,
+                 name=None,
                  ready_replicas=None,
-                 service_endpoint=None):
+                 service_endpoint=None,
+            ):
+
         """Constructor for the SystemAppStatusResult class"""
 
         # Initialize members of the class
         self.available_replicas = available_replicas
-        self.name = name
         self.configured_replicas = configured_replicas
+        self.name = name
         self.ready_replicas = ready_replicas
         self.service_endpoint = service_endpoint
 
-
     @classmethod
     def from_dictionary(cls,
                         dictionary):
@@ -61,16 +62,16 @@ class SystemAppStatusResult(object):
 
         # Extract variables from the dictionary
         available_replicas = dictionary.get('availableReplicas')
-        name = dictionary.get('name')
         configured_replicas = dictionary.get('configuredReplicas')
-        service_endpoint = dictionary.get('serviceEndpoint')
+        name = dictionary.get('name')
         ready_replicas = dictionary.get('readyReplicas')
+        service_endpoint = dictionary.get('serviceEndpoint')
 
         # Return an object of this model
-        return cls(available_replicas,
-                   name,
-                   configured_replicas,
-                   ready_replicas,
-                   service_endpoint)
-
-
+        return cls(
+            available_replicas,
+            configured_replicas,
+            name,
+            ready_replicas,
+            service_endpoint
+)
\ No newline at end of file
