@@ -1,15 +1,12 @@
 # -*- coding: utf-8 -*-
-# Copyright 2021 Cohesity Inc.
+# Copyright 2023 Cohesity Inc.
 
 class TagEnum(object):
 
     """Implementation of the 'Tag' enum.
+    Specifies use of the nodeport kDefault - No specific service. kHttp - HTTP
+    server. kHttps -  Secure HTTP server. kSsh - Secure shell server.
 
-    Specifies use of the nodeport
-    kDefault - No specific service.
-    kHttp - HTTP server.
-    kHttps -  Secure HTTP server.
-    kSsh - Secure shell server.
 
     Attributes:
         KDEFAULT: TODO: type description here.
@@ -26,4 +23,3 @@ class TagEnum(object):
     KHTTPS = 'kHttps'
 
     KSSH = 'kSsh'
-
