@@ -1,6 +1,5 @@
 # -*- coding: utf-8 -*-
-# Copyright 2022 Cohesity Inc.
-
+# Copyright 2023 Cohesity Inc.
 
 class TieringAuditLogConfiguration(object):
 
@@ -8,34 +7,35 @@ class TieringAuditLogConfiguration(object):
 
     Specifies the settings of the tiering audit log configuration.
 
+
     Attributes:
+
         enabled (bool): Specifies if tiering audit logging is enabled on the
-            Cohesity Cluster.
-            If 'true', NAS tiering audit logging is enabled. Otherwise, it is
-            disabled.
+            Cohesity Cluster. If 'true', NAS tiering audit logging is enabled.
+            Otherwise, it is disabled.
         retention_period_days (int): Specifies the number of days to keep
             (retain) the tiering audit logs. Audit logs generated before the
             period of time specified by retentionPeriodDays are removed from
             the Cohesity Cluster.
-
     """
 
+
     # Create a mapping from Model property names to API property names
     _names = {
-        "enabled": 'enabled',
-        "retention_period_days": 'retentionPeriodDays'
+        "enabled":'enabled',
+        "retention_period_days":'retentionPeriodDays',
     }
-
     def __init__(self,
                  enabled=None,
-                 retention_period_days=None):
+                 retention_period_days=None,
+            ):
+
         """Constructor for the TieringAuditLogConfiguration class"""
 
         # Initialize members of the class
         self.enabled = enabled
         self.retention_period_days = retention_period_days
 
-
     @classmethod
     def from_dictionary(cls,
                         dictionary):
@@ -54,11 +54,11 @@ class TieringAuditLogConfiguration(object):
             return None
 
         # Extract variables from the dictionary
-        enabled = dictionary.get('enabled', None)
-        retention_period_days = dictionary.get('retentionPeriodDays', None)
+        enabled = dictionary.get('enabled')
+        retention_period_days = dictionary.get('retentionPeriodDays')
 
         # Return an object of this model
-        return cls(enabled,
-                   retention_period_days)
-
-
+        return cls(
+            enabled,
+            retention_period_days
+)
\ No newline at end of file
