@@ -1,13 +1,13 @@
 # -*- coding: utf-8 -*-
-# Copyright 2022 Cohesity Inc.
+# Copyright 2023 Cohesity Inc.
 
 class TypeCloneTaskRequestEnum(object):
 
-    """Implementation of the 'Type_CloneTaskRequest' enum.
-
+    """Implementation of the 'TypeCloneTaskRequest' enum.
     Specifies the type of Restore Task such as 'kCloneVMs' or 'kCloneView'.
-    'kCloneVMs' specifies a Restore Task that clones VMs.
-    'kCloneView' specifies a Restore Task that clones a View.
+    'kCloneVMs' specifies a Restore Task that clones VMs. 'kCloneView'
+    specifies a Restore Task that clones a View.
+
 
     Attributes:
         KCLONEVMS: TODO: type description here.
@@ -18,4 +18,3 @@ class TypeCloneTaskRequestEnum(object):
     KCLONEVMS = 'kCloneVMs'
 
     KCLONEVIEW = 'kCloneView'
-
