@@ -1,19 +1,17 @@
 # -*- coding: utf-8 -*-
-# Copyright 2022 Cohesity Inc.
+# Copyright 2023 Cohesity Inc.
 
 class TypeSqlProtectionSourceEnum(object):
 
-    """Implementation of the 'Type_SqlProtectionSource' enum.
-
+    """Implementation of the 'TypeSqlProtectionSource' enum.
     Specifies the type of the managed Object in a SQL Protection Source.
-    Examples of SQL Objects include 'kInstance' and 'kDatabase'.
-    'kInstance' indicates that SQL server instance is being protected.
-    'kDatabase' indicates that SQL server database is being protected.
-    'kAAG' indicates that SQL AAG (AlwaysOn Availability Group) is being
-    protected.
+    Examples of SQL Objects include 'kInstance' and 'kDatabase'. 'kInstance'
+    indicates that SQL server instance is being protected. 'kDatabase'
+    indicates that SQL server database is being protected. 'kAAG' indicates
+    that SQL AAG (AlwaysOn Availability Group) is being protected.
     'kAAGRootContainer' indicates that SQL AAG's root container is being
-    protected.
-    'kRootContainer' indicates root container for SQL sources.
+    protected. 'kRootContainer' indicates root container for SQL sources.
+
 
     Attributes:
         KINSTANCE: TODO: type description here.
@@ -33,4 +31,3 @@ class TypeSqlProtectionSourceEnum(object):
     KAAGROOTCONTAINER = 'kAAGRootContainer'
 
     KROOTCONTAINER = 'kRootContainer'
-
