@@ -1,15 +1,14 @@
 # -*- coding: utf-8 -*-
-# Copyright 2022 Cohesity Inc.
+# Copyright 2023 Cohesity Inc.
 
 class TypeViewProtectionSourceEnum(object):
 
-    """Implementation of the 'Type_ViewProtectionSource' enum.
-
+    """Implementation of the 'TypeViewProtectionSource' enum.
     Specifies the type of managed Object in a View Protection Source
-    environment.
-    Examples of View Objects include 'kViewBox' or 'kView'.
-    'kViewBox' indicates Storage Domain as a Protection Source type.
-    'kView' indicates View as a Protection Source type.
+    environment. Examples of View Objects include 'kViewBox' or 'kView'.
+    'kViewBox' indicates Storage Domain as a Protection Source type. 'kView'
+    indicates View as a Protection Source type.
+
 
     Attributes:
         KVIEWBOX: TODO: type description here.
@@ -20,4 +19,3 @@ class TypeViewProtectionSourceEnum(object):
     KVIEWBOX = 'kViewBox'
 
     KVIEW = 'kView'
-
