@@ -1,34 +1,38 @@
 # -*- coding: utf-8 -*-
-# Copyright 2022 Cohesity Inc.
+# Copyright 2023 Cohesity Inc.
 
 class UdaRestoreObjectParams(object):
 
     """Implementation of the 'UdaRestoreObjectParams' model.
 
+    TODO: type description here.
+
+
     Attributes:
+
         new_object_name (string): The new name of the object, if it is going to
             be renamed.
-        overwrite (bool): Whether to overwrite or keep the object if the
-            object being recovered already exists in the destination.
+        overwrite (bool): Whether to overwrite or keep the object if the object
+            being recovered already exists in the destination.
         restore_time_secs (long|int): The point-in-time to which object needs
             to be restored. This allows for the granular recovery of Uda
             objects. If this is not set, the Uda object will be restored to
             full/incremental snapshot.
-
-
     """
 
+
     # Create a mapping from Model property names to API property names
     _names = {
         "new_object_name":'newObjectName',
         "overwrite":'overwrite',
-        "restore_time_secs":'restoreTimeSecs'
+        "restore_time_secs":'restoreTimeSecs',
     }
-
     def __init__(self,
                  new_object_name=None,
                  overwrite=None,
-                 restore_time_secs=None):
+                 restore_time_secs=None,
+            ):
+
         """Constructor for the UdaRestoreObjectParams class"""
 
         # Initialize members of the class
@@ -36,7 +40,6 @@ class UdaRestoreObjectParams(object):
         self.overwrite = overwrite
         self.restore_time_secs = restore_time_secs
 
-
     @classmethod
     def from_dictionary(cls,
                         dictionary):
@@ -56,12 +59,12 @@ class UdaRestoreObjectParams(object):
 
         # Extract variables from the dictionary
         new_object_name = dictionary.get('newObjectName')
-        overwrite =  dictionary.get('overwrite')
+        overwrite = dictionary.get('overwrite')
         restore_time_secs = dictionary.get('restoreTimeSecs')
 
         # Return an object of this model
-        return cls(new_object_name,
-                   overwrite,
-                   restore_time_secs)
-
-
+        return cls(
+            new_object_name,
+            overwrite,
+            restore_time_secs
+)
\ No newline at end of file
