@@ -1,6 +1,5 @@
 # -*- coding: utf-8 -*-
-# Copyright 2022 Cohesity Inc.
-
+# Copyright 2023 Cohesity Inc.
 
 class UpdateBondParameters(object):
 
@@ -8,31 +7,34 @@ class UpdateBondParameters(object):
 
     Specifies the parameters needed to modify the bonding mode of a bond.
 
+
     Attributes:
-        bonding_mode (BondingModeUpdateBondParametersEnum): Specifies the new
-            bonding mode. 'kActiveBackup' indicates active backup bonding
-            mode. 'k802_3ad' indicates 802.3ad bonding mode.
+
+        bonding_mode (BondingModeEnum): Specifies the new bonding mode.
+            'kActiveBackup' indicates active backup bonding mode. 'k802_3ad'
+            indicates 802.3ad bonding mode.
         lacp_rate (string): Specifies the LACP rate. If not specified, This
             value will default to 0 (slow).
         name (string): Specifies the name of the bond being updated.
         xmit_hash_policy (string): Specifies the xmit hash policy. If not
             specified, This value will default to 1 (layer3+4).
-
     """
 
+
     # Create a mapping from Model property names to API property names
     _names = {
         "bonding_mode":'bondingMode',
-        "name":'name',
         "lacp_rate":'lacpRate',
-        "xmit_hash_policy":'xmitHashPolicy'
+        "name":'name',
+        "xmit_hash_policy":'xmitHashPolicy',
     }
-
     def __init__(self,
                  bonding_mode=None,
-                 name=None,
                  lacp_rate=None,
-                 xmit_hash_policy=None):
+                 name=None,
+                 xmit_hash_policy=None,
+            ):
+
         """Constructor for the UpdateBondParameters class"""
 
         # Initialize members of the class
@@ -41,7 +43,6 @@ class UpdateBondParameters(object):
         self.name = name
         self.xmit_hash_policy = xmit_hash_policy
 
-
     @classmethod
     def from_dictionary(cls,
                         dictionary):
@@ -61,14 +62,14 @@ class UpdateBondParameters(object):
 
         # Extract variables from the dictionary
         bonding_mode = dictionary.get('bondingMode')
-        name = dictionary.get('name')
         lacp_rate = dictionary.get('lacpRate')
+        name = dictionary.get('name')
         xmit_hash_policy = dictionary.get('xmitHashPolicy')
 
         # Return an object of this model
-        return cls(bonding_mode,
-                   name,
-                   lacp_rate,
-                   xmit_hash_policy)
-
-
+        return cls(
+            bonding_mode,
+            lacp_rate,
+            name,
+            xmit_hash_policy
+)
\ No newline at end of file
