@@ -1,6 +1,5 @@
 # -*- coding: utf-8 -*-
-# Copyright 2022 Cohesity Inc.
-
+# Copyright 2023 Cohesity Inc.
 
 class UpdateLdapProviderParams(object):
 
@@ -8,25 +7,27 @@ class UpdateLdapProviderParams(object):
 
     Specifies the params to update the LDAP provider info.
 
+
     Attributes:
+
         ldap_provider_id (long|int): Specifies the LDAP provider id which is
             mapped to an Active Directory
-
     """
 
+
     # Create a mapping from Model property names to API property names
     _names = {
-        "ldap_provider_id":'ldapProviderId'
+        "ldap_provider_id":'ldapProviderId',
     }
-
     def __init__(self,
-                 ldap_provider_id=None):
+                 ldap_provider_id=None,
+            ):
+
         """Constructor for the UpdateLdapProviderParams class"""
 
         # Initialize members of the class
         self.ldap_provider_id = ldap_provider_id
 
-
     @classmethod
     def from_dictionary(cls,
                         dictionary):
@@ -48,6 +49,6 @@ class UpdateLdapProviderParams(object):
         ldap_provider_id = dictionary.get('ldapProviderId')
 
         # Return an object of this model
-        return cls(ldap_provider_id)
-
-
+        return cls(
+            ldap_provider_id
+)
\ No newline at end of file
