@@ -1,15 +1,16 @@
 # -*- coding: utf-8 -*-
-# Copyright 2022 Cohesity Inc.
-
+# Copyright 2023 Cohesity Inc.
 
 class UsageAndPerformanceStats(object):
 
     """Implementation of the 'UsageAndPerformanceStats' model.
 
-    Provides usage and performance statistics
-    for entities such as a disks, Nodes or Clusters.
+    Provides usage and performance statistics for entities such as a disks,
+    Nodes or Clusters.
+
 
     Attributes:
+
         data_in_bytes (long|int): Specifies the data read from the protected
             objects by the Cohesity Cluster before any data reduction using
             deduplication and compression.
@@ -31,28 +32,25 @@ class UsageAndPerformanceStats(object):
             the last 30 seconds.
         read_latency_msecs (float): Provides the Read latency in milliseconds
             for the Read IOs that occurred during the last 30 seconds.
-        system_capacity_bytes (long|int): Provides the total available
-            capacity as computed by the Linux 'statfs' command.
-        system_usage_bytes (long|int): Provides the usage of bytes, as
-            computed by the Linux 'statfs' command, after the size of the data
-            is reduced by change-block tracking, compression and
-            deduplication.
-        total_physical_raw_usage_bytes (long|int): Provides the usage of
-            bytes, as computed by the Cohesity Cluster, before the size of the
-            data is reduced by change-block tracking, compression and
-            deduplication.
+        system_capacity_bytes (long|int): Provides the total available capacity
+            as computed by the Linux 'statfs' command.
+        system_usage_bytes (long|int): Provides the usage of bytes, as computed
+            by the Linux 'statfs' command, after the size of the data is
+            reduced by change-block tracking, compression and deduplication.
+        total_physical_raw_usage_bytes (long|int): Provides the usage of bytes,
+            as computed by the Cohesity Cluster, before the size of the data is
+            reduced by change-block tracking, compression and deduplication.
         total_physical_usage_bytes (long|int): Provides the data stored
             locally, after the data has been reduced by deduplication and
             compression, including the space required for honoring the
             resiliency settings (EC/RF).
-        write_ios (long|int): Provides the number of Write IOs that occurred
-            in the last 30 seconds.
-        write_latency_msecs (float): Provides the Write latency in
-            milliseconds for the Write IOs that occurred during the last 30
-            seconds.
-
+        write_ios (long|int): Provides the number of Write IOs that occurred in
+            the last 30 seconds.
+        write_latency_msecs (float): Provides the Write latency in milliseconds
+            for the Write IOs that occurred during the last 30 seconds.
     """
 
+
     # Create a mapping from Model property names to API property names
     _names = {
         "data_in_bytes":'dataInBytes',
@@ -68,9 +66,8 @@ class UsageAndPerformanceStats(object):
         "total_physical_raw_usage_bytes":'totalPhysicalRawUsageBytes',
         "total_physical_usage_bytes":'totalPhysicalUsageBytes',
         "write_ios":'writeIos',
-        "write_latency_msecs":'writeLatencyMsecs'
+        "write_latency_msecs":'writeLatencyMsecs',
     }
-
     def __init__(self,
                  data_in_bytes=None,
                  data_in_bytes_after_reduction=None,
@@ -85,7 +82,9 @@ class UsageAndPerformanceStats(object):
                  total_physical_raw_usage_bytes=None,
                  total_physical_usage_bytes=None,
                  write_ios=None,
-                 write_latency_msecs=None):
+                 write_latency_msecs=None,
+            ):
+
         """Constructor for the UsageAndPerformanceStats class"""
 
         # Initialize members of the class
@@ -104,7 +103,6 @@ class UsageAndPerformanceStats(object):
         self.write_ios = write_ios
         self.write_latency_msecs = write_latency_msecs
 
-
     @classmethod
     def from_dictionary(cls,
                         dictionary):
@@ -139,19 +137,19 @@ class UsageAndPerformanceStats(object):
         write_latency_msecs = dictionary.get('writeLatencyMsecs')
 
         # Return an object of this model
-        return cls(data_in_bytes,
-                   data_in_bytes_after_reduction,
-                   min_usable_physical_capacity_bytes,
-                   num_bytes_read,
-                   num_bytes_written,
-                   physical_capacity_bytes,
-                   read_ios,
-                   read_latency_msecs,
-                   system_capacity_bytes,
-                   system_usage_bytes,
-                   total_physical_raw_usage_bytes,
-                   total_physical_usage_bytes,
-                   write_ios,
-                   write_latency_msecs)
-
-
+        return cls(
+            data_in_bytes,
+            data_in_bytes_after_reduction,
+            min_usable_physical_capacity_bytes,
+            num_bytes_read,
+            num_bytes_written,
+            physical_capacity_bytes,
+            read_ios,
+            read_latency_msecs,
+            system_capacity_bytes,
+            system_usage_bytes,
+            total_physical_raw_usage_bytes,
+            total_physical_usage_bytes,
+            write_ios,
+            write_latency_msecs
+)
\ No newline at end of file
