@@ -1,54 +1,59 @@
 # -*- coding: utf-8 -*-
-# Copyright 2022 Cohesity Inc.
+# Copyright 2023 Cohesity Inc.
 
 import cohesity_management_sdk.models.cluster_identifier
 import cohesity_management_sdk.models.mcm_user_profile
+import cohesity_management_sdk.models.tenant_access
+
 
 class UserParameters(object):
 
     """Implementation of the 'UserParameters' model.
 
-    Specifies the settings used to create/add a new user or modify an
-    existing user.
+    Specifies the settings used to create/add a new user or modify an existing
+    user.
+
 
     Attributes:
-        additional_group_names (list of string): Array of Additional Groups.
+
+        additional_group_names (list of string): Array of Additional Groups. 
             Specifies the names of additional groups this User may belong to.
         cluster_identifiers (list of ClusterIdentifier): Specifies the list of
             clusters this user has access to. If this is not specified, access
             will be granted to all clusters.
         description (string): Specifies a description about the user.
-        domain (string): Specifies the fully qualified domain name (FQDN) of
-            an Active Directory or LOCAL for the default LOCAL domain on the
+        domain (string): Specifies the fully qualified domain name (FQDN) of an
+            Active Directory or LOCAL for the default LOCAL domain on the
             Cohesity Cluster. A user is uniquely identified by combination of
             the username and the domain.
         effective_time_msecs (long|int): Specifies the epoch time in
             milliseconds when the user becomes effective. Until that time, the
             user cannot log in.
         email_address (string): Specifies the email address of the user.
-        expired_time_msecs (long|int): Specifies the epoch time in
-            milliseconds when the user becomes expired. After that, the user
-            cannot log in.
+        expired_time_msecs (long|int): Specifies the epoch time in milliseconds
+            when the user becomes expired. After that, the user cannot log in.
         password (string): Specifies the password of this user.
-        primary_group_name (string): Specifies the name of the primary group
-            of this User.
-        privilege_ids (list of PrivilegeIdUserParametersEnum): Array of
-            Privileges.  Specifies the Cohesity privileges from the roles.
-            This will be populated based on the union of all privileges in
-            roles. Type for unique privilege Id values. All below enum values
-            specify a value for all uniquely defined privileges in Cohesity.
-        profiles (list of McmUserProfile): Specifies the user profiles.
-            NOTE: Currently used for Helios.
+        primary_group_name (string): Specifies the name of the primary group of
+            this User.
+        privilege_ids (list of PrivilegeIdsEnum): Array of Privileges. 
+            Specifies the Cohesity privileges from the roles. This will be
+            populated based on the union of all privileges in roles. Type for
+            unique privilege Id values. All below enum values specify a value
+            for all uniquely defined privileges in Cohesity.
+        profiles (list of McmUserProfile): Specifies the user profiles. NOTE:
+            Currently used for Helios.
         restricted (bool): Whether the user is a restricted user. A restricted
             user can only view the objects he has permissions to.
         roles (list of string): Array of Roles.  Specifies the Cohesity roles
             to associate with the user such as such as 'Admin', 'Ops' or
             'View'. The Cohesity roles determine privileges on the Cohesity
             Cluster for this user.
+        tenant_accesses (list of TenantAccess): Specifies the tenant access
+            available to current user. NOTE: Currently used for Helios.
         username (string): Specifies the login name of the user.
-
     """
 
+
     # Create a mapping from Model property names to API property names
     _names = {
         "additional_group_names":'additionalGroupNames',
@@ -64,9 +69,9 @@ class UserParameters(object):
         "profiles":'profiles',
         "restricted":'restricted',
         "roles":'roles',
-        "username":'username'
+        "tenant_accesses":'tenantAccesses',
+        "username":'username',
     }
-
     def __init__(self,
                  additional_group_names=None,
                  cluster_identifiers=None,
@@ -81,7 +86,10 @@ class UserParameters(object):
                  profiles=None,
                  restricted=None,
                  roles=None,
-                 username=None):
+                 tenant_accesses=None,
+                 username=None,
+            ):
+
         """Constructor for the UserParameters class"""
 
         # Initialize members of the class
@@ -98,9 +106,9 @@ class UserParameters(object):
         self.profiles = profiles
         self.restricted = restricted
         self.roles = roles
+        self.tenant_accesses = tenant_accesses
         self.username = username
 
-
     @classmethod
     def from_dictionary(cls,
                         dictionary):
@@ -119,7 +127,7 @@ class UserParameters(object):
             return None
 
         # Extract variables from the dictionary
-        additional_group_names = dictionary.get('additionalGroupNames')
+        additional_group_names = dictionary.get("additionalGroupNames")
         cluster_identifiers = None
         if dictionary.get('clusterIdentifiers') != None:
             cluster_identifiers = list()
@@ -132,30 +140,36 @@ class UserParameters(object):
         expired_time_msecs = dictionary.get('expiredTimeMsecs')
         password = dictionary.get('password')
         primary_group_name = dictionary.get('primaryGroupName')
-        privilege_ids = dictionary.get('privilegeIds')
+        privilege_ids = dictionary.get("privilegeIds")
         profiles = None
         if dictionary.get('profiles') != None:
             profiles = list()
             for structure in dictionary.get('profiles'):
                 profiles.append(cohesity_management_sdk.models.mcm_user_profile.McmUserProfile.from_dictionary(structure))
         restricted = dictionary.get('restricted')
-        roles = dictionary.get('roles')
+        roles = dictionary.get("roles")
+        tenant_accesses = None
+        if dictionary.get('tenantAccesses') != None:
+            tenant_accesses = list()
+            for structure in dictionary.get('tenantAccesses'):
+                tenant_accesses.append(cohesity_management_sdk.models.tenant_access.TenantAccess.from_dictionary(structure))
         username = dictionary.get('username')
 
         # Return an object of this model
-        return cls(additional_group_names,
-                   cluster_identifiers,
-                   description,
-                   domain,
-                   effective_time_msecs,
-                   email_address,
-                   expired_time_msecs,
-                   password,
-                   primary_group_name,
-                   privilege_ids,
-                   profiles,
-                   restricted,
-                   roles,
-                   username)
-
-
+        return cls(
+            additional_group_names,
+            cluster_identifiers,
+            description,
+            domain,
+            effective_time_msecs,
+            email_address,
+            expired_time_msecs,
+            password,
+            primary_group_name,
+            privilege_ids,
+            profiles,
+            restricted,
+            roles,
+            tenant_accesses,
+            username
+)
\ No newline at end of file
