@@ -1,9 +1,10 @@
 # -*- coding: utf-8 -*-
-# Copyright 2021 Cohesity Inc.
+# Copyright 2023 Cohesity Inc.
 
-import cohesity_management_sdk.models.usage_and_performance_stats
 import cohesity_management_sdk.models.data_usage_stats
 import cohesity_management_sdk.models.logical_stats
+import cohesity_management_sdk.models.usage_and_performance_stats
+
 
 class ViewBoxStats(object):
 
@@ -11,23 +12,26 @@ class ViewBoxStats(object):
 
     Provides statistics about the Storage Domain (View Box).
 
+
     Attributes:
-        cloud_usage_perf_stats (UsageAndPerformanceStats): Provides usage and
-            performance statistics for entities such as a disks, Nodes or
-            Clusters.
+
+        cloud_usage_perf_stats (UsageAndPerformanceStats): Provides the usage
+            statistics for the data stored in the cloud for the Storage Domain
+            (View Box). Performance statistics are not populated.
         data_usage_stats (DataUsageStats): Specifies the data usage metric of
             the data stored on the Storage Domain (View Box).
         id (long|int): Specifies the id of the Storage Domain (View Box).
         local_usage_perf_stats (UsageAndPerformanceStats): Provides usage
             statistics for the locally stored data on the Storage Domain (View
             Box). Performance statistics are not populated.
-        logical_stats (LogicalStats): Provides the logical usage statistics
-            for the Storage Domain (View Box).
+        logical_stats (LogicalStats): Provides the logical usage statistics for
+            the Storage Domain (View Box).
         usage_perf_stats (UsageAndPerformanceStats): Provides usage and
-            performance statistics for the Storage Domain (View Box)
-            (includes both local and cloud data).
+            performance statistics for the Storage Domain (View Box) (includes
+            both local and cloud data).
     """
 
+
     # Create a mapping from Model property names to API property names
     _names = {
         "cloud_usage_perf_stats":'cloudUsagePerfStats',
@@ -35,16 +39,17 @@ class ViewBoxStats(object):
         "id":'id',
         "local_usage_perf_stats":'localUsagePerfStats',
         "logical_stats":'logicalStats',
-        "usage_perf_stats":'usagePerfStats'
+        "usage_perf_stats":'usagePerfStats',
     }
-
     def __init__(self,
                  cloud_usage_perf_stats=None,
                  data_usage_stats=None,
                  id=None,
                  local_usage_perf_stats=None,
                  logical_stats=None,
-                 usage_perf_stats=None):
+                 usage_perf_stats=None,
+            ):
+
         """Constructor for the ViewBoxStats class"""
 
         # Initialize members of the class
@@ -55,7 +60,6 @@ class ViewBoxStats(object):
         self.logical_stats = logical_stats
         self.usage_perf_stats = usage_perf_stats
 
-
     @classmethod
     def from_dictionary(cls,
                         dictionary):
@@ -82,11 +86,11 @@ class ViewBoxStats(object):
         usage_perf_stats = cohesity_management_sdk.models.usage_and_performance_stats.UsageAndPerformanceStats.from_dictionary(dictionary.get('usagePerfStats')) if dictionary.get('usagePerfStats') else None
 
         # Return an object of this model
-        return cls(cloud_usage_perf_stats,
-                   data_usage_stats,
-                   id,
-                   local_usage_perf_stats,
-                   logical_stats,
-                   usage_perf_stats)
-
-
+        return cls(
+            cloud_usage_perf_stats,
+            data_usage_stats,
+            id,
+            local_usage_perf_stats,
+            logical_stats,
+            usage_perf_stats
+)
\ No newline at end of file
