@@ -1,41 +1,44 @@
 # -*- coding: utf-8 -*-
-# Copyright 2022 Cohesity Inc.
+# Copyright 2023 Cohesity Inc.
 
-import cohesity_management_sdk.models.virtual_disk_id_information
 import cohesity_management_sdk.models.protection_source
+import cohesity_management_sdk.models.virtual_disk_id_information
+
 
 class VirtualDiskMappingResponse(object):
 
     """Implementation of the 'VirtualDiskMappingResponse' model.
 
-    Specifies information about virtual disks where a user can specify
-    mappings
+    Specifies information about virtual disks where a user can specify mappings
     of source disk and destination disk to overwrite.
 
+
     Attributes:
+
         disk_to_overwrite (VirtualDiskIdInformation): Specifies information
             about disk which user wants to overwrite. If specified, then
             powerOffVmBeforeRecovery must be true.
-        source_disk (VirtualDiskIdInformation): Specifies information about
-            the source disk.
+        source_disk (VirtualDiskIdInformation): Specifies information about the
+            source disk.
         target_location (ProtectionSource): Specifies the target location
             information, for e.g. a datastore in VMware environment. If
             diskToOverwrite is specified, then the target location is
             automatically deduced.
-
     """
 
+
     # Create a mapping from Model property names to API property names
     _names = {
         "disk_to_overwrite":'diskToOverwrite',
         "source_disk":'sourceDisk',
-        "target_location":'targetLocation'
+        "target_location":'targetLocation',
     }
-
     def __init__(self,
                  disk_to_overwrite=None,
                  source_disk=None,
-                 target_location=None):
+                 target_location=None,
+            ):
+
         """Constructor for the VirtualDiskMappingResponse class"""
 
         # Initialize members of the class
@@ -43,7 +46,6 @@ class VirtualDiskMappingResponse(object):
         self.source_disk = source_disk
         self.target_location = target_location
 
-
     @classmethod
     def from_dictionary(cls,
                         dictionary):
@@ -67,8 +69,8 @@ class VirtualDiskMappingResponse(object):
         target_location = cohesity_management_sdk.models.protection_source.ProtectionSource.from_dictionary(dictionary.get('targetLocation')) if dictionary.get('targetLocation') else None
 
         # Return an object of this model
-        return cls(disk_to_overwrite,
-                   source_disk,
-                   target_location)
-
-
+        return cls(
+            disk_to_overwrite,
+            source_disk,
+            target_location
+)
\ No newline at end of file
