@@ -1,15 +1,15 @@
 # -*- coding: utf-8 -*-
-# Copyright 2022 Cohesity Inc.
-
+# Copyright 2023 Cohesity Inc.
 
 class VmLinkingInfo(object):
 
     """Implementation of the 'VmLinkingInfo' model.
 
-    Specifies the parameters for configuration of IPMI. This is only needed
-    for physical clusters.
+    VM Linking Info
+
 
     Attributes:
+
         is_migrated (bool): This is set to true if a VM is linked in entity
             provenance by edge type kVMMigration.
         migrated_time_usecs (long|int): This is the time when ther VM was
@@ -19,22 +19,23 @@ class VmLinkingInfo(object):
             vCenter where it was originally present
         previous_vm_parent_source_id (long|int): This is the id of vCenter
             where the VM was originally present
-
     """
 
+
     # Create a mapping from Model property names to API property names
     _names = {
         "is_migrated":'isMigrated',
         "migrated_time_usecs":'migratedTimeUsecs',
         "previous_vm_entity_id":'previousVmEntityId',
-        "previous_vm_parent_source_id":'previousVmParentSourceId'
+        "previous_vm_parent_source_id":'previousVmParentSourceId',
     }
-
     def __init__(self,
                  is_migrated=None,
                  migrated_time_usecs=None,
                  previous_vm_entity_id=None,
-                 previous_vm_parent_source_id=None):
+                 previous_vm_parent_source_id=None,
+            ):
+
         """Constructor for the VmLinkingInfo class"""
 
         # Initialize members of the class
@@ -43,7 +44,6 @@ class VmLinkingInfo(object):
         self.previous_vm_entity_id = previous_vm_entity_id
         self.previous_vm_parent_source_id = previous_vm_parent_source_id
 
-
     @classmethod
     def from_dictionary(cls,
                         dictionary):
@@ -68,9 +68,9 @@ class VmLinkingInfo(object):
         previous_vm_parent_source_id = dictionary.get('previousVmParentSourceId')
 
         # Return an object of this model
-        return cls(is_migrated,
-                   migrated_time_usecs,
-                   previous_vm_entity_id,
-                   previous_vm_parent_source_id)
-
-
+        return cls(
+            is_migrated,
+            migrated_time_usecs,
+            previous_vm_entity_id,
+            previous_vm_parent_source_id
+)
\ No newline at end of file
