@@ -1,50 +1,51 @@
 # -*- coding: utf-8 -*-
-# Copyright 2022 Cohesity Inc.
+# Copyright 2023 Cohesity Inc.
 
-import cohesity_management_sdk.models.source_app_params
 import cohesity_management_sdk.models.credentials
+import cohesity_management_sdk.models.source_app_params
 import cohesity_management_sdk.models.vmware_disk_exclusion_proto
 
-class VmwareBackupSourceParams(object):
+
+class VMwareBackupSourceParams(object):
 
     """Implementation of the 'VMwareBackupSourceParams' model.
 
     Message to capture additional backup params for a VMware type source.
 
+
     Attributes:
-        source_app_params (SourceAppParams): This message contains params
-            specific to application running on the source such as a VM or a
-            physical host.
+
+        source_app_params (SourceAppParams): This message will capture params
+            for applications that are running as part of the server.
         vm_credentials (Credentials): Target entity credentials. This should
             usually be set if the source_app_params is set, i.e any additional
             operations that require access within the guest.
-            
-        vmware_disk_exclusion_info (list of VmwareDiskExclusionProto): List of
+        vmware_disk_exclusion_info (list of VMwareDiskExclusionProto): List of
             Virtual Disk(s) to be excluded from the backup job for the source.
             Overrides the exclusion list requested (if any) through
             EnvBackupParams.VMwareBackupEnvParams.
-
     """
 
+
     # Create a mapping from Model property names to API property names
     _names = {
         "source_app_params":'sourceAppParams',
         "vm_credentials":'vmCredentials',
-        "vmware_disk_exclusion_info":'vmwareDiskExclusionInfo'
+        "vmware_disk_exclusion_info":'vmwareDiskExclusionInfo',
     }
-
     def __init__(self,
                  source_app_params=None,
                  vm_credentials=None,
-                 vmware_disk_exclusion_info=None):
-        """Constructor for the VmwareBackupSourceParams class"""
+                 vmware_disk_exclusion_info=None,
+            ):
+
+        """Constructor for the VMwareBackupSourceParams class"""
 
         # Initialize members of the class
         self.source_app_params = source_app_params
         self.vm_credentials = vm_credentials
         self.vmware_disk_exclusion_info = vmware_disk_exclusion_info
 
-
     @classmethod
     def from_dictionary(cls,
                         dictionary):
@@ -69,11 +70,11 @@ class VmwareBackupSourceParams(object):
         if dictionary.get('vmwareDiskExclusionInfo') != None:
             vmware_disk_exclusion_info = list()
             for structure in dictionary.get('vmwareDiskExclusionInfo'):
-                vmware_disk_exclusion_info.append(cohesity_management_sdk.models.vmware_disk_exclusion_proto.VmwareDiskExclusionProto.from_dictionary(structure))
+                vmware_disk_exclusion_info.append(cohesity_management_sdk.models.vmware_disk_exclusion_proto.VMwareDiskExclusionProto.from_dictionary(structure))
 
         # Return an object of this model
-        return cls(source_app_params,
-                   vm_credentials,
-                   vmware_disk_exclusion_info)
-
-
+        return cls(
+            source_app_params,
+            vm_credentials,
+            vmware_disk_exclusion_info
+)
\ No newline at end of file
