@@ -1,30 +1,33 @@
 # -*- coding: utf-8 -*-
-# Copyright 2021 Cohesity Inc.
+# Copyright 2023 Cohesity Inc.
 
 class VmwareParams(object):
 
     """Implementation of the 'VmwareParams' model.
 
-    TODO: Type description here.
+    TODO: type description here.
+
 
     Attributes:
+
         use_vm_bios_uuid (bool): Specifies to use VM BIOS UUID to track virtual
-        machines in the host.
+            machines in the host.
     """
 
+
     # Create a mapping from Model property names to API property names
     _names = {
-        "use_vm_bios_uuid":'useVmBiosUuid'
+        "use_vm_bios_uuid":'useVmBiosUuid',
     }
-
     def __init__(self,
-                 use_vm_bios_uuid=None):
+                 use_vm_bios_uuid=None,
+            ):
+
         """Constructor for the VmwareParams class"""
 
         # Initialize members of the class
         self.use_vm_bios_uuid = use_vm_bios_uuid
 
-
     @classmethod
     def from_dictionary(cls,
                         dictionary):
@@ -46,6 +49,6 @@ class VmwareParams(object):
         use_vm_bios_uuid = dictionary.get('useVmBiosUuid')
 
         # Return an object of this model
-        return cls(use_vm_bios_uuid)
-
-
+        return cls(
+            use_vm_bios_uuid
+)
\ No newline at end of file
