@@ -1,6 +1,5 @@
 # -*- coding: utf-8 -*-
-# Copyright 2021 Cohesity Inc.
-
+# Copyright 2023 Cohesity Inc.
 
 class VssWriter(object):
 
@@ -8,29 +7,31 @@ class VssWriter(object):
 
     Specifies vss writer information about a Physical Protection Source.
 
+
     Attributes:
+
         is_writer_excluded (bool): If true, the writer will be excluded by
             default.
         writer_name (string): Specifies the name of the writer.
-
     """
 
+
     # Create a mapping from Model property names to API property names
     _names = {
-        "is_writer_excluded": 'isWriterExcluded',
-        "writer_name": 'writerName'
+        "is_writer_excluded":'isWriterExcluded',
+        "writer_name":'writerName',
     }
-
     def __init__(self,
                  is_writer_excluded=None,
-                 writer_name=None):
+                 writer_name=None,
+            ):
+
         """Constructor for the VssWriter class"""
 
         # Initialize members of the class
         self.is_writer_excluded = is_writer_excluded
         self.writer_name = writer_name
 
-
     @classmethod
     def from_dictionary(cls,
                         dictionary):
@@ -49,11 +50,11 @@ class VssWriter(object):
             return None
 
         # Extract variables from the dictionary
-        is_writer_excluded = dictionary.get('isWriterExcluded', None)
-        writer_name = dictionary.get('writerName', None)
+        is_writer_excluded = dictionary.get('isWriterExcluded')
+        writer_name = dictionary.get('writerName')
 
         # Return an object of this model
-        return cls(is_writer_excluded,
-                   writer_name)
-
-
+        return cls(
+            is_writer_excluded,
+            writer_name
+)
\ No newline at end of file
