@@ -1,16 +1,19 @@
 # -*- coding: utf-8 -*-
-# Copyright 2021 Cohesity Inc.
+# Copyright 2023 Cohesity Inc.
 
 import cohesity_management_sdk.models.nas_mount_credential_params
 import cohesity_management_sdk.models.network_pool_config
 
+
 class ZoneConfig(object):
 
     """Implementation of the 'ZoneConfig' model.
 
-    Specifies the access zone config of the Isilon Access Zone.
+    TODO: type description here.
+
 
     Attributes:
+
         dynamic_network_pool_config (NetworkPoolConfig): Specifies the Dynamic
             network pool configuration for the Access Zone. Dynamic pool is
             used for stateless protocols, e.g. NFSv3.
@@ -19,27 +22,28 @@ class ZoneConfig(object):
         smb_credentials (NasMountCredentialParams): SMB credentials for the
             Access Zone.
         static_network_pool_config (NetworkPoolConfig): Specifies the Static
-            network pool configuration for the Access Zone. Static pool is
-            used for stateful protocols: e.g. SMB, NFSv4, and for stateless
+            network pool configuration for the Access Zone. Static pool is used
+            for stateful protocols: e.g. SMB, NFSv4, and for stateless
             protocols e.g. NFSv3 if dynamic pool below is not set.
-
     """
 
+
     # Create a mapping from Model property names to API property names
     _names = {
-        "dynamic_network_pool_config": 'dynamicNetworkPoolConfig',
-        "groupnet": 'groupnet',
-        "name": 'name',
-        "smb_credentials": 'smbCredentials',
-        "static_network_pool_config":'staticNetworkPoolConfig'
+        "dynamic_network_pool_config":'dynamicNetworkPoolConfig',
+        "groupnet":'groupnet',
+        "name":'name',
+        "smb_credentials":'smbCredentials',
+        "static_network_pool_config":'staticNetworkPoolConfig',
     }
-
     def __init__(self,
                  dynamic_network_pool_config=None,
                  groupnet=None,
                  name=None,
                  smb_credentials=None,
-                 static_network_pool_config=None):
+                 static_network_pool_config=None,
+            ):
+
         """Constructor for the ZoneConfig class"""
 
         # Initialize members of the class
@@ -74,10 +78,10 @@ class ZoneConfig(object):
         static_network_pool_config = cohesity_management_sdk.models.network_pool_config.NetworkPoolConfig.from_dictionary(dictionary.get('staticNetworkPoolConfig')) if dictionary.get('staticNetworkPoolConfig') else None
 
         # Return an object of this model
-        return cls(dynamic_network_pool_config,
-                   groupnet,
-                   name,
-                   smb_credentials,
-                   static_network_pool_config)
-
-
+        return cls(
+            dynamic_network_pool_config,
+            groupnet,
+            name,
+            smb_credentials,
+            static_network_pool_config
+)
\ No newline at end of file
